function [sectfile] = dosection(raw_filename, properties, sectfile)

% define file names from raw_filename prefix
add_tri=[raw_filename,'_tria'];
sectfile=raw_filename;
raw_filename=[raw_filename,'_raw'];


% DOSECTION   Process raw_sectfile to sectfile for dobox
%===================================================================
% DOSECTION  4.7   93/10/12   Copyright (C)  Phil Morgan 1992.
%
% sectfile = dosection(raw_filename, properties, sectfile)
%
% test version
%
% DESCRIPTION:
%    Reads a file "raw_filename" containing binned "properties" data and 
%    calculates the average property and property*area in each layer.
%    Processed section saved to new file.
%
% INPUT:
%    raw_filename   = Raw section file name string
%    properties     = List of property names in raw_filename. (string)
%    sectfile        = optional filename for new section file. Else prompted.
%
% OUTPUT:
%    sectfile       = processed section file name
%
% AUTHOR:  Phil Morgan 12-03-92
%==========================================================================

% @(#)dosection.m   Revision: 4.7   Date: 93/10/12
%--------------------------------------------------------------------

disp('DOSECTION determines where valid layers exist and calculates')
disp('          mean property values in layers at station pairs')
disp(' ')
TRUE  = 1;
FALSE = 0;

raw_filename          = charword(raw_filename);   % strip blanks
[raw_filename,fileok] = validfile(raw_filename,'.mat');
if fileok
   disp(['Loading data file {' raw_filename '}'])
   disp(' ')
   command=['load ' raw_filename];
   clear Ln;
   setstr(command);
   eval(command);    
else
   error(['File {' raw_filename '} not found'])
end %if
clear fileok command

[nsurfs, nstations] = size(surf_press);
[nproperties, n ]  = size(properties);
npairs = nstations - 1;
nlayers = nsurfs+1;  %not used  - can be derived from nsurfs
clear n

if nproperties < 2
   error('require at least 2 props.  mass and one other')
end %if


disp('Verifying that properties are self-consistent')
PropName2 = charword( properties(2,:) );
bin_prop2 = ['bin_' PropName2];
for iprop = 3:nproperties
   prop_next = ['bin_' charword( properties(iprop,:) )];
   if ~nansame( eval(bin_prop2) , eval(prop_next) );
      error(['     ' bin_prop2 ' and ' prop_next ' not consistent'])
   else
      disp(['     ' bin_prop2 ' and ' prop_next ' ARE consistent'])    
   end %if
end %for
clear prop_next bin_prop2 iprop 

%disp('Calculating binPair averages for ')
%reply = input('Add bottom triangle to station pair (y/n)?  ','s');
reply='y';
 for iprop = 2:nproperties
    PropName = [charword( properties(iprop,:) )];
    disp(['      ' PropName])
    bin_prop = ['bin_' PropName];
    VariableName = ['binPair_' PropName];
    command = [VariableName ' = avecol(' bin_prop '); '];
    eval(command)
    triindex   = sum(finite(binPair_vel));
    eval(['tt = sum(finite(' bin_prop ')); ']);
    tt = round(diff(tt)/2);
    eval(['ntriindex  = sum(finite(' VariableName ')); ']);
    [mn,nn] = size(binPair_vel);
       for tri = 1:nn
         if strcmp(reply,'y') == 1
             if tt(tri) >= 0
               eval([VariableName '(ntriindex(tri) + 1:triindex(tri),tri) = '...
                     bin_prop '(ntriindex(tri)+1:triindex(tri) ,tri+1); ']);
             elseif tt(tri) < 0
               eval([VariableName '(ntriindex(tri) + 1:triindex(tri),tri) = '...
                      bin_prop '(ntriindex(tri)+1:triindex(tri) ,tri); ']);
             end %(if tt)
          elseif strcmp(reply,'y') == 0
             binPair_vel(ntriindex(tri) + 1:triindex(tri),tri) = ...
                 ones(triindex(tri)-ntriindex(tri),1)*NaN; 
          end %if
     end %for
 end %for

surfPair_press    = avecol( surf_press );

clear command VariableName PropName bin_prop ntriindex triindex mn nn 

disp('Verifying binPair_vel...')
if ~nansame( eval(['binPair_' PropName2]), binPair_vel )
  disp(['    binPair_vel NOT consistent with ' PropName2])
  keyboard
  %error('STOPPED by dosection.m')
else
  disp(['    binPair_vel is consistent with ' PropName2])
end %if


disp('Calculating deepest common pressures...')
Press2Row         = [bin_press [1:length(bin_press)]' ];
[values,com_rows] = lastgood( eval(['binPair_' PropName2]),NaN);

pelp1=fliplr(Press2Row);
com_press = interp1(pelp1(:,1),pelp1(:,2),com_rows);
clear values PropName2 pelp1

disp('Finding valid surfaces above deepest common pressures...')
surfPair_press_valid = surfPair_press;
surfPair_bin         = NaN*ones(size(surfPair_press));

for ipair=1:npairs
  bad = find( surfPair_press(:,ipair) > com_press(ipair) );
  if ~isempty(bad)
     surfPair_press_valid(bad,ipair) = NaN*ones(length(bad),1);
  end %if
  good = find( ~isnan(surfPair_press_valid(:,ipair) ) );
  if ~isempty( good )
     %surfPair_bin(good,ipair) = ...
         %fix(table1(Press2Row,surfPair_press_valid(good,ipair)) );
     surfPair_bin(good,ipair) = ...
         fix(interp1(Press2Row(:,1),Press2Row(:,2), ...
		surfPair_press_valid(good,ipair)) );
  end %if
end %for
clear good bad ipair

disp('Identifying all surfaces and bin numbers...')

if (0) %%%%%%%%%%%%%%%%%%
Layer_press = [NaN*ones(size(surfPair_press_valid(1,:)));
               surfPair_press_valid;
	       NaN*ones(size(surfPair_press_valid(1,:)))];

[val1,itop] = firstgood(surfPair_press_valid,NaN);
[val2,ibot] = lastgood( surfPair_press_valid,NaN);

for ipair = 1:npairs  %length(val1)
   if ~isnan(itop(ipair))
      Layer_press( itop(ipair),   ipair) = bin_press(1);
   end %if
   if ~isnan(ibot(ipair))
      Layer_press( ibot(ipair)+2, ipair) = com_press(ipair);
   end %if
end %for
else %%%%%%%%%%%%%%%%%%%%%
Layer_press=NaN*ones(nsurfs+2,length(lon)-1);
end; %%%%%%%%%%%%%%%%%%%%%

Area_layer=NaN*ones(nsurfs+1,length(lon)-1);
disp('Calculating thickness, area of Layers ... ')
%thick = diff(Layer_press);
%thick = change(thick,'==',NaN,0);
% new code (added 28-29 May 2002)
thick=NaN*ones(size(surf_press,1)+1,length(lon)-1);
fprintf('  counting to %d: ',size(thick,2));
for i=1:length(lon)-1;
  fprintf('%d ',i);

  % extract values of surf_press from both casts
  sp1=surf_press(:,i);
  sp2=surf_press(:,i+1);

  q=find(isfinite(sp1)); if (length(q))
  if sum(sp1(q)~=sort(sp1(q)))
    fprintf('  gamma not monotonic in cast %d.\n',i);
    sp1(q)=sort(sp1(q));
  end;end;
  q=find(isfinite(sp2)); if (length(q))
  if sum(sp2(q)~=sort(sp2(q)))
    fprintf('  gamma not monotonic in cast %d.\n',i+1);
    sp2(q)=sort(sp2(q));
  end;end;

  % Add top and bottom level for layers 1, nsurfs+1.
  % Add NaNs to top if upper layer doesn't exist
  % or is at 0, otherwise add 0.  Same with bottom.
  if (sp1(1)>0) sp1=[0;sp1];
  else sp1=[NaN;sp1]; end;
  if (sp2(1)>0) sp2=[0;sp2];
  else sp2=[NaN;sp2]; end;
  if (last(sp1)<bottom(i)) sp1=[sp1;bottom(i)];
  else sp1=[sp1;NaN]; end;
  if (last(sp2)<bottom(i+1)) sp2=[sp2;bottom(i+1)];
  else sp2=[sp2;NaN]; end;

  % In cases where only the uppermost or lowermost
  % layer exists in a cast, spN is all NaNs.  Fix.
  if (~sum(isfinite(sp1)) & sum(isfinite(sp2)) )
    if (mean(find(isfinite(sp2)))>((nsurfs+2)/2)) 
      sp1(nsurfs+1)=0;sp1(nsurfs+2)=bottom(i);
      fprintf('  assigning deepest layer to cast %d.\n',i);
    else
      sp1(1)=0;sp1(2)=bottom(i);
      fprintf('  assigning layer 1 to cast %d.\n',i);
    end;
  elseif (~sum(isfinite(sp2)) & sum(isfinite(sp1)) )
    if (mean(find(isfinite(sp1)))>((nsurfs+2)/2))
      sp2(nsurfs+1)=0;sp2(nsurfs+2)=bottom(i+1);
      fprintf('  assigning deepest layer to cast %d.\n',i+1);
    else
      sp2(1)=0;sp2(2)=bottom(i+1);
      fprintf('  assigning layer 1 to cast %d.\n',i+1);
    end;
  elseif (~sum(isfinite(sp1)) & ~sum(isfinite(sp2)) )
    disp('Cannot identify layers in dosection.m');
    keyboard;
  end;
  
  % should have min(diff(spN))>0.  Fix if not happening
  q=find(diff(sp1)==0);
  if (length(q))
      disp('WARNING!  diff(sp1) has a zero\n')
      if q<(nsurfs/2)
        sp1(q+1)=.5*(sp1(q)+sp1(q+2));
      else
        sp1(q)=.5*(sp1(q-1)+sp1(q+1));
      end;
  end;
  q=find(diff(sp2)==0);
  if (length(q))
      disp('WARNING! diff(sp2) has a zero - \n')
      if q<(nsurfs/2)
          sp2(q+1)=.5*(sp2(q)+sp2(q+2));
      else
        sp2(q)=.5*(sp2(q-1)+sp2(q+1));
      end;
  end;

  dx=sw_dist([lat(i) lat(i+1)], ...
        [lon(i) lon(i+1)],'km')*1e3;
  % calculate area of each layer between casts
  % using routine interpcasts.m
  [A,LayP]=interpcasts( ...
	sp1,sp2,[bottom(i) bottom(i+1)],dx,nsurfs);
  Area_layer(:,i)=A;
  thick(:,i)=A/dx;
  q=find(isnan(thick(:,i)));
  thick(q,i)=0;
  %lp=-[flipud(cumsum(flipud(thick(:,i))));0];
  %lp=lp-min(lp);
  %% NaN-out non-unique values
  %lp2=NaN*ones(size(lp));
  %lp2(min(find(diff(lp)>1)):min(find(diff(lp)>1)) ...
	%+length(unique(lp))-1)=unique(lp);
  %Layer_press(:,i)=lp2;
  Layer_press(:,i)=LayP;
end;
fprintf('\n');
thick = change(thick,'==',NaN,0);
clear i A dx q lp lp2 sp1 sp2 LayP ans;

Layer_bin = NaN*ones(size(Layer_press));
for ipair = 1:npairs
   goodi=find( ~isnan(Layer_press(:,ipair)) );
   % length(goodi) = 0 (ok, no surfs))
   if length(goodi) > 1
      Layer_bin(goodi,ipair) = fix(interp1( ...
	Press2Row(:,1),Press2Row(:,2),Layer_press(goodi,ipair)) );
   elseif length(goodi) == 1
      error('dosection.m: must have more than 1 surface to define layers')
   end %if
end %for
clear Press2Row goodi

clear val1 val2 itop ibot

disp('Calculating mean property value in middle of LayerPair for ')

LayerPair_mass = ones(nsurfs+1,npairs);

for iprop = 2:nproperties
   PropName = [charword( properties(iprop,:) )];
   disp(['     ' PropName])
   binPair_property = eval(['binPair_'   PropName]);

   IntLayer_prop  = [];

   for ipair = 1:npairs
     IntLayerPair_prop   = NaN*ones(1,nlayers);
  
     %% FIND VALID NEUTRAL SURFACES FOR A STATION PAIR. incl csurf and bottom
      good_p      = Layer_press(:,ipair); 
      good_surf   = find(~isnan(good_p)); 
  
     %% INTEGRATE PROP DOWN A STATION PAIR BETWEEN VALID SURFACES
     if (~isempty(good_surf) & 0)
	F_good = [];
        F_good = integrate(bin_press,binPair_property(:,ipair),good_p(good_surf));
       %% INSERT INTEGRATE FLUXES INTO VALID LAYERS, OTHERS LEFT AS NaN
       for igood = 1:length(F_good)
         IntLayerPair_prop(good_surf(igood))   = F_good(igood);
       end %for
     else 
        for igood=1:length(good_surf)-1;
	  q=find(bin_press>=good_p(good_surf(igood)) & ...
		bin_press<=good_p(good_surf(igood+1)));
	  if ~length(q) 
	    q2=find(bin_press>good_p(good_surf(igood+1)));
	    q=q2(1);
	  end;
          IntLayerPair_prop(good_surf(igood))=nanmean( ...
		binPair_property(q,ipair) );
        end;
     end %if

     %% APPEND INTEGRATION OF ONE STATION PAIR FLUXES INTO A SECTION OF FLUXES
     IntLayer_prop   = [IntLayer_prop IntLayerPair_prop'];

   end % loop over ipair
   clear F_good binPair_property igood good_p good_surf 
   
if (0)
   % want Integrated_property between surfaces (ie in layer) divided
   % by layer thickness.  Avoid division by zero error messages.
   bad = find( thick==0);
   goodthick = thick;
   if ~isempty(bad)
      goodthick(bad) = ones(1,length(bad));
   end %if
   Layer_mean     = IntLayer_prop ./ goodthick;
   Layer_mean     = change(Layer_mean,'==',NaN,0);
   if ~isempty(bad)
      Layer_mean(bad) = zeros(1,length(bad));
   end %if
   clear bad goodthick
else
  Layer_mean=IntLayer_prop;
  Layer_mean     = change(Layer_mean,'==',NaN,0);
end;

   VariableName = ['LayerPair_' PropName];
   command = [VariableName ' = Layer_mean;'];
   eval(command)
   
end %for   
clear iprop Layer_mean IntLayer_prop binPair_prop IntLayerPair_prop
clear good_p good_surf PropName

deldistkm      = dobox_distance(lat,lon,'km');
distkm         = cumsum([0 deldistkm]);

if (0)
  disp('Calculating AreaPair ...')
  Area_layer     = thick*diag(1000*deldistkm);
    if strcmp(reply,'y') == 1
        %add_tri = input('Add tri file:  ','s')
        eval(['load ' add_tri]);
         for iadd = 1:nstations -1
           if (length(max(find(Area_layer(:,iadd) > 0))))
             tt(iadd) = max(find(Area_layer(:,iadd) > 0));
             % commented out 28 May 2002: area already
	     % included in "thick" calculation (above)
             %Area_layer(tt(iadd),iadd) = ...
                %Area_layer(tt(iadd),iadd) + area_tri(iadd);
           end
         end %(for)
     end %(if)
end;

disp('Calculating Area_properties for')
disp('     mass')
Area_mass = Area_layer;

for iprop = 2:nproperties
   PropName = [charword( properties(iprop,:) )];
   disp(['     ' PropName])
   LayerPair_prop = ['LayerPair_'   PropName];

%  Area_prop  = Area_layer .* LayerPair_prop;
      VariableName = ['Area_' PropName];
      Expression   = ['Area_layer .* ' LayerPair_prop];
      command = [VariableName ' = ' Expression ';'];
      eval(command)
end %for   
clear iprop VariableName Expression command LayerPair_prop PropName
clear tt add_tri
clear TRUE FALSE

prompt_user = 1;  % do not prompt user to overwrite if sectfile passed
if exist('sectfile')==0
   sectfile = input('What filename to save this section? ','s');
   prompt_user = 1;
end %if

%[sectfile,file_exists] = validfile(sectfile,'.mat');
%if file_exists
   %if prompt_user
       %fprintf('Warning: file %s exists.  ',sectfile);
       %reply = input('Overwrite (y/n) ? [n] ','s');
       %if ~strcmp(lower(reply),'y')
           %error('ABORT. Not overwriting existing file')
       %end %if
   %end %if
%else
   %% ok - batch mode
%end %if
%clear file_exists prompt_user

clear q q2 

disp(['Saving file {' sectfile '} '])
command = ['save  ' sectfile];
setstr(command);
eval(command);

return

