function [itaux,itauy]=getwind(ylat,xlong, wind_file)

%===================================================================
% GETECMWF   3.1  92/04/03
%
% [ctaux,ctauy]=getwind(ylat,xlong, windfile)
%
% DESCRIPTION:
%    Interpolates the wind stress dataset for the wind stress at the
%    desired position(s).
% 
% INPUT:
%    ylat   = vector latitudes  for wind stress. Decimal degrees (+ve N, -ve S)
%    xlong  = vector longitudes for wind stress. Decimal degrees (+ve E, -ve W)
% wind_file = wind climatologhy data
% OUTPUT:
%    itaux  = interpolated wind stress component in x (E) direction 
%    itauy  = interpolated wind stress component in y (N) direction
%                units are dynes/cm2
%
%
% AUTHOR:   Phil Morgan 17-02-92
% Modified: Bernadette sloyan 95-4-27
% Last Modificatin: BS 95-8-22 deal with long 0..359
%==================================================================

% @(#)getecmwf.m   3.1   92/04/03
%--------------------------------------------------------------------

xc = find(xlong <  0);
if ~isempty(xc)
  xlong(xc) = xlong(xc) +360;
end

command = ['load ' wind_file];
eval(command)

[m,n]=size(tauy);
if m~=size(lat)
  error('GETECMWF.M: lat wrong dims')
end %if
if n~=size(long)
  error('GETECMWF.M: long wrong dims')
end %if

taux = change(taux,'<',-90,NaN);
tauy = change(tauy,'<',-90,NaN);

tabx = [0 long; lat' taux];
taby = [0 long; lat' tauy];

for i=1:length(xlong)
  [itaux(i)]=table2(tabx,ylat(i),xlong(i));
  [itauy(i)]=table2(taby,ylat(i),xlong(i));
end

%---------------------------------------------------------------------------

