function [DL,E,D,bbase,reflevel] = ...
 rhs_menu(nsections,geometry,sectfiles,properties,nsurfs,DL,E,D,bbase,reflevel)

% RHS_MENU  Menu for constructing RHS matrices D, bbase
%===================================================================
% RHS_MENU  4.7   93/10/12   Copyright (C)  Phil Morgan  1992
%
% DESCRIPTION:
%    Script for menu of the constructing RHS
% 
% CALLER:   dobox.m
% CALLEE:   build_dl.m build_e.m
%
%
% AUTHOR:   Phil Morgan 92-08-03
% Modified: Bernadette Sloyan 1995 Addition of Hellerman and
%           Rosenstein wind product
% Modified: Bernadette Sloyan 13/07/00 Addition of Da Silva
%           COADS wind and unit qualifer for wind products.
%==================================================================


if     nargin == 5
  % ok - minimum allowable input parameters.
  DL = []; D = []; bbase = []; E = [];
elseif nargin == 10
  % ok - pass thru any previous values for output parameters DL,E,D,bbase
else
  error('rhs_menu.m: wrong number of input parameters')
end %if


rhs_opt_stop = 0;
rhs_opt = 0;
%while rhs_opt_stop == 0
    %disp(' ')
    %disp(' 						')
    %disp('----- RHS MENU (3) -----			')
    %disp(' 						')
    %disp('      1) Set Reference level - build DL ')
    %disp('      2) Reset Ekman to zero	          ')
    %disp('      3) Calculate Ekman		')
    %disp(' 					')
    %disp('      0) Main Menu - construct RHS	')
    %disp('  					')

    %rhs_opt = input(' Select a menu number: ');
    rhs_opt = 1;

    if      rhs_opt == 0
	rhs_opt_stop = 1;
	if isempty(DL)
           disp(' ')
	   disp('WARNING: RHS not constructed, reflevel not set.')
           disp(' ')
	   disp('Hit a key to continue')
	   pause
	else
           if ~exist('E')
	      E = zeros(size(DL));
           end %if
           D = -DL - E;
	   bbase = sum(D')';
        end %if

    elseif rhs_opt == 1
        %%%% reflevel now set in geo.m %%%%
        %[reflevel] = getreflevel(nsections,sectfiles);
    	[DL]     = build_dl(geometry, sectfiles, properties, reflevel);

        E = zeros(size(DL));	% zero out Ekman;
				% this is now done in airsea.m
    		
    elseif  rhs_opt == 2
	if isempty(DL)
          disp('WARNING: RHS not construct, reflevel must be set first')
          disp(' ')
          disp('Hit a key to continue')
	  pause
	else
	   E = zeros(size(DL));
	end %if
        disp(' ')
        disp(' Ekman reset to zero')
    		
    elseif  rhs_opt == 3
        disp(' ')
        disp('------ Wind data -------');
        disp('       1) ECMWF         ');
        disp('       2) Hellerman and Rosenstein ');
        disp('       3) COADS (Da Silva 1994)    ');

        wind_opt = input('Select wind climatology data: ');
          if wind_opt == 1
          %wind_file = '/tphs1/user6/bsloyan/inverse/data/wind/ecmwfdata.mat';
	  wind_file = 'ecmwfdata.mat';
          elseif wind_opt == 2
          %wind_file = '/tphs1/user6/bsloyan/inverse/data/wind/hrwind.mat';
	  wind_file = 'hrwind.mat';
          else % wind_opt == 3
          wind_file = '/home/lasalle0/scratch/coads/meancoadswind.mat';
          end
        units = input(' Unit of wind data (dynes/cm2 or N/m2): ','s');
    
      	disp(' Adding ekman flux to RHS ');
  	disp(' ')
      	E = build_e( geometry, sectfiles, properties,wind_file,units);

    else
	rhs_opt_stop = 0;

    end %if

%end %while

%%%%%
E = zeros(size(DL));
D = -DL - E;
bbase = sum(D')';
%%%%%

return
%--------------------------------------------------------------------
