% uniquerefvels.m
%
% Define a set of inhomogeneous initial reference 
% velocities and a priori magnitudes of corrections for
% particular sections.

% load defined levels, layers
glev;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% a08 (11 deg. S).
%
% Initial reference levels from Speer, Holfort,
%	Reynaud and Siedler (1996).
sect='a08.mat';
i=sectname2sectnum(sect);
if (length(i))

  refp=3900;
  load /phod007/lumpkin/dobox/sections/a08_raw ...
        bin_press surf_press;
  d=(refp-nanmean(surf_press')').^2;
  reflevel(i)=find(d==min(d));

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  % shift reference level to isobaric surfaces
  % (ASSUMES BOTTOM REFERENCE LEVEL)
  reflevel(i)=length(glevels);  % must be set to bottom
                                % for isobaric code to work!
  load /phod007/lumpkin/dobox/sections/a08_raw ...
	 binPair_vel lon bin_press
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  for j=1:length(lon);
    q=find(isfinite(binPair_vel(:,j)));
    binPair_vel(:,j)=binPair_vel(:,j)- ...
	binPair_vel(last(q),j);
  end;

  % shift ref level to 1100m west of 35.5W
  q=find(bin_press==1100);
  q2=find(lon<=-35.5);
  RV(q2)=RV(q2)-binPair_vel(q,q2);
  q=find(isnan(RV(q2)));RV(q2(q))=0;
  %RV(3)=-.2886;

  % shift ref level to 3800m between 35.5W and 17.67W
  % (Brazil Basin)  (stations 4:6 stay bottom-referenced)
  q=find(bin_press==3800);
  q2=find(lon>=-35.5 & lon<=-17.67);
  RV(q2)=RV(q2)-binPair_vel(q,q2);
  q=find(isnan(RV(q2)));RV(q2(q))=0;

  % shift ref level to 2400m between 17.67W and 10.17W (MAR)
  q=find(bin_press==2400);
  q2=find(lon>=-17.67 & lon<=-10.17);
  RV(q2)=RV(q2)-binPair_vel(q,q2);
  q=find(isnan(RV(q2)));RV(q2(q))=0;

  % shift ref level to 4000m east of 10.17W (Angola Basin)
  q=find(bin_press==4000);
  q2=find(lon>=-10.17);
  RV(q2)=RV(q2)-binPair_vel(q,q2);
  q=find(isnan(RV(q2)));RV(q2(q))=0;

  % uniform shift to balance Ekman (9.71Sv south)
  RV=RV-1.23e-4;

  clear binPair_vel lon bin_press q q2

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);

end;

%%%%%%%%%%%%%%%%
% a10 (30 deg S.
sect='a10.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=28.175); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),200,.3);
  RV=rv(i)*ones(length(Vmag),1)';
  
  load /phod007/lumpkin/dobox/sections/a10_raw lon
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  % Brazil Current (inshore): 25 Sv south
  q=find(lon<-46.4); RV(q)=-.195;
  % Brazil Current recirc: 7.5 Sv north
  q=find(lon>-46.4 & lon<-44.8); RV(q)=.015;
  
  % Vema Channel AABW (gam>28.175): 2 Sv north
  %q=find(lon<-35.8); RV(q)=RV(q)+0;  % already satisfied
  % Brazil Basin AABW: 3 Sv north
  q=find(lon>-33 & lon<-17.8);RV(q)=RV(q)+.003;
  % Cape Basin AABW: 0 Sv (blocked by Walvis)
  %q=find(lon>-3); RV(q)=RV(q)+0;  % already satisfied

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% a11 (45-30 deg. S).
%
% Primary reference Saunders and King, 1995
%   ref level sig_3=41.58, gam=28.173-28.178
%	Note: not including Zapiola anticyclone
%	 in a priori field (see SK95 pg.1951).
sect='a11.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=28.175); reflevel(i)=q(1);

  load /phod007/lumpkin/dobox/sections/a11_raw lon
  lon=lon(1:length(lon)-1)+diff(lon)/2;

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),200,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  % 45 Sv WBC (Malvinas Current, pairs 1-5; SK95)
  q=find(lon<=-58.4); RV(q)=.15;

  % -5 Sv EBC (pairs 85-89; SK95)
  q=find(lon>=14.5); RV(q)=-.037;

  % 0 Sv bottom water (gam>28.175) into Cape Basin
  %  (pairs 60:81; blocked by Walvis Ridge) (SK95)
  q=find(lon>=-6 & lon<=12.1); RV(q)=-.0003;

  % 6 Sv bottom water (gam>28.175) into Argentine Basin
  %  (pairs 9-45)
  q=find(lon>=-57.3 & lon<=-21.1); RV(q)=.0013;

  % uniform s-ward flow across station pairs
  %   over MAR to get 0 net flow (-5.4 Sv to balance Ek)
  q=find(lon>=-15.7 & lon<=-12.5);
  retflow=-.022;RV(q)=retflow;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Canadian Archipelago throughflow
sect='arch.mat';
i=sectname2sectnum(sect);
if (length(i))

  reflevel(i)=length(glevels);

  eval(['load ',sectfiles(i,:),' binPair_vel']);
  Vmag=vmag(i)*ones(1,size(binPair_vel,2));
  RV=rv(i)*ones(length(Vmag),1)';

  RV(1:length(RV))=-.04;  % gives .82 Sv, 28.13 Gg/s salt.
  for bl=1:length(Vmag);
    Vmag(bl)=.05;
  end;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Bering Strait throughflow
sect='bering.mat';
i=sectname2sectnum(sect);
if (length(i))

  reflevel(i)=length(glevels);

  eval(['load ',sectfiles(i,:),' binPair_vel']);
  Vmag=vmag(i)*ones(1,size(binPair_vel,2));
  RV=rv(i)*ones(length(Vmag),1)';

  RV(1:length(RV))=.22; % gives .8 Sv, 28.84 Gg/s salt.
  for bl=1:length(Vmag);
    Vmag(bl)=.05;
  end;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% a05fs (Florida Strait).
sect='a05fs.mat';
i=sectname2sectnum(sect);
if (length(i))

  reflevel(i)=length(glevels); %bottom

  %%Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  eval(['load ',sectfiles(i,:),' binPair_vel']);
  Vmag=.15*ones(1,size(binPair_vel,2));

  RV=rv(i)*ones(length(Vmag),1)';
  RV(1:length(RV))=.285;  % 31 Sv through Florida Strait
  for bl=1:length(Vmag);
    Vmag(bl)=.15;
  end;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ar01fs (Florida Strait).
sect='ar01fs.mat';
i=sectname2sectnum(sect);
if (length(i))

  %q=find(glevels>=28.358); reflevel(i)=q(1); %bottom
  reflevel(i)=length(glevels); %bottom

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';
  RV(1:length(RV))=.307;  % 31 Sv through Florida Strait
  for bl=1:length(Vmag);
    %Vmag(bl)=max([Vmag(bl) .1]);
    Vmag(bl)=.15;
  end;
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% Florida Strait 26N (Abaco 2003 cruise)
sect='fs_south';
i=sectname2sectnum(sect);
if (length(i))
  reflevel(i)=length(glevels);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';
  RV(1:length(RV))=-.1917;   % 31 Sv north
  for bl=1:length(Vmag);
    %Vmag(bl)=max([Vmag(bl) .1]);
    Vmag(bl)=.15;
  end;
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% Florida Strait 27N (Abaco 2003 cruise)
sect='fs_north';
i=sectname2sectnum(sect);
if (length(i))
  reflevel(i)=length(glevels);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';
  RV(1:length(RV))=.173;   % 31 Sv north
  for bl=1:length(Vmag);
    %Vmag(bl)=max([Vmag(bl) .1]);
    Vmag(bl)=.15;
  end;
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% NW Providence Channel (Abaco 2003 cruise)
sect='providence';
i=sectname2sectnum(sect);
if (length(i))
  reflevel(i)=length(glevels);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';
  RV(1:length(RV))=+.103;   % 0 Sv net
  for bl=1:length(Vmag);
    %Vmag(bl)=max([Vmag(bl) .1]);
    Vmag(bl)=.15;
  end;
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% a05int (24.5 deg. N).
%   Increase the magnitude of reference
%   velocities against the western slope
sect='a05int.mat';
i=sectname2sectnum(sect);
if (length(i))

  % 3000 dbar ref level (Rintoul and Wunsch 1991)
  refp=3000;
  load /phod007/lumpkin/dobox/sections/a05int_raw ...
	bin_press surf_press;
  d=(refp-nanmean(surf_press')').^2;
  reflevel(i)=find(d==min(d));
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  % shift RV to zero the thermal wind profile at 3000dbar
  reflevel(i)=length(glevels); 	% must be set to bottom
				% for isobaric code to work!
  load /phod007/lumpkin/dobox/sections/a05int_raw ...
         binPair_vel lon bin_press bottom
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  bottom=[bottom(1:length(bottom)-1),bottom(2:length(bottom))];
  bottom=nanmin(bottom')';
  for j=1:length(lon);
    q=find(isfinite(binPair_vel(:,j)));
    binPair_vel(:,j)=binPair_vel(:,j)- ...
        binPair_vel(last(q),j);
  end;
  q=find(bin_press==refp);
  q2=find(bottom>refp);
  RV(q2)=RV(q2)-binPair_vel(q,q2);
  q=find(isnan(RV(q2)));RV(q2(q))=0;

  % balance Ekman and FS flow: want 35.3 Sv south:
  %	4.3Sv N Ekman + 31.0 Sv N in Florida Strait
  RV=RV-8.7e-4;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ar01int (24.5 deg. N, EB at nearly 28N).
%   Increase the magnitude of reference
%   velocities against the western slope
sect='ar01int.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=27.77); reflevel(i)=q(1); % AAIW/NADW int.
  disp('warning: ar01int is not consistent with a05int');
  disp('  in uniquerefvels.m')

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  RV=rv(i)*ones(length(Vmag),1)';
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% a06 (7.5 deg. N).
sect='a06.mat';
i=sectname2sectnum(sect);
if (length(i))

  %q=find(glevels>=27.74); reflevel(i)=q(1); % AAIW/NADW int.
	% mean level pressure: 1200dbar
  q=find(glevels>=28.05); reflevel(i)=q(1);
	% mean level pressure: 2700dbar

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),150,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  % balance Ekman: 
  %RV=RV+.0019;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ar07ed_ebc: Cape Farvel to Ireland, including
% 	an "EBC" tail closing the Porcupine Bank
%	to Ireland gap.
sect='ar07ed_ebc';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=27.879); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  % 15 Sv, pairs 1-5:
  RV(1)=-.1;RV(2)=-.2;RV(3)=-.3; RV(4)=-.04;RV(5)=-.03;
  % 32 Sv, pairs 1-12:
  RV(6:8)=-.035;

  % Bersch: 25-35 cm/s surface current against Porcupine Bank
  RV(50)=.18; RV(51)=.08;

  RV=RV+1.5e-3;      % close salt and mass balance (incl. Ek)

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% a01e: Cape Farvel to Ireland, including
%       an "EBC" tail closing the Porcupine Bank
%       to Ireland gap.
sect='a01e';
i=sectname2sectnum(sect);
if (length(i))
  q=find(glevels>=27.879); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  % 15 Sv, pairs 1-5:
  RV(1)=-.1;RV(2)=-.2;RV(3)=-.3; RV(4)=-.05;RV(5)=-.03;
  % 32 Sv, pairs 1-12:
  RV(6:8)=-.035;RV(9)=-.028;
  %for bl=1:3; Vmag(bl)=max([Vmag(bl) .3]); end;
  %for bl=4:9; Vmag(bl)=max([Vmag(bl) .05]); end;

  % Bersch: 25-35 cm/s surface current against Porcupine Bank
  RV(50)=.1;
  %for bl=49:50; Vmag(bl)=max([Vmag(bl) .2]); end;

  RV=RV+2.33e-3;     % close mass (including Ekman)

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ar07e_g: Cape Farvel to Ireland, including
%       an "EBC" tail closing the Porcupine Bank
%       to Ireland gap.
sect='ar07e_g';
i=sectname2sectnum(sect);
if (length(i))
  q=find(glevels>=27.879); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  % 15 Sv, pairs 1-5:
  RV(1)=-.1;RV(2)=-.2;RV(3)=-.3; RV(4)=-.05;RV(5)=-.03;
  % 32 Sv, pairs 1-12:
  RV(6:9)=-.035;RV(10)=-.016;
  %for bl=1:3; Vmag(bl)=max([Vmag(bl) .3]); end;
  %for bl=4:9; Vmag(bl)=max([Vmag(bl) .05]); end;

  % Bersch: 25-35 cm/s surface current against Porcupine Bank
  RV(50)=.28;RV(51)=.2;
  %for bl=50:51; Vmag(bl)=max([Vmag(bl) .3]); end;

  RV=RV-1.91e-3;     % close mass (including Ekman)

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ar07e_h: Cape Farvel to Ireland, including
%       an "EBC" tail closing the Porcupine Bank
%       to Ireland gap.
sect='ar07e_h';
i=sectname2sectnum(sect);
if (length(i))
  q=find(glevels>=27.879); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  % 15 Sv, pairs 1-5:
  RV(1)=-.1;RV(2)=-.2;RV(3)=-.29; RV(4)=-.04;RV(5)=-.03;
  % 32 Sv, pairs 1-12:
  RV(6:8)=-.035;RV(9)=-.03;
  %for bl=1:3; Vmag(bl)=max([Vmag(bl) .3]); end;
  %for bl=4:9; Vmag(bl)=max([Vmag(bl) .05]); end;

  % Bersch: 25-35 cm/s surface current against Porcupine Bank
  RV(50)=.17;RV(51)=.27;
  %for bl=50:51; Vmag(bl)=max([Vmag(bl) .3]); end;

  RV=RV-8.2e-4;     % close mass (including Ekman)

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%% Labrador Sea    %%%%%%%%%%%%%
% Lazier and Wright, 1993: the Lab. Current is 11.0 Sv,
% with a width of 100km.

sect='ar07w_a.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=27.949); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.2);
  RV=rv(i)*ones(length(Vmag),1)';
  % allow relatively strong EBC corrections
  %for bl=1:6; Vmag(bl)=max([Vmag(bl) .25]); end;

  % Lazier and Wright, 1993: the Lab. Current is
  % 11.0 Sv, of which 7.2 Sv is BT and concentrated
  % in the main core of the Lab. Current
  % Add 14 cm/s to main core:
  RV(16:17)=.14;  % 11.0 Sv for pairs 16-23
  %Vmag(16:17)=max([Vmag(16:17) .2]);

  % Lazier and Wright: the total export in
  % the western Lab Sea, including the DWBC,
  % is 37~Sv.  This may be obtained by BC +
  % a BT component of 15 cm/s on the 2500m
  % isobath, decaying linearly to 0 over 140km.
  RV(15)=.1; RV(14)=.05; RV(13)=.01; 
  %Vmag(13:15)=max([Vmag(13:15) .15]);

  % this produces 11.9 Sv of gamma>28 in pairs 7-15
  % (export from Lab Sea).  The BC import in
  % the DBC is only 9.8 Sv.
  % Add a BT component to get -11.9 Sv.
  RV(4:6)=-.026;

  % finally, balance net in West Greenland Current
  RV(3)=-.229;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%% Denmark Strait  %%%%%%%%%%%%%
%
% Over the deepest part of this section,
% direct current measurements [Ross, 1975;
% Aagaard & Malmberg, 1978] give a mean
% southward speed of 50-60 cm/s.
% 
% Probably the best estimate of absolute
% currents here is from Girton, Sanford and Kaese (2001)
% ( http://ohm.apl.washington.edu/%7Egirton/dso/figs2.html )
% 60 cm/s core of barotropic jet over sill

sect='ar18e1.mat';
i=sectname2sectnum(sect);
if (length(i))

  reflevel(i)=length(glevels);	% bottom ref level

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';

  % Irminger Current (pairs 1:5):
  %     -0.9 Sv (northward) in layers 1-15
  RV(1:5)=-.144;
  %for bl=1:5; Vmag(bl)=max([Vmag(bl) .2]); end;

  % Barotropic jet west of channel.
  % 2.9Sv (this gives 3.0) at sig_theta>27.8, layers 27-45;
  % .9 Sv in layers 27-37, 2.0 Sv in layers 38-45.
  % [Girton et al. 2001].  This gives 0.86, 2.07 respectively.
  RV(10)=.22;RV(9)=.21; RV(8)=.04;
  for bl=7:10; Vmag(bl)=max([Vmag(bl) .3]); end;

  % EGC: 1.6 Sv (southward) polar water (layers 1-15 west
  % of the Irminger Current, stn. pairs 7-21).
  RV(19:21)=-.004;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%% Iceland-Scotland Ridge %%%%%%%%%%%%%%
sect='ice2scot.mat';
i=sectname2sectnum(sect);

if (length(i))

  q=find(glevels>=27.879); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';

  % add BT velocity in FBC to get 1.4 Sv overflow at
  % sig_thet>27.975 (gamma>28.145) [Mauritzen, 1996;
  %  Osterhus et al., 1999; Price et al., 2001]
  RV(15)=.47;
  Vmag(15)=max([Vmag(15) .4]);

  % -4 Sv (northward) SPMW (layers 1-20) across
  % Iceland-Faroe Rise (pairs 19-32) [Hansen et al 1999]
  RV(19:29)=-.045;	% adjust in pairs 19:29 against Iceland
  
  % simultaneously, .7 to 1 Sv denser (including
  % N. Iceland Winter Water) passing S over Rise
  RV(31:32)=.09;		% this gives 1.03 Sv, 
			%   layers 21:45 pairs 19:32
  %for bl=31:32; Vmag(bl)=max([Vmag(bl) .15]); end;

  % -3 Sv SPMW over Wyville-Thomson Ridge
  % (pairs 1-9) - but adjust against Hebridian Shelf
  % [Hansen et al 1999]
  RV(1:3)=-.035;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ar16d : Gulf of Cadiz
sect='ar16d.mat';
i=sectname2sectnum(sect);
if (length(i))
  reflevel(i)=length(glevels);	% bottom
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';

  load /phod007/lumpkin/dobox/sections/ar16d_raw lat
  lat=lat(1:length(lat)-1)+diff(lat)/2;

  % shift to cancel net flow at sub-NACW densities
  % (<7 degC; gamma>=27.94)
  q=find(lat>33.85 & lat<36.2); RV(q)=RV(q)-5e-3;
  q=find(lat>34 & lat<34.5); RV(q)=5e-3;
  % 2 Sv outflow in layers 15-20, met by magnifying
  % westward flow against Spain
  q=find(lat>36.2 & lat<36.75); RV(q)=.02;
  % eastward flow of surface water against Africa
  % to balance net Ekman (0.15Sv west)
  q=find(lat<33.85); RV(q)=-1.6e-1;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

sect='gibraltar.mat';
i=sectname2sectnum(sect);
if (length(i))
  q=find(glevels>=27.4); reflevel(i)=q(1);
  eval(['load ',sectfiles(i,:),' binPair_vel']);
  Vmag=.15*ones(1,size(binPair_vel,2));
  RV=rv(i)*ones(length(Vmag),1)';

  % .7 Sv Med water (S>36.4, layers 14-45) outflow
  %  (Baringer and Price, JPO27 p1654, 1997)
  RV(3:4)=-2e-1;
  % 0 Sv net exchange
  RV=RV+5e-2;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% a02_94: 48N
sect='a02_94.mat';
i=sectname2sectnum(sect);
if (length(i))
  q=find(glevels>=27.879); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  RV(1:4)=RV(1:4)-.2;   % balance Ekman in WBC

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% ar19a: 48N
% Reference: Clarke, Watts, Hendry and Yashayaer ACM6 poster (CWHY)
sect='ar19a.mat';
i=sectname2sectnum(sect);
if (length(i))
  q=find(glevels>=27.879); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);

  RV=rv(i)*ones(length(Vmag),1)';
  RV=RV-5.3e-4;		% balance southward Ekman

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;
% ar19c: 48N
sect='ar19c.mat';
i=sectname2sectnum(sect);
if (length(i))
  q=find(glevels>=27.879); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  RV=rv(i)*ones(length(Vmag),1)';
  RV=RV-4.3e-4;         % balance southward Ekman
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;
% ar19d: 48N
sect='ar19d.mat';
i=sectname2sectnum(sect);
if (length(i))
  q=find(glevels>=27.879); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  RV=rv(i)*ones(length(Vmag),1)';
  RV=RV-1e-4;         % balance southward Ekman
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;
% ar19f: 48N
sect='ar19f.mat';
i=sectname2sectnum(sect);
if (length(i))
  q=find(glevels>=27.879); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  RV=rv(i)*ones(length(Vmag),1)';
  RV=RV-1.02e-3;         % balance southward Ekman
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;
% a02_97: 48N
sect='a02_97.mat';
i=sectname2sectnum(sect);
if (length(i))
  q=find(glevels>=27.879); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  RV=rv(i)*ones(length(Vmag),1)';
  RV=RV-1.16e-3;         % balance southward Ekman
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% i05p: 32S
sect='i05p.mat';
i=sectname2sectnum(sect);
if (length(i))
  q=find(glevels>=28.11); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  % constraints from Ganachaud (1999)
  load /phod007/lumpkin/dobox/sections/i05p_raw lon
  lon=lon(1:length(lon)-1)+diff(lon)/2;

  % Natal Valley (pairs 1-13) AABW (gamma>28.11) cul-de-sac
  q=find(lon>32 & lon<33.3); RV(q)=.001;
  % 1 Sv AABW (gamma>28.11) into Mozambique Basin (pairs 15-28)
  %   NOTE: this gives 2.3Sv, but smaller values produce
  %   net southward advection in densest layers 42, 43.
  q=find(lon>36.7 & lon<37.6); RV(q)=.03;
  % Madagascar Basin (pairs 29-40) AABW (") cul-de-sac
  q=find(lon>47 & lon<55); RV(q)=-.0011;
  % Adjust to cancel 1.2 Sv southward flow of
  % bottom water between 56 and 69E
  q=find(lon>56 & lon<69); RV(q)=.001;
  % Central Basin (pairs 58-68) AABW (") cul-de-sac
  q=find(lon>78 & lon<88); RV(q)=.0002;

  % balance net to get PIT (10Sv S) -Ek (.9Sv N),
  %     i.e. to get a net southward transport of 10.9Sv.
  RV=RV+1.2e-3;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% ir06d: 1992 JADE section from Indonesia to Australia
sect='ir06d.mat';
i=sectname2sectnum(sect);
if (length(i))

  % bottom reference level
  reflevel(i)=length(glevels);
  %Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';
  load /phod007/lumpkin/dobox/sections/ir06d_raw lat
  lat=lat(1:length(lat)-1)+diff(lat)/2;

  % net mass transport 10Sv west against Australia
  q=find(lat<-16.6);
  RV(q)=RV(q)+3e-2;
  % No net transport in incredibly thick layer 39
  % actually, this sets up 0 for layers 37:39
  q=find(lat>-16.6 & lat<-9);
  RV(q)=RV(q)-6e-4;
  % No net transport below gamma=27.7
  q=find((lat>-18 & lat<-16.6));
  RV(q)=RV(q)+3e-3;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% i02: 11S Madagascar to Australia
sect='i02.mat';
i=sectname2sectnum(sect);
if (length(i))
  q=find(glevels>=28.11); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  RV=rv(i)*ones(length(Vmag),1)';
  load /phod007/lumpkin/dobox/sections/i02_raw lon
  lon=lon(1:length(lon)-1)+diff(lon)/2;

  % 10 Sv southward across western part of section
  %  (Indonesia to Australia)
  q=find(lon>105.6);
  RV(q)=1.55e-3;
  % In other stations, balance Ekman (11.66Sv S-ward)
  % and Mozam.Channel (10Sv S-ward), i.e.
  % get a net northward transport of 22Sv)
  q=find(lon<=105.6);
  RV(q)=-1.95e-3;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% Mozambique: 11S Africa to Madagascar
sect='mozambique.mat';
i=sectname2sectnum(sect);
if (length(i))
  q=find(glevels>=28.11); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),1000,.3);
  RV=rv(i)*ones(length(Vmag),1)';
  load /phod007/lumpkin/dobox/sections/mozambique_raw lon
  lon=lon(1:length(lon)-1)+diff(lon)/2;

  % No net in layers 28-45 (gamma>28.03;
  %     sill depth 2600m in Moz.Channel)
  % NOTE: this still leaves 5Sv, but stronger
  % adjustment is worse for layers>33
  q=find(lat<-5.3 & lat>-11.2);
  RV(q)=7e-3;

  % Adjust against Africa to get net southward
  % flow of 10Sv (see i04)
  q=find(lon<42);
  RV(q)=.054;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% i04: 24.6S, Africa to Mozambique
sect='i04.mat';
i=sectname2sectnum(sect);
if (length(i))
  q=find(glevels>=28.11); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),1000,.3);
  RV=rv(i)*ones(length(Vmag),1)';
  load /phod007/lumpkin/dobox/sections/i04_raw lon
  lon=lon(1:length(lon)-1)+diff(lon)/2;

  % No net in layers 28-45 (gamma>28.03;
  %     sill depth 2600m in Moz.Channel)
  q=find(lon>41 & lon<43.6);
  RV(q)=2e-3;

  % adjust against Africa and Madagascar
  % to get southward net of 10Sv
  % (see summary values in Chapman et al proposal)
  q=find(lon<=36.25 | lon>43.75);
  RV(q)=RV(q)-.115;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% p06: 32S
sect='p06.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=28.11); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  RV=rv(i)*ones(length(Vmag),1)';
  % S New Cal. Trough (162-168E): cul-de-sac for
  % gamma>27.9 (lay22-45) 
  q=find(lon>=162.5 & lon<=166.5);
  RV(q)=-.0013;
  % 16 Sv (layers 21-45) N against Kermadec Ridge
  %     as seen by PCM9 (179-168W; pairs 64:90)
  q=find(lon>=-178.6 & lon<=-177.1);
  RV(q)=0.0255;
  % Balance net to get PIT (10Sv N) - Ek (.6 Sv N)= 9.4Sv N
  RV=RV-3.1e-4;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% p03: 24N
sect='p03.mat';
i=sectname2sectnum(sect);
if (length(i))

  % 2000 dbar ref level (Roemmich and McCallister 1989)
  refp=2000;
  load /phod007/lumpkin/dobox/sections/p03_raw ...
        bin_press surf_press bottom;
  d=(refp-nanmean(surf_press')').^2;
  reflevel(i)=find(d==min(d));
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),250,.4);
  RV=rv(i)*ones(length(Vmag),1)';

  % shift RV to zero the thermal wind profile at refp
  reflevel(i)=length(glevels);  % must be set to bottom
                                % for isobaric code to work!
  load /phod007/lumpkin/dobox/sections/p03_raw ...
         binPair_vel lon bin_press
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  for j=1:length(lon);
    q=find(isfinite(binPair_vel(:,j)));
    binPair_vel(:,j)=binPair_vel(:,j)- ...
        binPair_vel(last(q),j);
  end;
  q=find(bin_press==refp);
  q2=find(bottom>refp);
  RV(q2)=RV(q2)-binPair_vel(q,q2);
  q=find(isnan(RV(q2)));RV(q2(q))=0;

  % No transport at gamma>27.52 (1200m) in Okinawa Trough
  %  (125-127E, pairs 193-205 ; Ganachaud 1999)
  q=find(lon>125 & lon<127);
  RV(q)=3e-3;
  % No transport at gamma>28.04 (3100m) in N.Phil. Basin
  %  (127-141E, pairs 163-193 ; Ganachaud 1999)
  q=find(lon>127 & lon<141);
  RV(q)=-3.5e-4;
  % Balance Ekman (8.26 Sv south)
  RV=RV-5e-5;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% p01: 45N
sect='p01.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=28.1); reflevel(i)=q(1);
  load /phod007/lumpkin/dobox/sections/p01_raw ...
         binPair_vel lon bin_press
  lon=lon(1:length(lon)-1)+diff(lon)/2;

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  % No transport at gamma>28.1 in Kural Trench
  %  (145-147E, pairs 1-14; Ganachaud 1999)
  q=find(lon>145 & lon<147);
  RV(q)=6e-3;

  % Balance Ekman (Ek=3.96 Sv south) 
  RV=RV-7e-4;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% s4 - circumpolar section isolating Antarctica
sect='s4comp.mat';
i=sectname2sectnum(sect);
if (length(i))
  % reference level: 0 deg C. CDW/WSDW interface
  q=find(glevels>=28.292); reflevel(i)=q(1);
  % 24 Jan 03: moved to 28.27 as per request from Alex Orsi
  % 27 Jan 03: moved to bottom ref level, re:Alex's input
  % (CURRENTLY UNDONE)
  %reflevel(i)=length(glevels);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  load /phod007/lumpkin/dobox/sections/s4comp_raw ...
	 binPair_vel lon bin_press bottom surf_press;
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  bottom=bottom(1:length(bottom)-1)+diff(bottom)/2;
  
  for j=1:length(lon);
      if isfinite(surf_press(reflevel(i),j)) % reflev above bottom
          zind=(bin_press-surf_press(reflevel(i),j)).^2;
          zind=find(zind==min(zind));
          binPair_vel(:,j)=binPair_vel(:,j)- ...
              binPair_vel(zind,j);
      else  % reflevel too dense to be defined for this pair
          q=find(isfinite(binPair_vel(:,j)));
          binPair_vel(:,j)=binPair_vel(:,j)- ...
	        binPair_vel(last(q),j);
      end;
  end;
  % shift ref level to bottom where bottom>=1000m,
  %  and to surface where bottom<1000m or where,
  % on South Scotia Ridge (-60<=lon<-42), bottom<2000
  for j=1:length(lon);
      q=find(isfinite(binPair_vel(:,j)));
      if (bottom(j)>=1000 & (lon(j)<-60 | lon(j)>-42))
          % bottom ref level
          %RV(j)=RV(j)-binPair_vel(last(q),j);
      elseif (bottom(j)>=2000) % bottom for these SSR pairs
          %RV(j)=RV(j)-binPair_vel(last(q),j);
      else  % shallow: surface ref level
          RV(j)=RV(j)-binPair_vel(1,j);
      end;
  end;  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

clear sect i;

% s4_pac
sect='s4_pac.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  % reference level: 0 deg C. CDW/WSDW interface
  q=find(glevels>=28.292); reflevel(i)=q(1);
  % 24 Jan 03: moved to 28.27 as per request from Alex Orsi
  q=find(glevels>=28.27); reflevel(i)=q(1);
  % 27 Jan 03: moved to bottom ref level, re:Alex's input
  % (CURRENTLY UNDONE)
  %reflevel(i)=length(glevels);

  %%Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  
  RV=rv(i)*ones(length(Vmag),1)';
  
  load /phod007/lumpkin/dobox/sections/s4_pac_raw ...
	 binPair_vel lon bin_press bottom surf_press;
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  bottom=bottom(1:length(bottom)-1)+diff(bottom)/2;
  
  for j=1:length(lon);
      if isfinite(surf_press(reflevel(i),j)) % reflev above bottom
          zind=(bin_press-surf_press(reflevel(i),j)).^2;
          zind=find(zind==min(zind));
          binPair_vel(:,j)=binPair_vel(:,j)- ...
              binPair_vel(zind,j);
      else  % reflevel too dense to be defined for this pair
          q=find(isfinite(binPair_vel(:,j)));
          binPair_vel(:,j)=binPair_vel(:,j)- ...
	        binPair_vel(last(q),j);
      end;
  end;
  % shift ref level to bottom where bottom>=1000m,
  %  and to surface where bottom<1000m or where,
  % on South Scotia Ridge (-60<=lon<-42), bottom<2000
  for j=1:length(lon);
      q=find(isfinite(binPair_vel(:,j)));
      if (bottom(j)>=1000 & (lon(j)<-60 | lon(j)>-42))
          % bottom ref level
          %RV(j)=RV(j)-binPair_vel(last(q),j);
      elseif (bottom(j)>=2000) % bottom for these SSR pairs
          %RV(j)=RV(j)-binPair_vel(last(q),j);
      else  % shallow: surface ref level
          RV(j)=RV(j)-binPair_vel(1,j);
      end;
  end;  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% s4_atl
sect='s4_atl.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  % reference level: 0 deg C. CDW/WSDW interface
  q=find(glevels>=28.292); reflevel(i)=q(1);
  % 24 Jan 03: moved to 28.27 as per request from Alex Orsi
  q=find(glevels>=28.27); reflevel(i)=q(1);
  % 27 Jan 03: moved to bottom ref level, re:Alex's input
  % (CURRENTLY UNDONE)
  %reflevel(i)=length(glevels);

  %%Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),150,.3);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';

  load /phod007/lumpkin/dobox/sections/s4_atl_raw ...
	 binPair_vel lon bin_press bottom surf_press;
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  bottom=bottom(1:length(bottom)-1)+diff(bottom)/2;
  
  for j=1:length(lon);
      if isfinite(surf_press(reflevel(i),j)) % reflev above bottom
          zind=(bin_press-surf_press(reflevel(i),j)).^2;
          zind=find(zind==min(zind));
          binPair_vel(:,j)=binPair_vel(:,j)- ...
              binPair_vel(zind,j);
      else  % reflevel too dense to be defined for this pair
          q=find(isfinite(binPair_vel(:,j)));
          binPair_vel(:,j)=binPair_vel(:,j)- ...
	        binPair_vel(last(q),j);
      end;
  end;
  % shift ref level to bottom where bottom>=1000m,
  %  and to surface where bottom<1000m or where,
  % on South Scotia Ridge (-60<=lon<-42), bottom<2000
  for j=1:length(lon);
      q=find(isfinite(binPair_vel(:,j)));
      if (bottom(j)>=1000 & (lon(j)<-60 | lon(j)>-42))
          % bottom ref level
          %RV(j)=RV(j)-binPair_vel(last(q),j);
      elseif (bottom(j)>=2000) % bottom for these SSR pairs
          %RV(j)=RV(j)-binPair_vel(last(q),j);
      else  % shallow: surface ref level
          RV(j)=RV(j)-binPair_vel(1,j);
      end;
  end;  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% s4_ind
sect='s4_ind.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  % reference level: 0 deg C. CDW/WSDW interface
  q=find(glevels>=28.27); reflevel(i)=q(1);
  % 24 Jan 03: moved to 28.27 as per request from Alex Orsi
  q=find(glevels>=28.27); reflevel(i)=q(1);
  % 27 Jan 03: moved to bottom ref level, re:Alex's input
  % (CURRENTLY UNDONE)
  %reflevel(i)=length(glevels);

  %%Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';

  load /phod007/lumpkin/dobox/sections/s4_ind_raw ...
	 binPair_vel lon bin_press bottom surf_press;
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  bottom=bottom(1:length(bottom)-1)+diff(bottom)/2;
  
  for j=1:length(lon);
      if isfinite(surf_press(reflevel(i),j)) % reflev above bottom
          zind=(bin_press-surf_press(reflevel(i),j)).^2;
          zind=find(zind==min(zind));
          binPair_vel(:,j)=binPair_vel(:,j)- ...
              binPair_vel(zind,j);
      else  % reflevel too dense to be defined for this pair
          q=find(isfinite(binPair_vel(:,j)));
          binPair_vel(:,j)=binPair_vel(:,j)- ...
	        binPair_vel(last(q),j);
      end;
  end;
  % shift ref level to bottom where bottom>=1000m,
  %  and to surface where bottom<1000m or where,
  % on South Scotia Ridge (-60<=lon<-42), bottom<2000
  for j=1:length(lon);
      q=find(isfinite(binPair_vel(:,j)));
      if (bottom(j)>=1000 & (lon(j)<-60 | lon(j)>-42))
          % bottom ref level
          %RV(j)=RV(j)-binPair_vel(last(q),j);
      elseif (bottom(j)>=2000) % bottom for these SSR pairs
          %RV(j)=RV(j)-binPair_vel(last(q),j);
      else  % shallow: surface ref level
          RV(j)=RV(j)-binPair_vel(1,j);
      end;
  end;  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% sr03c Tasmania to Antarctica
sect='sr03c';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
              % bottom reference level
  reflevel(i)=length(glevels);
  load /phod007/lumpkin/dobox/sections/sr03c_raw ...
         binPair_vel surf_press
         
  %%Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,.3);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=zeros(length(Vmag),1)';
  for j=1:size(binPair_vel,2);
      if (isfinite(surf_press(reflevel(i),j)))
          q=find(bin_press==round(surf_press(reflevel(i),j)));
          q2=find(isfinite(binPair_vel(:,j)));
          RV(j)=RV(j)-binPair_vel(last(q2),j)+binPair_vel(q,j);
      end;
  end;
  
  %load /export/lasalle1/hydrography/WOCE/SR03c/sr03c_bvel;
  %RV=RV+bvel;
  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% indant - the piece of SR03c from S4 to the Antarctic
sect='indant';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
                  % bottom reference level
  reflevel(i)=length(glevels);
  load /phod007/lumpkin/dobox/sections/indant_raw ...
         binPair_vel surf_press
         
  %%Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,.3);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=zeros(length(Vmag),1)';
  for j=1:size(binPair_vel,2);
      if (isfinite(surf_press(reflevel(i),j)))
          q=find(bin_press==round(surf_press(reflevel(i),j)));
          q2=find(isfinite(binPair_vel(:,j)));
          RV(j)=RV(j)-binPair_vel(last(q2),j)+binPair_vel(q,j);
      end;
  end;
  
  %shift ref level to 2000dbar (Heywood et al. 1998)
  %refp=2000;
  %q=min(find(bin_press>=refp));
  %q2=7:10;
  %RV(q2)=RV(q2)-binPair_vel(q,q2);
  %q=find(isnan(RV(q2)));
  %RV(q2(q))=0;

  %courant de bord a 10 SV
  RV(1:6)=RV(1:6)+0.07;
  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% I06b (CIVA - S. africa to S4)
sect='i06b';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
      % bottom reference level
  reflevel(i)=length(glevels);
  load /phod007/lumpkin/dobox/sections/i06b_raw ...
         binPair_vel surf_press
         
  %%Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,.3);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=zeros(length(Vmag),1)';
  for j=1:size(binPair_vel,2);
      if (isfinite(surf_press(reflevel(i),j)))    
          q=(bin_press-surf_press(reflevel(i),j)).^2;
          q=find(q==min(q));
          q2=find(isfinite(binPair_vel(:,j)));
          RV(j)=RV(j)-binPair_vel(last(q2),j)+binPair_vel(q,j);
      end;
  end;
  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% I06bs (CIVA - S4 to Antarctica)
sect='i06bs';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
          % bottom reference level
  reflevel(i)=length(glevels);
  load /phod007/lumpkin/dobox/sections/i06bs_raw ...
         binPair_vel surf_press
          
  %%Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,.3);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=zeros(length(Vmag),1)';
  for j=1:size(binPair_vel,2);
      if (isfinite(surf_press(reflevel(i),j)))
          q=(bin_press-surf_press(reflevel(i),j)).^2;
          q=find(q==min(q));
          q2=find(isfinite(binPair_vel(:,j)));
          RV(j)=RV(j)-binPair_vel(last(q2),j)+binPair_vel(q,j);
      end;
  end;

  % Add bottom velocities in the boundary current to create a
  % 10 SV WBC (Heywood et al. 1998).
  RV(1:5)=RV(1:5)+0.125;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;
    
% A21: Drake Passage segment
sect='drake90';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  % bottom reference level
  reflevel(i)=length(glevels);
  load /phod007/lumpkin/dobox/sections/drake90_raw ...
         binPair_vel surf_press
         
  %%Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,.3);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=zeros(length(Vmag),1)';
  for j=1:size(binPair_vel,2);
      if (isfinite(surf_press(reflevel(i),j)))
          q=(bin_press-surf_press(reflevel(i),j)).^2;
          q=find(q==min(q));
          q2=find(isfinite(binPair_vel(:,j)));
          RV(j)=RV(j)-binPair_vel(last(q2),j)+binPair_vel(q,j);
      end;
  end;
  
  % Add Gille's bottom reference profile
  %load /export/lasalle1/hydrography/WOCE/A21/drake90_bvel
  %RV=RV+bvel;
  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% Wedsea: german section in Weddell Sea
sect='wedsea';
i=sectname2sectnum(sect,sectfiles);
if (length(i))

  % reference level=level 44
  %q=find(glevels>=28.37); reflevel(i)=q(1);
  
  reflevel(i)=length(glevels);
  %%Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.3);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';
  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;


clear sect i;
