% uniquerefvels.m
%
% Define a set of inhomogeneous initial reference 
% velocities and a priori magnitudes of corrections for
% particular sections.

% directory containing dobox-prepared section data
sectdir='/phod007/lumpkin/dobox/sections';

% load defined levels, layers
glev;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% a08 (11 deg. S).
%
% Initial reference levels from Speer, Holfort,
%	Reynaud and Siedler (1996).
sect='a08.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))

  refp=3900;
  eval(['load ',sectdir,'/a08_raw bin_press surf_press']);
  d=(refp-nanmean(surf_press')').^2;
  reflevel(i)=find(d==min(d));

  Vmag=defVmag(sectfiles(i,:),reflevel(i),.01,100,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  % shift reference level to isobaric surfaces
  % (ASSUMES BOTTOM REFERENCE LEVEL)
  reflevel(i)=length(glevels);  % must be set to bottom
                                % for isobaric code to work!
  eval(['load ',sectdir,'/a08_raw bin_press lon binPair_vel']);              
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  for j=1:length(lon);
    q=find(isfinite(binPair_vel(:,j)));
    binPair_vel(:,j)=binPair_vel(:,j)- ...
	binPair_vel(last(q),j);
  end;

  % shift ref level to 1100m west of 35.5W
  q=find(bin_press==1100);
  q2=find(lon<=-35.5);
  RV(q2)=RV(q2)-binPair_vel(q,q2);
  q=find(isnan(RV(q2)));RV(q2(q))=0;
  %RV(3)=-.2886;

  % shift ref level to 3800m between 35.5W and 17.67W
  % (Brazil Basin)  (stations 4:6 stay bottom-referenced)
  q=find(bin_press==3800);
  q2=find(lon>=-35.5 & lon<=-17.67);
  RV(q2)=RV(q2)-binPair_vel(q,q2);
  q=find(isnan(RV(q2)));RV(q2(q))=0;

  % shift ref level to 2400m between 17.67W and 10.17W (MAR)
  q=find(bin_press==2400);
  q2=find(lon>=-17.67 & lon<=-10.17);
  RV(q2)=RV(q2)-binPair_vel(q,q2);
  q=find(isnan(RV(q2)));RV(q2(q))=0;

  % shift ref level to 4000m east of 10.17W (Angola Basin)
  q=find(bin_press==4000);
  q2=find(lon>=-10.17);
  RV(q2)=RV(q2)-binPair_vel(q,q2);
  q=find(isnan(RV(q2)));RV(q2(q))=0;

  % uniform shift to balance Ekman (9.71Sv south)
  RV=RV-1.23e-4;

  clear binPair_vel lon bin_press q q2

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);

end;

%%%%%%%%%%%%%%%%
% a10 (30 deg S.
sect='a10.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))

  q=find(glevels>=28.175); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),.01,200,.3);
  RV=rv(i)*ones(length(Vmag),1)';
  
  eval(['load ',sectdir,'/a10_raw lon']);
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  % Brazil Current (inshore): 25 Sv south
  q=find(lon<-46.4); RV(q)=-.195;
  % Brazil Current recirc: 7.5 Sv north
  q=find(lon>-46.4 & lon<-44.8); RV(q)=.015;
  
  % Vema Channel AABW (gam>28.175): 2 Sv north
  %q=find(lon<-35.8); RV(q)=RV(q)+0;  % already satisfied
  % Brazil Basin AABW: 3 Sv north
  q=find(lon>-33 & lon<-17.8);RV(q)=RV(q)+.003;
  % Cape Basin AABW: 0 Sv (blocked by Walvis)
  %q=find(lon>-3); RV(q)=RV(q)+0;  % already satisfied

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% a11 (45-30 deg. S).
%
% Primary reference Saunders and King, 1995
%   ref level sig_3=41.58, gam=28.173-28.178
%	Note: not including Zapiola anticyclone
%	 in a priori field (see SK95 pg.1951).
sect='a11.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))

  q=find(glevels>=28.175); reflevel(i)=q(1);
  
  eval(['load ',sectdir,'/a11_raw lon']);
  lon=lon(1:length(lon)-1)+diff(lon)/2;

  Vmag=defVmag(sectfiles(i,:),reflevel(i),.01,200,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  % 45 Sv WBC (Malvinas Current, pairs 1-5; SK95)
  %q=find(lon<=-58.4); RV(q)=.15;
  q=find(lon>-59.25 & lon<-58.4);RV(q)=.27;

  % -5 Sv EBC (pairs 85-89; SK95)
  q=find(lon>=14.5); RV(q)=-.037;

  % 0 Sv bottom water (gam>28.175) into Cape Basin
  %  (pairs 60:81; blocked by Walvis Ridge) (SK95)
  q=find(lon>=-6 & lon<=12.1); RV(q)=-.0003;

  % 6 Sv bottom water (gam>28.175) into Argentine Basin
  %  (pairs 9-45)
  q=find(lon>=-57.3 & lon<=-21.1); RV(q)=.0013;

  % uniform s-ward flow across station pairs
  %   over MAR to get 0 net flow (-5.4 Sv to balance Ek)
  q=find(lon>=-15.7 & lon<=-12.5);
  retflow=-.022;RV(q)=retflow;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Canadian Archipelago throughflow
sect='arch.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))

  reflevel(i)=length(glevels);

  eval(['load ',sectfiles(i,:),' binPair_vel']);
  Vmag=vmag(i)*ones(1,size(binPair_vel,2));
  RV=rv(i)*ones(length(Vmag),1)';

  RV(1:length(RV))=-.04;  % gives .82 Sv, 28.13 Gg/s salt.
  for bl=1:length(Vmag);
    Vmag(bl)=.05;
  end;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Bering Strait throughflow
sect='bering.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))

  reflevel(i)=length(glevels);

  eval(['load ',sectfiles(i,:),' binPair_vel']);
  Vmag=vmag(i)*ones(1,size(binPair_vel,2));
  RV=rv(i)*ones(length(Vmag),1)';

  RV(1:length(RV))=.22; % gives .8 Sv, 28.84 Gg/s salt.
  for bl=1:length(Vmag);
    Vmag(bl)=.05;
  end;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% a05fs (Florida Strait).
sect='a05fs.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))

  reflevel(i)=length(glevels); %bottom

  Vmag=defVmag(sectfiles(i,:),reflevel(i),.3,-99,-99);
  eval(['load ',sectfiles(i,:),' binPair_vel']);
  Vmag=.15*ones(1,size(binPair_vel,2));

  RV=rv(i)*ones(length(Vmag),1)';
  RV(1:length(RV))=.285;  % 31 Sv through Florida Strait
  for bl=1:length(Vmag);
    Vmag(bl)=.15;
  end;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ar01fs (Florida Strait).
sect='ar01fs.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))

  %q=find(glevels>=28.358); reflevel(i)=q(1); %bottom
  reflevel(i)=length(glevels); %bottom

  Vmag=defVmag(sectfiles(i,:),reflevel(i),.3,-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';
  RV(1:length(RV))=.307;  % 31 Sv through Florida Strait
  for bl=1:length(Vmag);
    %Vmag(bl)=max([Vmag(bl) .1]);
    Vmag(bl)=.15;
  end;
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% Florida Strait 26N (Abaco 2003 cruise)
sect='fs_south';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  reflevel(i)=length(glevels);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.3,-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';
  RV(1:length(RV))=-.1917;   % 31 Sv north
  for bl=1:length(Vmag);
    %Vmag(bl)=max([Vmag(bl) .1]);
    Vmag(bl)=.15;
  end;
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% Florida Strait 27N (Abaco 2003 cruise)
sect='fs_north';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  reflevel(i)=length(glevels);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.3,-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';
  RV(1:length(RV))=.173;   % 31 Sv north
  for bl=1:length(Vmag);
    %Vmag(bl)=max([Vmag(bl) .1]);
    Vmag(bl)=.15;
  end;
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% NW Providence Channel (Abaco 2003 cruise)
sect='providence';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  reflevel(i)=length(glevels);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.3,-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';
  RV(1:length(RV))=+.103;   % 0 Sv net
  for bl=1:length(Vmag);
    %Vmag(bl)=max([Vmag(bl) .1]);
    Vmag(bl)=.15;
  end;
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% a05int (24.5 deg. N).
%   Increase the magnitude of reference
%   velocities against the western slope
sect='a05int.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))

  % 3000 dbar ref level (Rintoul and Wunsch 1991)
  refp=3000;
  eval(['load ',sectdir,'/a05int_raw bin_press surf_press']);
  d=(refp-nanmean(surf_press')').^2;
  reflevel(i)=find(d==min(d));
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.01,100,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  % shift RV to zero the thermal wind profile at 3000dbar
  reflevel(i)=length(glevels); 	% must be set to bottom
				% for isobaric code to work!
  eval(['load ',sectdir,'/a05int_raw binPair_vel lon bin_press bottom']);
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  bottom=[bottom(1:length(bottom)-1),bottom(2:length(bottom))];
  keyboard
  bottom=nanmin(bottom')';
  for j=1:length(lon);
    q=find(isfinite(binPair_vel(:,j)));
    binPair_vel(:,j)=binPair_vel(:,j)- ...
        binPair_vel(last(q),j);
  end;
  q=find(bin_press==refp);
  q2=find(bottom>refp);
  RV(q2)=RV(q2)-binPair_vel(q,q2);
  q=find(isnan(RV(q2)));RV(q2(q))=0;

  % balance Ekman and FS flow: want 35.3 Sv south:
  %	4.3Sv N Ekman + 31.0 Sv N in Florida Strait
  RV=RV-8.7e-4;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ar01int (24.5 deg. N, EB at nearly 28N).
%   Increase the magnitude of reference
%   velocities against the western slope
sect='ar01int.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))

  q=find(glevels>=27.77); reflevel(i)=q(1); % AAIW/NADW int.
  disp('warning: ar01int is not consistent with a05int');
  disp('  in uniquerefvels.m')

  Vmag=defVmag(sectfiles(i,:),reflevel(i),.01,100,.3);
  RV=rv(i)*ones(length(Vmag),1)';
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% a06 (7.5 deg. N).
sect='a06.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))

  %q=find(glevels>=27.74); reflevel(i)=q(1); % AAIW/NADW int.
	% mean level pressure: 1200dbar
  q=find(glevels>=28.05); reflevel(i)=q(1);
	% mean level pressure: 2700dbar

  Vmag=defVmag(sectfiles(i,:),reflevel(i),.01,150,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  % balance Ekman: 
  %RV=RV+.0019;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ar07ed_ebc: Cape Farvel to Ireland, including
% 	an "EBC" tail closing the Porcupine Bank
%	to Ireland gap.
sect='ar07ed_ebc';
i=sectname2sectnum(sect,sectfiles);
if (length(i))

  q=find(glevels>=27.879); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),.05,100,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  % 15 Sv, pairs 1-5:
  RV(1)=-.1;RV(2)=-.2;RV(3)=-.3; RV(4)=-.04;RV(5)=-.03;
  % 32 Sv, pairs 1-12:
  RV(6:8)=-.035;

  % Bersch: 25-35 cm/s surface current against Porcupine Bank
  RV(50)=.18; RV(51)=.08;

  RV=RV+1.5e-3;      % close salt and mass balance (incl. Ek)

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% a01e: Cape Farvel to Ireland, including
%       an "EBC" tail closing the Porcupine Bank
%       to Ireland gap.
sect='a01e';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  q=find(glevels>=27.879); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.05,100,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  % 15 Sv, pairs 1-5:
  RV(1)=-.1;RV(2)=-.2;RV(3)=-.3; RV(4)=-.05;RV(5)=-.03;
  % 32 Sv, pairs 1-12:
  RV(6:8)=-.035;RV(9)=-.028;
  %for bl=1:3; Vmag(bl)=max([Vmag(bl) .3]); end;
  %for bl=4:9; Vmag(bl)=max([Vmag(bl) .05]); end;

  % Bersch: 25-35 cm/s surface current against Porcupine Bank
  RV(50)=.1;
  %for bl=49:50; Vmag(bl)=max([Vmag(bl) .2]); end;

  RV=RV+2.33e-3;     % close mass (including Ekman)

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ar07e_g: Cape Farvel to Ireland, including
%       an "EBC" tail closing the Porcupine Bank
%       to Ireland gap.
sect='ar07e_g';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  q=find(glevels>=27.879); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.05,100,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  % 15 Sv, pairs 1-5:
  RV(1)=-.1;RV(2)=-.2;RV(3)=-.3; RV(4)=-.05;RV(5)=-.03;
  % 32 Sv, pairs 1-12:
  RV(6:9)=-.035;RV(10)=-.016;
  %for bl=1:3; Vmag(bl)=max([Vmag(bl) .3]); end;
  %for bl=4:9; Vmag(bl)=max([Vmag(bl) .05]); end;

  % Bersch: 25-35 cm/s surface current against Porcupine Bank
  RV(50)=.28;RV(51)=.2;
  %for bl=50:51; Vmag(bl)=max([Vmag(bl) .3]); end;

  RV=RV-1.91e-3;     % close mass (including Ekman)

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ar07e_h: Cape Farvel to Ireland, including
%       an "EBC" tail closing the Porcupine Bank
%       to Ireland gap.
sect='ar07e_h';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  q=find(glevels>=27.879); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.05,100,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  % 15 Sv, pairs 1-5:
  RV(1)=-.1;RV(2)=-.2;RV(3)=-.29; RV(4)=-.04;RV(5)=-.03;
  % 32 Sv, pairs 1-12:
  RV(6:8)=-.035;RV(9)=-.03;
  %for bl=1:3; Vmag(bl)=max([Vmag(bl) .3]); end;
  %for bl=4:9; Vmag(bl)=max([Vmag(bl) .05]); end;

  % Bersch: 25-35 cm/s surface current against Porcupine Bank
  RV(50)=.17;RV(51)=.27;
  %for bl=50:51; Vmag(bl)=max([Vmag(bl) .3]); end;

  RV=RV-8.2e-4;     % close mass (including Ekman)

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%% Labrador Sea    %%%%%%%%%%%%%
% Lazier and Wright, 1993: the Lab. Current is 11.0 Sv,
% with a width of 100km.

sect='ar07w_a.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))

  q=find(glevels>=27.949); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),.05,100,.2);
 
  % allow relatively strong EBC corrections
  RV=rv(i)*ones(length(Vmag),1)';
  % allow relatively strong EBC corrections
  %for bl=1:6; Vmag(bl)=max([Vmag(bl) .25]); end;

  % Lazier and Wright, 1993: the Lab. Current is
  % 11.0 Sv, of which 7.2 Sv is BT and concentrated
  % in the main core of the Lab. Current
  % Add 14 cm/s to main core:
  RV(16:17)=.14;  % 11.0 Sv for pairs 16-23
  %Vmag(16:17)=max([Vmag(16:17) .2]);

  % Lazier and Wright: the total export in
  % the western Lab Sea, including the DWBC,
  % is 37~Sv.  This may be obtained by BC +
  % a BT component of 15 cm/s on the 2500m
  % isobath, decaying linearly to 0 over 140km.
  RV(15)=.1; RV(14)=.05; RV(13)=.01; 
  %Vmag(13:15)=max([Vmag(13:15) .15]);

  % this produces 11.9 Sv of gamma>28 in pairs 7-15
  % (export from Lab Sea).  The BC import in
  % the DBC is only 9.8 Sv.
  % Add a BT component to get -11.9 Sv.
  RV(4:6)=-.026;

  % finally, balance net in West Greenland Current
  RV(3)=-.229;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%% Denmark Strait  %%%%%%%%%%%%%
%
% Over the deepest part of this section,
% direct current measurements [Ross, 1975;
% Aagaard & Malmberg, 1978] give a mean
% southward speed of 50-60 cm/s.
% 
% Probably the best estimate of absolute
% currents here is from Girton, Sanford and Kaese (2001)
% ( http://ohm.apl.washington.edu/%7Egirton/dso/figs2.html )
% 60 cm/s core of barotropic jet over sill

sect='ar18e1.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))

  reflevel(i)=length(glevels);	% bottom ref level

  Vmag=defVmag(sectfiles(i,:),reflevel(i),.1,-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';

  % Irminger Current (pairs 1:5):
  %     -0.9 Sv (northward) in layers 1-15
  RV(1:5)=-.144;
  %for bl=1:5; Vmag(bl)=max([Vmag(bl) .2]); end;

  % Barotropic jet west of channel.
  % 2.9Sv (this gives 3.0) at sig_theta>27.8, layers 27-45;
  % .9 Sv in layers 27-37, 2.0 Sv in layers 38-45.
  % [Girton et al. 2001].  This gives 0.86, 2.07 respectively.
  RV(10)=.22;RV(9)=.21; RV(8)=.04;
  for bl=7:10; Vmag(bl)=max([Vmag(bl) .3]); end;

  % EGC: 1.6 Sv (southward) polar water (layers 1-15 west
  % of the Irminger Current, stn. pairs 7-21).
  RV(19:21)=-.004;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%% Iceland-Scotland Ridge %%%%%%%%%%%%%%
sect='ice2scot.mat';
i=sectname2sectnum(sect,sectfiles);

if (length(i))

  q=find(glevels>=27.879); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),.1,-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';

  % add BT velocity in FBC to get 1.4 Sv overflow at
  % sig_thet>27.975 (gamma>28.145) [Mauritzen, 1996;
  %  Osterhus et al., 1999; Price et al., 2001]
  RV(15)=.47;
  Vmag(15)=max([Vmag(15) .4]);

  % -4 Sv (northward) SPMW (layers 1-20) across
  % Iceland-Faroe Rise (pairs 19-32) [Hansen et al 1999]
  RV(19:29)=-.045;	% adjust in pairs 19:29 against Iceland
  
  % simultaneously, .7 to 1 Sv denser (including
  % N. Iceland Winter Water) passing S over Rise
  RV(31:32)=.09;		% this gives 1.03 Sv, 
			%   layers 21:45 pairs 19:32
  %for bl=31:32; Vmag(bl)=max([Vmag(bl) .15]); end;

  % -3 Sv SPMW over Wyville-Thomson Ridge
  % (pairs 1-9) - but adjust against Hebridian Shelf
  % [Hansen et al 1999]
  RV(1:3)=-.035;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ar16d : Gulf of Cadiz
sect='ar16d.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  reflevel(i)=length(glevels);	% bottom
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.1,-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';

  eval(['load ',sectdir,'/ar16d_raw lat']);
  lat=lat(1:length(lat)-1)+diff(lat)/2;

  % shift to cancel net flow at sub-NACW densities
  % (<7 degC; gamma>=27.94)
  q=find(lat>33.85 & lat<36.2); RV(q)=RV(q)-5e-3;
  q=find(lat>34 & lat<34.5); RV(q)=5e-3;
  % 2 Sv outflow in layers 15-20, met by magnifying
  % westward flow against Spain
  q=find(lat>36.2 & lat<36.75); RV(q)=.02;
  % eastward flow of surface water against Africa
  % to balance net Ekman (0.15Sv west)
  q=find(lat<33.85); RV(q)=-1.6e-1;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

sect='gibraltar.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  q=find(glevels>=27.4); reflevel(i)=q(1);
  eval(['load ',sectfiles(i,:),' binPair_vel']);
  Vmag=.15*ones(1,size(binPair_vel,2));
  RV=rv(i)*ones(length(Vmag),1)';

  % .7 Sv Med water (S>36.4, layers 14-45) outflow
  %  (Baringer and Price, JPO27 p1654, 1997)
  RV(3:4)=-2e-1;
  % 0 Sv net exchange
  RV=RV+5e-2;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% a02_94: 48N
sect='a02_94.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  q=find(glevels>=27.879); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.02,100,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  disp('Handle consistently with other 48N section.')
  keyboard
  RV(1:4)=RV(1:4)-.2;   % balance Ekman in WBC

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% ar19a: 48N
sect='ar19a.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  % adjustments to reference velocities from
  % Meinen, 2001: DSR I 48, 1553-1580.
  q=find(glevels>=27.879); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.02,100,.3);
  RV=zeros(length(Vmag),1)';

  eval(['load ',sectdir, ...
          '/ar19a lon bin_press bin_temp lon lat bottom;'])
  mann=-43.85;  % longitude of Mann Eddy center
  bottom=bottom(1:length(lon)-1)+diff(bottom)/2;
  
  % Identify the core of the NAC (where the 10dgC
  % isotherm crosses 450dbar)
  temp=bin_temp(find(bin_press==450),:);
  lonhr=min(lon):.01:max(lon);
  lathr=interp1(lon,lat,lonhr,'linear');
  temp=interp1(lon,temp,lonhr,'linear');
  lon_0=lonhr(min(find(temp>10)));
  lat_0=lathr(min(find(temp>10)));
  % convert lon, lat to pair coordinates
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  lat=lat(1:length(lat)-1)+diff(lat)/2;
  
  % calculate distance (negative=west)
  % between station pairs and NAC core.
  dist=NaN*ones(size(lon));
  for jj=1:length(dist);
    dist(jj)=sw_dist([lat(jj) lat_0], ...
        [lon(jj) lon_0],'km');
    if (lon(jj)<lon_0) dist(jj)=-dist(jj); end;
  end;
  
  % load mean reference velocity on 27.879 surface
  %  (calculated by "calcstreammean.m" in NACpies directory)
  load /phod007/lumpkin/NACpies/48n_refvel d_s v27879
  % rescale so that max(d_s) is at mann eddy center 
  % for this repeat (instead of +200km)
  q=find(d_s>0);
  d_s(q)=d_s(q)/200*interp1(lon,dist,mann);
  % interpolate to dist for this repeat
  v2=interp1(d_s,v27879,dist,'linear');
  % extrapolate westward to shelf break (bottom==500)
  q=find(dist<0 & bottom'>500 & isnan(v2));
  v2(q)=v27879(1);
  % zero bottom ref level inshore of this
  q=find(dist<0 & isnan(v2)); v2(q)=0;
  % zero ref level east of mann eddy center
  v2(find(dist>interp1(lon,dist,mann)))=0;
  
  % match the time-mean net transport from -200km to Mann 
  % center (pairs 4:14):
  %   145 Sv northward - 30 Sv southward = 115 Sv
  %q=find(dist>-200 & lon<mann);
  v2=0.802*v2;
  RV=RV+v2;
  
  % East half of Mann eddy:  55Sv south.
  q=find(lon>=-43.85 & lon<=-41);  % pairs 15:18
  RV(q)=RV(q)-4.21e-2;
  
  % these adjustments give a net transport of 64 Sv north.
  % adjust in interior (west of eastern edge Mann eddy)
  % to get +2.46 Sv (-1*Ekman transport)
  q=19:length(lon); 
  RV(q)=RV(q)-6.59e-3;
  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% ar19c: 48N
sect='ar19c.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  % adjustments to reference velocities from
  % Meinen, 2001: DSR I 48, 1553-1580.
  q=find(glevels>=27.879); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.02,100,.3);
  RV=zeros(length(Vmag),1)';
    
  eval(['load ',sectdir, ...
          '/ar19c lon bin_press bin_temp lon lat bottom;'])
  mann=-44.37;  % longitude of Mann Eddy center
  bottom=bottom(1:length(lon)-1)+diff(bottom)/2;
  
  % Identify the core of the NAC (where the 10dgC
  % isotherm crosses 450dbar)
  temp=bin_temp(find(bin_press==450),:);
  lonhr=min(lon):.01:max(lon);
  lathr=interp1(lon,lat,lonhr,'linear');
  temp=interp1(lon,temp,lonhr,'linear');
  lon_0=lonhr(min(find(temp>10)));
  lat_0=lathr(min(find(temp>10)));
  % convert lon, lat to pair coordinates
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  lat=lat(1:length(lat)-1)+diff(lat)/2;
  
  % calculate distance (negative=west)
  % between station pairs and NAC core.
  dist=NaN*ones(size(lon));
  for jj=1:length(dist);
    dist(jj)=sw_dist([lat(jj) lat_0], ...
        [lon(jj) lon_0],'km');
    if (lon(jj)<lon_0) dist(jj)=-dist(jj); end;
  end;
  
  % load mean reference velocity on 27.879 surface
  %  (calculated by "calcstreammean.m" in NACpies directory)
  load /phod007/lumpkin/NACpies/48n_refvel d_s v27879
  % rescale so that max(d_s) is at mann eddy center 
  % for this repeat (instead of +200km)
  q=find(d_s>0);
  d_s(q)=d_s(q)/200*interp1(lon,dist,mann);
  % interpolate to dist for this repeat
  v2=interp1(d_s,v27879,dist,'linear');
  % extrapolate westward to shelf break (bottom==500)
  q=find(dist<0 & bottom'>500 & isnan(v2));
  v2(q)=v27879(1);
  % zero bottom ref level inshore of this
  q=find(dist<0 & isnan(v2)); v2(q)=0;
  % zero ref level east of mann eddy center
  v2(find(dist>interp1(lon,dist,mann)))=0;
  
  % match the time-mean net transport from -200km to Mann core:
  %   145 Sv northward - 30 Sv southward = 115 Sv
  %q=find(dist>=-200 & lon<mann);    % pairs 6:15
  v2=1.103*v2;
  RV=RV+v2;
  
  % East half of Mann eddy:  55Sv south.
  q=find(lon>=-44.37 & lon<=-42.82);  % pairs 16:17
  RV(q)=RV(q)-6.29e-2;
  
  % these adjustments give a net transport of 67 Sv north.
  % adjust in interior (west of eastern edge Mann eddy)
  % to get +2.46 Sv (-1*Ekman transport)
  q=find(lon>-42.82);
  RV(q)=RV(q)-6.28e-3;
  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% ar19d: 48N
sect='ar19d.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  % adjustments to reference velocities from
  % Meinen, 2001: DSR I 48, 1553-1580.
  q=find(glevels>=27.879); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.02,100,.3);
  RV=zeros(length(Vmag),1)';

  eval(['load ',sectdir, ...
          '/ar19d lon bin_press bin_temp lon lat bottom;'])
  mann=-43.65;
  bottom=bottom(1:length(lon)-1)+diff(bottom)/2;
  
  % Identify the core of the NAC (where the 10dgC
  % isotherm crosses 450dbar)
  temp=bin_temp(find(bin_press==450),:);
  lonhr=min(lon):.01:max(lon);
  lathr=interp1(lon,lat,lonhr,'linear');
  temp=interp1(lon,temp,lonhr,'linear');
  lon_0=lonhr(min(find(temp>10)));
  lat_0=lathr(min(find(temp>10)));
  % convert lon, lat to pair coordinates
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  lat=lat(1:length(lat)-1)+diff(lat)/2;
  
  % calculate distance (negative=west)
  % between station pairs and NAC core.
  dist=NaN*ones(size(lon));
  for jj=1:length(dist);
    dist(jj)=sw_dist([lat(jj) lat_0], ...
        [lon(jj) lon_0],'km');
    if (lon(jj)<lon_0) dist(jj)=-dist(jj); end;
  end;
  
  % load mean reference velocity on 27.879 surface
  %  (calculated by "calcstreammean.m" in NACpies directory)
  load /phod007/lumpkin/NACpies/48n_refvel d_s v27879
  % rescale so that max(d_s) is at mann eddy center 
  % for this repeat (instead of +200km)
  q=find(d_s>0);
  d_s(q)=d_s(q)/200*interp1(lon,dist,mann);
  % interpolate to dist for this repeat
  v2=interp1(d_s,v27879,dist,'linear');
  % extrapolate westward to shelf break (bottom==500)
  q=find(dist<0 & bottom'>500 & isnan(v2));
  v2(q)=v27879(1);
  % zero bottom ref level inshore of this
  q=find(dist<0 & isnan(v2)); v2(q)=0;
  % zero ref level east of mann eddy center
  v2(find(dist>interp1(lon,dist,mann)))=0;
  
  % match the time-mean net transport from -200km to Mann 
  % center (pairs 7:17):
  %   145 Sv northward - 30 Sv southward = 115 Sv
  q=find(dist>-200 & lon<mann);
  v2=0.478*v2;
  RV=RV+v2;
  
  % East half of Mann eddy:  55Sv south.
  q=find(lon>=-43.65 & lon<=-40.95);  % pairs 18:21
  RV(q)=RV(q)-2.80e-2;
  
  % these adjustments give a net transport of 19 Sv north.
  % adjust in interior (west of eastern edge Mann eddy)
  % to get +2.46 Sv (-1*Ekman transport)
  q=find(lon>-40.95);
  RV(q)=RV(q)-1.76e-3;
  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;
% ar19f: 48N
sect='ar19f.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  % adjustments to reference velocities from
  % Meinen, 2001: DSR I 48, 1553-1580.
  q=find(glevels>=27.879); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.02,100,.3);
  RV=zeros(length(Vmag),1)';

  eval(['load ',sectdir, ...
          '/ar19f lon bin_press bin_temp lon lat bottom;']);
  mann=[-45.4 -43];  % longitude of Mann Eddy center, east edge
  bottom=bottom(1:length(lon)-1)+diff(bottom)/2;
  
  % Identify the core of the NAC (where the 10dgC
  % isotherm crosses 450dbar)
  temp=bin_temp(find(bin_press==450),:);
  lonhr=min(lon):.01:max(lon);
  lathr=interp1(lon,lat,lonhr,'linear');
  temp=interp1(lon,temp,lonhr,'linear');
  lon_0=lonhr(min(find(temp>10)));
  lat_0=lathr(min(find(temp>10)));
  % convert lon, lat to pair coordinates
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  lat=lat(1:length(lat)-1)+diff(lat)/2;
  
  % calculate distance (negative=west)
  % between station pairs and NAC core.
  dist=NaN*ones(size(lon));
  for jj=1:length(dist);
    dist(jj)=sw_dist([lat(jj) lat_0], ...
        [lon(jj) lon_0],'km');
    if (lon(jj)<lon_0) dist(jj)=-dist(jj); end;
  end;
  
  % load mean reference velocity on 27.879 surface
  %  (calculated by "calcstreammean.m" in NACpies directory)
  load /phod007/lumpkin/NACpies/48n_refvel d_s v27879
  % rescale so that max(d_s) is at mann eddy center 
  % for this repeat (instead of +200km)
  q=find(d_s>0);
  d_s(q)=d_s(q)/200*interp1(lon,dist,mann(1));
  % interpolate to dist for this repeat
  v2=interp1(d_s,v27879,dist,'linear');
  % extrapolate westward to shelf break (bottom==500)
  q=find(dist<0 & bottom'>500 & isnan(v2));
  v2(q)=v27879(1);
  % zero bottom ref level inshore of this
  q=find(dist<0 & isnan(v2)); v2(q)=0;
  % zero ref level east of mann eddy center
  v2(find(dist>interp1(lon,dist,mann(1))))=0;
  
  if (1)    % treat ar19f like the others
  % match the time-mean net transport from -200km to Mann 
  % center (pairs 6:11):
  %   145 Sv northward - 30 Sv southward = 115 Sv
  %q=find(dist>-200 & lon<mann(1));
    v2=2.737*v2;
    RV=RV+v2;
  
  % East half of Mann eddy:  55Sv south.
    q=find(lon>=mann(1) & lon<=mann(2));  % pair 12
    RV(q)=RV(q)-6.17e-2;
  
  % these adjustments give a net transport of 63 Sv north.
  % adjust in interior (west of eastern edge Mann eddy)
  % to get +2.46 Sv (-1*Ekman transport)
    q=find(lon>mann(2));
    RV(q)=RV(q)-5.92e-3;
    
    else
  % no mann eddy here: impose 115-55=60Sv north in NAC
  q=find(dist>-200 & lon<mann(1));
  v2=1.413*v2;
  RV=RV+v2;
  
  % net transport 67.5 east of NAC.
  % adjust in interior to get +2.46 Sv (-1*Ekman transport)
  q=find(lon>mann(1));
  RV(q)=RV(q)-5.84e-3;
    end; % with/ without Mann code
    
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% a02_97: 48N
sect='a02_97.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  % adjustments to reference velocities from
  % Meinen, 2001: DSR I 48, 1553-1580.
  q=find(glevels>=27.879); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.02,100,.3);
  RV=zeros(length(Vmag),1)';

  eval(['load ',sectdir, ...
          '/a02_97 lon bin_press bin_temp lon lat bottom;'])
  mann=-43.54;
  bottom=bottom(1:length(lon)-1)+diff(bottom)/2;
  
  % Identify the core of the NAC (where the 10dgC
  % isotherm crosses 450dbar)
  temp=bin_temp(find(bin_press==450),:);
  lonhr=min(lon):.01:max(lon);
  lathr=interp1(lon,lat,lonhr,'linear');
  temp=interp1(lon,temp,lonhr,'linear');
  lon_0=lonhr(min(find(temp>10)));
  lat_0=lathr(min(find(temp>10)));
  % convert lon, lat to pair coordinates
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  lat=lat(1:length(lat)-1)+diff(lat)/2;
  
  % calculate distance (negative=west)
  % between station pairs and NAC core.
  dist=NaN*ones(size(lon));
  for jj=1:length(dist);
    dist(jj)=sw_dist([lat(jj) lat_0], ...
        [lon(jj) lon_0],'km');
    if (lon(jj)<lon_0) dist(jj)=-dist(jj); end;
  end;
  
  % load mean reference velocity on 27.879 surface
  %  (calculated by "calcstreammean.m" in NACpies directory)
  load /phod007/lumpkin/NACpies/48n_refvel d_s v27879
  % rescale so that max(d_s) is at mann eddy center 
  % for this repeat (instead of +200km)
  q=find(d_s>0);
  d_s(q)=d_s(q)/200*interp1(lon,dist,mann);
  % interpolate to dist for this repeat
  v2=interp1(d_s,v27879,dist,'linear');
  % extrapolate westward to shelf break (bottom==500)
  q=find(dist<0 & bottom'>500 & isnan(v2));
  v2(q)=v27879(1);
  % zero bottom ref level inshore of this
  q=find(dist<0 & isnan(v2)); v2(q)=0;
  % zero ref level east of mann eddy center
  v2(find(dist>interp1(lon,dist,mann)))=0;
  
  % problem with A02_97:  -200km (stream coords)
  % is in the center of an anomalous anticyclonic eddy.
  % For this section, include the eddy (starting at
  % cast 7) when matching the net mean transport
  % for -200km to Mann Eddy Center  (115 Sv)
  %q=find(dist>=-200 & lon<mann); % pairs 10:16
  v2=1.223*v2;  % adjusted for pairs 10:16
  RV=RV+v2;
  
  % East half of Mann eddy:  55Sv south.
  q=find(lon>=-43.54 & lon<=-40.74);  % pairs 17:19
  RV(q)=RV(q)-2.57e-2;
  
  % these adjustments give a net transport of 60 Sv north.
  % adjust in interior (west of eastern edge Mann eddy)
  % to get +2.46 Sv (-1*Ekman transport)
  q=find(lon>-40.74);
  RV(q)=RV(q)-3.46e-3;
  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% i05p: 32S
sect='i05p.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
    
    reflevel(i)=length(glevels); 
    Vmag=defVmag(sectfiles(i,:),reflevel(i),.01,-99,-99);
    RV=zeros(length(Vmag),1)';
                            
    eval(['load ',sectdir, ...
            '/i05p_raw lon lat bottom binPair_vel bin_press'])
    dist=cumsum(sw_dist(lat,lon,'km'));
    lon=lon(1:length(lon)-1)+diff(lon)/2;
    bottom=[bottom(1:length(bottom)-1),bottom(2:length(bottom))];
    bottom=nanmin(bottom');
    
    % shift to bottom ref level before further adjustments
    for j=1:length(lon);
      q=find(isfinite(binPair_vel(:,j)));
      binPair_vel(:,j)=binPair_vel(:,j)- ...
        binPair_vel(last(q),j);
    end;
    
    % East of 113.5E, e.g. against western Australia,
    %   shift ref level to 300m to capture southward
    %   surface Leeuwin Current and northward undercurrent
    %   [Smith et al. (1991), JPO 21, 323-345;
    %   Feng et al. (2003), JGR 108 (C11), 3355]
    % Between the eastern Natal Vally and 113.5E,
    %   shift ref level to 2000dbar 
    %  [Bryden and Beal (2001), DSR 48 (8), 1821-1845]
    % West of this, shift level of no motion
    % to the zero velocity level from LADCP
    %   [Beal & Bryden (1999), DSR I 44 (9-10), 1715-1724]
    %   700m at innermost station,
    %   depth 2500m at 80 km offshore,
    %   depth 1000m at 230 km offshore.
    %   (linear trend gives 2000m at 130 km offshore)
    % Note that different numbers are reported in
    % BB01: linear increase from 800dbar at shelf break to
    % 2900dbar at 60 km offshore, then linear decrease
    % to 2000dbar at 100 km offshore.  
    dd=[dist(1) 80 130];  % distances offshore
    zz=[700 2500 2000]; % corresponding depths for refvel
    % this gives net transport across Agulhas segment 
    % (pairs 1:10) of 71 Sv southward
    a=diff(zz)./diff(dd);
    b=[zz(1)-a(1)*dd(1) zz(3)-a(2)*dd(3)];
    
    % shift ref level to 300m in Leeuwin region
    %( lon>=113.5, pairs 100-106).  This gives
    % net southward transport of 3.1 Sv in these
    % pairs, agreeing well with Feng et al (2003)
    % mean value of 3.4 Sv.
    refp=300;
    q=min(find(bin_press>=refp));
    q2=find(bottom>=refp & lon>=113.5);
    RV(q2)=RV(q2)-binPair_vel(q,q2);
    q=find(isnan(RV(q2)));
    RV(q2(q))=0;
    
    % shift ref level to 2000dbar from the
    % eastern Natal Valley to the western edge
    % of the Leeuwin Current
    refp=2000;
    q=min(find(bin_press>=refp));
    q2=find(bottom>=refp & dist>=dd(3) & lon<113.5);
    RV(q2)=RV(q2)-binPair_vel(q,q2);
    q=find(isnan(RV(q2)));
    RV(q2(q))=0;
    
    % V-shaped Agulhas reference level
    q2=find(dist<dd(2));
    for ind=1:length(q2);
        refp=a(1)*dist(q2(ind))+b(1);
        q=min(find(bin_press>=refp));
        RV(ind)=RV(ind)-binPair_vel(q,q2(ind));
        if (isnan(RV(q2(ind))))
            RV(q2(ind))=0;
        end;
    end;
    q2=find(dist>=dd(2) & dist<dd(3));
    for ind=1:length(q2);
        refp=a(2)*dist(q2(ind))+b(2);
        q=min(find(bin_press>=refp));
        RV(ind)=RV(ind)-binPair_vel(q,q2(ind));
        if (isnan(RV(q2(ind))))
            RV(q2(ind))=0;
        end;
    end;
    
    % unadjusted, this gives 33Sv southward.
    % If balanced in interior (pairs 10:99)
    % to get net 16Sv southward (Ekman=.9 Sv N),
    % ones finds two problems:
    %   1. southward transport in deepest layers 42-43.
    %   2. northward transport of 1377 kmol/s silicate
    %      (associated with 23 Sv overturning circulation).
    %q=find(dist>=dd(3) & lon<113.5);
    %RV(q)=RV(q)+0.67e-3;
    % A better solution will have northward or zero
    % flow in deepest layers, and smaller silicate transport.
          
    % constraints from Ganachaud (1999), modified by
    %  pers. comm. with Lisa Beal.  These are applied
    %  to deep/bottom water, gamma>28.11, layers 36:45.
    
    % Natal Valley (pairs 1-13) is a cul-de-sac
    %   for BW: met by default (0.3 Sv)
    
    % Mozambique Basin (pairs 16-24) is a cul-de-sac.
    %   NOTE: Ganachaud has 1 Sv north.  
    %   NOTE2: adding uniform 4.43e-3 to these pairs
    %    achieves 0 net, layers 36:45, but also yields
    %    1.3 Sv south in densest two layers 42,43.
    %    Set these to zero, at expense of 2.9Sv
    %    net northward flow in layers 36:41
    q=find(lon>36.1 & lon<43.2); % pairs 16:24
    RV(q)=RV(q)+7.39e-3;
    
    % Madagascar-Crozet Basin (pairs 30-54): 
    %  2.5-3.8 Sv northward deep water (potmp<1.0-1.1degC;
    %   gamma>28.13, layers 37:45) feeds DWBC 
    %   in Mascarene Basin (Johnson, Musgrave, Warren,
    %   Ffield and Olson, 1998: JGR 103(C13), 30973-30984)
    % first, cancel southward transport of layers 42-43.
    q=find(lon>55 & lon<70);
    RV(q)=RV(q)+1.20e-3;
    % next, get 1 Sv north in overall M-C segment
    q=find(lon>47 & lon<55);
    RV(q)=RV(q)-1.58e-3;
    
    % Central Basin (pairs 57-67) BW (") cul-de-sac.
    q=find(lon>78 & lon<89);
    RV(q)=RV(q)-0.72e-3;
    
    % layers through 41 can also cross northward
    % into Perth Basin through gap between Leeuwin
    % and Amsterdam-Naturaliste Ridge, pairs 81:98.
    % Unadjusted solution has 9.5 Sv northward here.
    % Cancel this to reduce net silicate transport.
    q=find(lon>102 & lon<113.5);
    RV(q)=RV(q)-5.78e-3;
    
    % unadjusted, this gives 33Sv southward.
    % Balance over Southeast Indian Ridge
    % (87.6-99.2E) to get net 13Sv southward (Ekman=.9 Sv N)
    q=find(lon>87.6 & lon<99.2);
    RV(q)=RV(q)+1.35e-2;
    
    % these choices give a prior overturning of 9.3 Sv
    % below 1200 dbar; in density coordinates the
    % overturning is 10.1 Sv, 4.4 ACCbw and 5.75 Sv LCDW
    % northward balanced by 4.6 Sv UCDW and 4.5 Sv 
    % mode water southward (+3.6 Sv mode southward as 
    % lower part of Pac.Ind.Throughflow).  It carries
    % a net transpor tof 59 kmol/sec silicate northward.
    %    This overturning is comparable to 
    % Robbins and Toole (1997) (12 Sv) and
    % Bryden and Beal (2001), as calculated in their
    % section 6: 10.1 Sv.
    % It is far smaller than Toole and Warren's
    % (1993) 25 Sv, which produces large silica
    % convergence (RT97).
    
    rvfilename=['refvel_',sect];
    eval(['save ',rvfilename,' RV Vmag']);
end;

% ir06d: Feb. 1992 JADE section from Indonesia to Australia.
    % Sprintall, J., S. Wijffels, T. Chareskin and
    % N. Bray, 2002: The JADE and WOCE I10/IR6
    % Throughflow sections in the southeast Indian
    % Ocean.  Part 2: velocity and transports.
    % DSR II (49), 1363-1389.
    %
    %
    % Primary differences between IR06d and other repeats:
    %    The Feb92 section best-sampled flow against 
    %   Indonesia.  Semiannually-reversing South Java
    %   Current (SJC) VERY strong eastward in Feb92.
    %   both SEC and EGC (Eastern Gyral C.) weaker than 
    %   ann.avg: typical February conditions.
    % Ekman: 0.65 Sv westward.
sect='ir06d.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))

  % bottom reference level - this section has been masked
  % below 100dbar
  % (1200dbar=the sill depth of the Timor Passage).
  reflevel(i)=length(glevels);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.05,-99,-99);
  RV=zeros(length(Vmag),1)';
  eval(['load ',sectdir,'/ir06d_raw lat']);
  lat=lat(1:length(lat)-1)+diff(lat)/2;
  
  % At this point, net transport is 1.8 Sv westward.
  % Add westward vref in South Equatorial Current
  % to get PIT (12 Sv westward)
  q=find(lat>=-14 & lat<=-10);
  RV(q)=RV(q)+.383;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% i02: 11S Madagascar to Australia
sect='i02.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  q=find(glevels>=28.20); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.02,500,.3);
  RV=rv(i)*ones(length(Vmag),1)';
  

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% Mozambique: 11S Africa to Madagascar
sect='mozambique.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  q=find(glevels>=28.11); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.1,1000,.3);
  RV=rv(i)*ones(length(Vmag),1)';
  eval(['load ',sectdir,'/mozambique_raw lon']);
  lon=lon(1:length(lon)-1)+diff(lon)/2;

  % No net in layers 28-45 (gamma>28.03;
  %     sill depth 2600m in Moz.Channel)
  % NOTE: this still leaves 5Sv, but stronger
  % adjustment is worse for layers>33
  q=find(lat<-5.3 & lat>-11.2);
  RV(q)=7e-3;

  % Adjust against Africa to get net southward
  % flow of 10Sv (see i04)
  q=find(lon<42);
  RV(q)=.054;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% i04: 24.6S, Africa to Mozambique
sect='i04.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  q=find(glevels>=28.11); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.1,1000,.3);
  RV=rv(i)*ones(length(Vmag),1)';
  eval(['load ',sectdir,'/i04_raw lon']);
  lon=lon(1:length(lon)-1)+diff(lon)/2;

  % No net in layers 28-45 (gamma>28.03;
  %     sill depth 2600m in Moz.Channel)
  q=find(lon>41 & lon<43.6);
  RV(q)=2e-3;

  % adjust against Africa and Madagascar
  % to get southward net of 10Sv
  % (see summary values in Chapman et al proposal)
  q=find(lon<=36.25 | lon>43.75);
  RV(q)=RV(q)-.115;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% p06: 32S
sect='p06.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
    
    % interface between Wijffels et al. (2001)
    % deep and bottom water for ZVS
    q=find(glevels>=28.125); reflevel(i)=q(1);
    eval(['load ',sectdir,'/p06_raw lon']);
    lon=lon(1:length(lon)-1)+diff(lon)/2;
    
    Vmag=defVmag(sectfiles(i,:),reflevel(i),.01,-99,-99);
    RV=zeros(length(Vmag),1)';
  
    % allow larger adjustment against Tonga-Kermadec Ridge
    q=find(lon>=-179 & lon<=-169);
    Vmag(q)=max([Vmag(q);.2*ones(1,length(q))]);
    
    % S New Cal. Trough (162-168E): cul-de-sac for 
  % gamma>27.9 (lay22-45)
  q=find(lon>=162.5 & lon<=166.5); % pairs 28:34
  RV(q)=RV(q)-1.00e-3;
  
  % 14.8 Sv (layers 21-45) N against Kermadec Ridge
  %	as seen by PCM9 (179-169W; pairs 64:88)
  % in layers below 3250 m (layers 31:45)
  q=find(lon>=-179 & lon<=-169); 
  RV(q)=RV(q)+4.14e-3;
  % this gives:
  % 4.1 Sv S, layers 21:30 (should be 1 Sv N)
  % 7.5 Sv N, layers 31:40 (should be 8.8 Sv N)
  % 7.3 Sv N, layers 41:45 (should be 6.0 Sv N)
  
  % Constraints from Wijffels et al Table 3
  % West Tasman Sea: .5 Sv N, gamma>28.1 (layers 35:45)
  q=find(lon>=154 & lon<=160);  % pairs 7:22
  RV(q)=RV(q)+0.18e-3;
  % Central Tasman Sea: 0 Sv at gamma>27.95 (layers 23:45)
  q=find(lon>=160 & lon<173);   % pairs 23:48
  RV(q)=RV(q)+0.27e-3;
  % East Tasman Sea: 0 Sv at gamma>27.95 (layers 23:45)
  q=find( (lon>=173 & lon<=180) | (lon<-179));
    % pairs 49:63
  RV(q)=RV(q)-0.15e-3;
  
  % Adjustments so far yield net transport of 10.43 Sv N.
  % This is sufficiently close to PIT (12 Sv N)
  % minus Ekman (0.6 Sv N) = 11.4 Sv N.
  %     East Australia Current 
  %     q=find(lon>0 & lon<154);  % pairs 1-6
  % Prior overturning circulation is 21.2 Sv bottom/deep
  % water cell.  Wijffels et al: 16 Sv.

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% p03: 24N
sect='p03.mat';
i=sectname2sectnum(sect);
if (length(i))

  % 2000 dbar ref level (Roemmich and McCallister 1989)
  refp=2000;
  eval(['load ',sectdir,'/p03_raw bin_press surf_press']);
  d=(refp-nanmean(surf_press')').^2;
  reflevel(i)=find(d==min(d));
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.01,250,.4);
  RV=rv(i)*ones(length(Vmag),1)';

  % shift RV to zero the thermal wind profile at refp
  reflevel(i)=length(glevels);  % must be set to bottom
                                % for isobaric code to work!
  eval(['load ',sectdir,'/p03_raw binPair_vel lon bin_press bottom']); 
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  for j=1:length(lon);
    q=find(isfinite(binPair_vel(:,j)));
    binPair_vel(:,j)=binPair_vel(:,j)- ...
        binPair_vel(last(q),j);
  end;

  % shift ref level to 2000dbar (Roemmich and McCallister 1989)
  q=min(find(bin_press>=refp));
  q2=find(bottom>refp);
  RV(q2)=RV(q2)-binPair_vel(q,q2);
  q=find(isnan(RV(q2)));
  RV(q2(q))=0;

  % No transport at gamma>27.52 (1200m) in Okinawa Trough
  %  (125-127E, pairs 193-205 ; Ganachaud 1999)
  q=find(lon>125 & lon<127);
  RV(q)=3e-3;
  % No transport at gamma>28.04 (3100m) in N.Phil. Basin
  %  (127-141E, pairs 163-193 ; Ganachaud 1999)
  q=find(lon>127 & lon<141);
  RV(q)=-3.5e-4;
  % Balance Ekman (8.26 Sv north)
  RV=RV-5e-5;
  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% p01: 45N
sect='p01.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
    
  q=find(glevels>=28.1); reflevel(i)=q(1);
  eval(['load ',sectdir,'/p01_raw binPair_vel lon bin_press']);
  lon=lon(1:length(lon)-1)+diff(lon)/2;

  Vmag=defVmag(sectfiles(i,:),reflevel(i),.01,150,.3);
  RV=rv(i)*ones(length(Vmag),1)';

  % No transport at gamma>28.1 in Kural Trench
  %  (145-147E, pairs 1-14; Ganachaud 1999)
  q=find(lon>145 & lon<147);
  RV(q)=6e-3;

  % Balance Ekman (Ek=3.96 Sv south) 
  RV=RV-7e-4;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% s4 - circumpolar section isolating Antarctica
sect='s4comp.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  % reference level: 0 deg C. CDW/WSDW interface
  q=find(glevels>=28.292); reflevel(i)=q(1);
  % 24 Jan 03: moved to 28.27 as per request from Alex Orsi
  q=find(glevels>=28.27); reflevel(i)=q(1);
  % 27 Jan 03: moved to bottom ref level, re:Alex's input
  % (CURRENTLY UNDONE)
  %reflevel(i)=length(glevels);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),.05,100,.3);
  %Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';
  
  eval(['load ',sectdir,'/s4comp_raw binPair_vel ', ...
          'lon bin_press bottom surf_press']);
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  bottom=bottom(1:length(bottom)-1)+diff(bottom)/2;
  
  for j=1:length(lon);
      if isfinite(surf_press(reflevel(i),j)) % reflev above bottom
          zind=(bin_press-surf_press(reflevel(i),j)).^2;
          zind=find(zind==min(zind));
          binPair_vel(:,j)=binPair_vel(:,j)- ...
              binPair_vel(zind,j);
      else  % reflevel too dense to be defined for this pair
          q=find(isfinite(binPair_vel(:,j)));
          binPair_vel(:,j)=binPair_vel(:,j)- ...
	        binPair_vel(last(q),j);
      end;
  end;
  % shift ref level to bottom where bottom>=1000m,
  %  and to surface where bottom<1000m or where,
  % on South Scotia Ridge (-60<=lon<-42), bottom<2000
  for j=1:length(lon);
      q=find(isfinite(binPair_vel(:,j)));
      if (bottom(j)>=1000 & (lon(j)<-60 | lon(j)>-42))
          % bottom ref level
          %RV(j)=RV(j)-binPair_vel(last(q),j);
      elseif (bottom(j)>=2000) % bottom for these SSR pairs
          %RV(j)=RV(j)-binPair_vel(last(q),j);
      else  % shallow: surface ref level
          RV(j)=RV(j)-binPair_vel(1,j);
      end;
  end;  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% s4_pac
sect='s4_pac.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  q=find(glevels>=28.27); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),.05,-99,-99);
  RV=zeros(length(Vmag),1)';
  
  % Ross sea: 171E-159W (pairs 31:54)
  % Bellany Islands: 162.7E
  eval(['load ',sectdir,'/s4_pac_raw lon']);
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  
  % ~6 Sv in layers 43:45 from western Ross Sea
  q=find(lon>171 | lon<-178); %pairs 31-39
  RV(q)=RV(q)+1.08e-2;
  
  % balance Ekman (3.6 Sv northwards)
  % in southward current against AA Peninsula
  q=find(lon<0 & lon>-78);
  RV(q)=RV(q)-1.61e-2;
  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% s4_atl
sect='s4_atl.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  % reference level: 0 deg C. CDW/WSDW interface
  %q=find(glevels>=28.292); reflevel(i)=q(1);
  % 24 Jan 03: moved to 28.27 as per request from Alex Orsi
  q=find(glevels>=28.27); reflevel(i)=q(1);
  
  eval(['load ',sectdir,'/s4_atl_raw lon']);
  lon=lon(1:length(lon)-1)+diff(lon)/2; 
  
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.05,150,.3);
  RV=zeros(length(Vmag),1)';

  % The reflevel choice 28.27 produces VERY STRONG
  % (11.8Sv) outflow in layer 45, pairs 57-59.
  % This export is inconsistent with the 4.28 Sv
  % exported across wedsea in layer 45.
  q=find(lon>-25 & lon<-22);
  RV(q)=RV(q)-4e-2;
  
  % add southward transport in eastern side of
  % recirculating dome, to get zero net transport
  % for layer 45 in pairs 65:94 (these pairs are
  % east of 13W, the western edge of the dome)
  q=find(lon>-11.55); % center of dome
  RV(q)=RV(q)-1.3e-3;
  
  % between 15W and the western edge (13W) of the
  % dome of recirculating dense water,
  % add northward barotropic to get section net 
  % .9 Sv export in layer 44, 4 Sv in layer 45
  q=find(lon>=-15 & lon<=-10.5);
  RV(q)=RV(q)+2e-2;
  
  % finally adjust to balance Ekman (2 Sv north)
  q=find(lon<-25);
  RV(q)=RV(q)-1.45e-3;
  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% s4_ind
sect='s4_ind.mat';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  % 24 Jan 03: moved to 28.27 as advised by Alex Orsi
  q=find(glevels>=28.27); reflevel(i)=q(1);
  
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.05,-99,-99);
  RV=zeros(length(Vmag),1)';
  
  eval(['load ',sectdir,'/s4_ind_raw lon']);
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  
  % Kerguelen Plateau: 82.8E.  DWBC from 82.8 to 106E
  % (station pairs 45:62).  Layers 38-45 < 1degC potmp.
  % Donohue et al 1999: 38 Sv (+-12) in these layers.
  q=find(lon>=82.8 & lon<=106);
  RV(q)=RV(q)+8.73e-3;
  
  % flow through PET: Heywood et al 1999: 20 Sv
  % at theta<0 deg (layers 43:45)
  % This water enters the Weddell sector, or
  % exits between Kerguelen and Weddell Gyre
  % (lon>34 & lon<70; station pairs 8:35)
  % assume the latter in the prior thermal wind
  % by adding a barotropic component against the
  % bathymetric feature at 34E
  q=find(lon>34 & lon<40);
  RV(q)=RV(q)+1.43e-2;
  
  % balance Ekman (4.2 Sv northwards)
  q=find(lon<34 | lon>106);
  RV(q)=RV(q)-8.01e-3;
  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% sr03c Tasmania to Antarctica
sect='sr03c';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
              % bottom reference level
  reflevel(i)=length(glevels);
  eval(['load ',sectdir,'/sr03c_raw binPair_vel ', ...
          'bin_press surf_press']);
         
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.05,-99,-99);
  RV=zeros(length(Vmag),1)';
  for j=1:size(binPair_vel,2);
      if (isfinite(surf_press(reflevel(i),j)))
          q=find(bin_press==round(surf_press(reflevel(i),j)));
          q2=find(isfinite(binPair_vel(:,j)));
          RV(j)=RV(j)-binPair_vel(last(q2),j)+binPair_vel(q,j);
      end;
  end;
  %load /export/lasalle1/hydrography/WOCE/SR03c/sr03c_bvel;
  %RV=RV+bvel;
  % adjust to get 140+15=155Sv westward
  RV=RV-2e-3;
  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% indant - the piece of SR03c from S4 to the Antarctic
sect='indant';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
    q=find(glevels>=28.292); reflevel(i)=q(1);

    Vmag=defVmag(sectfiles(i,:),reflevel(i),.05,-99,-99);
    RV=zeros(length(Vmag),1)';
  
    %  10 SV boundary current, ~0Sv net
    RV(1:6)=RV(1:6)+0.07;
  
    rvfilename=['refvel_',sect];
    eval(['save ',rvfilename,' RV Vmag']);
end;

% I06b (CIVA - S. africa to S4)
sect='i06b';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
      % bottom reference level
  reflevel(i)=length(glevels);
  eval(['load ',sectdir,'/i06b_raw binPair_vel ', ...
          'bin_press surf_press bin_press']);
         
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.05,-99,-99);
  RV=zeros(length(Vmag),1)';
  for j=1:size(binPair_vel,2);
      if (isfinite(surf_press(reflevel(i),j)))    
          q=(bin_press-surf_press(reflevel(i),j)).^2;
          q=find(q==min(q));
          q2=find(isfinite(binPair_vel(:,j)));
          RV(j)=RV(j)-binPair_vel(last(q2),j)+binPair_vel(q,j);
      end;
  end;
  
  %load /export/lasalle1/hydrography/WOCE/I06b/i06b_bvel;
  %RV=RV+bvel;
  RV=RV+2.2e-3; % shift prior net from 180Sv to 140Sv
  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% I06bs (CIVA - S4 to Antarctica)
sect='i06bs';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
    q=find(glevels>=28.292); reflevel(i)=q(1);
    
    Vmag=defVmag(sectfiles(i,:),reflevel(i),.05,-99,-99);
    RV=zeros(length(Vmag),1)';

    % Add bottom velocities in the boundary current to create a
    % 10 DV WBC (Heywood et al. 1998).
    %RV(1:5)=RV(1:5)+0.125;

    rvfilename=['refvel_',sect];
    eval(['save ',rvfilename,' RV Vmag']);
end;
    
% A21: Drake Passage segment
sect='drake90';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  % bottom reference level
  reflevel(i)=length(glevels);
  
  eval(['load ',sectdir,'/drake90_raw binPair_vel ', ...
          'surf_press bin_press']);
         
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.05,-99,-99);
  RV=zeros(length(Vmag),1)';
  for j=1:size(binPair_vel,2);
      if (isfinite(surf_press(reflevel(i),j)))
          q=(bin_press-surf_press(reflevel(i),j)).^2;
          q=find(q==min(q));
          q2=find(isfinite(binPair_vel(:,j)));
          RV(j)=RV(j)-binPair_vel(last(q2),j)+binPair_vel(q,j);
      end;
  end;
  
  % Add Gille's bottom reference profile
  %load /export/lasalle1/hydrography/WOCE/A21/drake90_bvel
  %RV=RV+bvel;
  
  % adjust to get 140Sv westward
  RV=RV-2e-3;
  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% Wedsea: german section in Weddell Sea
sect='wedsea';
i=sectname2sectnum(sect,sectfiles);
if (length(i))
  eval(['load ',sectdir,'/wedsea_raw lon']);
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  
  q=find(glevels>=28.292); reflevel(i)=q(1);
  Vmag=defVmag(sectfiles(i,:),reflevel(i),.05,400,.3);
  RV=zeros(length(Vmag),1)';
  
  % easternmost 8 pairs: 34.8 Sv southward 
  % (Wienders, pers.comm.)
  % (compares well to Fahrbach et al (1995): 29.5 Sv.
  q=find(lon>-16.817);
  RV(q)=RV(q)-2.9e-2;
  % westernmost 10 pairs: 26 Sv northward (Wienders)
  q=find(lon<-47.95);
  RV(q)=RV(q)+3.41e-2;
  % surface (gamma<28.18) layers, 41.517-47.95W:
  %   2.1 Sv north (Wienders).  Note: concentrate
  %   for western 1/3, where sfc layers are thickest,
  %   or transport of deep (gamma>28.27) water far 
  %   exceeds 5.3+-9 Sv.
  q=find(lon>-47.95 & lon<-45);
  RV(q)=RV(q)+3.05e-2;
  %%% westernmost 15 pairs: 33 Sv northward (").
  %%% Choices above give 44 Sv, but all zones within
  %%% Wienders' error bar estimates.
  
  % resulting net mass transport is 11 Sv north.
  % Adjust in center of section to balance Ekman
  % (0.9 Sv north).  NOTE: this adjustment yields
  % a net northward, not southward, transport of 1 Sv.
  % This is a compromise between the net constraint
  % and the constraint that Zone 7 has 0+-1 Sv.
  q=find(lon>-41.516 & lon<-30);
  RV(q)=RV(q)-3.88e-3;
  
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;


clear sect i;
