function barflux3(massn,Sv2deg,avgnum,sectnum);

% barflux3(massn,Sv2deg,avgnum,sectnum)
%
% Plot bars showing the transport across section
% "sectnum", averaged over layers indicated by
% massn (defined in waterdiv.m) or in an individual
% model layer (massn=-12 for layer 12).
% 1 Sv spans Sv2deg degrees on the plot (default=.5)
% avgnum is the number of stations for each bar 
% (default=3; small numbers produce large error bars
% while large numbers average over important features)

load gaussout lon lat sectlabel nsections x erx Ax D ...
	A Pxx glayers indb indv EkmanE fluxdivfact fluxunits
massnum=massn;

ploterror=0;    % set to 1 to include error bars

q=find(sectlabel==sectnum);
minlon=min(lon(q))-5; maxlon=max(lon(q))+5;
minlat=min(lat(q))-5;; maxlat=max(lat(q))+5;

propnum=1;
waterdiv;
if (massnum>0)
  titl=waterdivslab(massnum,:);
elseif (massnum<0 & length(massnum)==1)
  titl=['layer ',num2str(-massnum)];
else
  titl=['layers ',num2str(-(max(massnum))), ...
        '-',num2str(-(min(massnum)))];
end;
if (massnum==0)
  nlyr=1:length(glayers);
  titl='vertically-integrated';
elseif (massnum==1)
  nlyr=find(glayers<waterdivs(massnum));
elseif (massnum==length(waterdivs)+1)
  nlyr=find(glayers>=last(waterdivs));
elseif (massnum>1 & massnum<length(waterdivs)+1)
  nlyr=find(glayers>=waterdivs(massnum-1) & ...
        glayers<waterdivs(massnum));
else
  nlyr=-massnum;
end;

if ~exist('Sv2deg');
  Sv2deg=.5;	% 1 Sv spans this many degrees on plot
end;
if ~exist('avgnum');
  avgnum=3;
end;
if (avgnum/2==floor(avgnum/2)) 	% avgnum must be an odd number
  avgnum=avgnum+1
end;

if (0)	% superimpose plot on bathymetry
  load bathyworld;
  q=find(z2>0);z2(q)=1000;
  l=-5000:1000:1000;
  q=find(z2<min(l));z2(q)=min(l);
  %[C,H]=contourf(lon2,lat2,z2,l);
  %set(H,'edgecolor','none');
  patchmap(lon2,lat2,z2);
  colormap bone
  colormap(flipud(colormap));
  set(gca,'layer','top')
  colorbarvertbig;
elseif (0)	% superimpose plot on salinity
  Lon=lon;Lat=lat;
  %load /home/lasalle0/archive/sac/modellayers Sg lon lat;
  ss=Sg(:,:,nlyr);ss2=NaN*ones(length(lat),length(lon));
  for i=1:length(lat);for j=1:length(lon);
    ss2(i,j)=nanmean(ss(i,j,:));
  end; end;
  q=find(lat<minlat);lat(q)=[];ss2(q,:)=[];
  contourfill(lon,lat,ss2,6);
  overlay;
  colormap bone;
  colormap(flipud(colormap));
  F=colormap; colormap(.8*F+.1);
  clear ss ss2;
  lon=Lon;lat=Lat;
else
  plot(1,1,'.','markersize',1);
  overlay;
end;
%mapaxis([minlon maxlon minlat maxlat]);
axis([minlon maxlon minlat maxlat]);
hold on;

%for sectnum=1:nsections;

    geo;
    boxnum=min(find(abs(geometry(:,sectnum))));
    q=find(sectlabel==sectnum);
    %plot(lon(q),lat(q),'color',[.5 .5 .5]);
    lonny=lon(q);latty=lat(q);
    q=find(abs(diff(lonny))>180);
    while(length(q))
        lonny=[lonny(1:q(1));NaN;lonny(q(1)+1:length(lonny))];
        latty=[latty(1:q(1));NaN;latty(q(1)+1:length(latty))];
        q=find(abs(diff(lonny))>180);
    end;
    plot(lonny,latty,'color',[.5 .5 .5])

    q=find(sectlabel==sectnum);
    [dist,ang]=sw_dist(lat(q),lon(q),'km');
    ang=ang*2*pi/360;
    if (length(ang)==1) ang=[ang;ang];
    else ang=[ang(1);ang(1:length(ang)-1)+diff(ang)/2;last(ang)];
    end
    if (geometry(boxnum,sectnum)<0)
        ang=ang+pi;
    end;

    pfluxref=NaN*ones(size(q));
    pfluxrel=pfluxref;eref=pfluxref;
    angle=pfluxref;latflux=pfluxref;lonflux=pfluxref;
for i=1+(avgnum-1)/2:avgnum:length(q)-(avgnum-1)/2;
  indx=i-(avgnum-1)/2 : i+(avgnum-1)/2;
  fluxref=sum(Ax(indb(nlyr,propnum,boxnum), ...
	indv(q(indx))));
  fluxrel=-sum(D(indb(nlyr,propnum,boxnum), ...
	indv(q(indx))));
  h=A(indb(nlyr,propnum,boxnum),indv(q(indx)))';
  eref(i)=sqrt(  sum(sum(h'*Pxx(indv(q(indx)),indv(q(indx)))*h))  );

  angle(i)=ang(i);
  lonflux(i)=lon(q(i));
  latflux(i)=lat(q(i));

  pfluxref(i)=sum(fluxref);
  pfluxrel(i)=sum(fluxrel);
end;
i=1+(avgnum-1)/2:avgnum:length(q)-(avgnum-1)/2;
if (max(i)<length(q)-(avgnum-1)/2)
  indx=max(i)+(avgnum-1)/2+1:length(q);
  pfluxref(length(q))=sum(sum(Ax(indb(nlyr,propnum,boxnum), ...
        indv(q(indx)))));
  pfluxrel(length(q))=-sum(sum(D(indb(nlyr,propnum,boxnum), ...
        indv(q(indx)))));
  h=A(indb(nlyr,propnum,boxnum),indv(q(indx)))';
  eref(length(q))=sqrt(  sum(sum(h'*Pxx(indv(q(indx)),indv(q(indx)))*h))  );
  angle(length(q))=mean(ang(indx));
end;

% EkIn: the total Ekman flux across that section
% (individual station pair information has not been saved).
EkIn=sum(sum(EkmanE(nlyr,propnum,boxnum,sectnum),1));
if (EkIn)
  % distribute EkIn evenly among the station pairs
  % (cum. sum climbs steadily to total EkIn)
  EkIn=ones(size(pfluxref))*EkIn/length(find(isfinite(pfluxref)));
else
  EkIn=zeros(size(pfluxref));
end;
jj=find(isnan(pfluxref));EkIn(jj)=NaN;

pfluxref=Sv2deg*pfluxref/fluxdivfact(propnum);
eref=abs(Sv2deg*eref/fluxdivfact(propnum));
pfluxrel=Sv2deg*pfluxrel/fluxdivfact(propnum);
EkIn=Sv2deg*EkIn/fluxdivfact(propnum);

netflux=pfluxref+pfluxrel+EkIn;

u=-netflux.*sin(angle);
eu=-eref.*sin(angle);
v=netflux.*cos(angle);
ev=eref.*cos(angle);

q2=find(isfinite(netflux));
for i=1:length(q2)
  plot([lonflux(q2(i)) lonflux(q2(i))+u(q2(i))], ...
	[latflux(q2(i)) latflux(q2(i))+v(q2(i))], ...
	'k','linewidth',4);
  if (ploterror)
    plot(lonflux(q2(i))+u(q2(i)), ...
	latflux(q2(i))+v(q2(i)),'.','markersize',8, ...
	'color',[.5 .5 .5]);
    plot([lonflux(q2(i))+u(q2(i))+eu(q2(i)) ...
	lonflux(q2(i))+u(q2(i))-eu(q2(i))], ...
	[latflux(q2(i))+v(q2(i))+ev(q2(i)), ...
	latflux(q2(i))+v(q2(i))-ev(q2(i))], ...
	'linewidth',1,'color',[.5 .5 .5]);
  end;
end;

title(titl,'fontsize',15);

%end;	% loop over sections
 
% make legend

%legend=[-65,42.5];
legend=[75,-45];
legendflux=round(10/Sv2deg);
dx=2*legendflux*Sv2deg;
dy=dx/3;
patch([legend(1)-dx/2 legend(1)-dx/2 ...
        legend(1)+dx/2 legend(1)+dx/2], ...
        [legend(2)-dy/2 legend(2)+dy/2 ...
        legend(2)+dy/2 legend(2)-dy/2],'w');
hold on;
P=quiver([legend(1)-Sv2deg*legendflux/2 0], ...
        [legend(2)+dy/5 0],Sv2deg*[legendflux 0],[0 0],0,'.');
set(P,'color','k','linewidth',4);
text(legend(1),legend(2)-dy/4, ...
        [num2str(legendflux),fluxunits(propnum,:)], ...
        'horizontalalignment','center','fontsize',8);

hold off;


