function pflux=calcpropflux(nlyr,property,boxnum,sectnum);
 
% function pflux=calcpropflux(nlyr,property,boxnum,sectnum);
%
% Calculate pflux, the property transport (first element
%  of 2-by-1 vector) and its error bar (second element)
% of "property" (e.g."botSILCAT") into box number "boxnum"
% across section "sectnum", using the output of gauss.m,
% saved as "gaussout.mat" in the current directory, and
% the property field from the original section.

%nlyr=1:45;
%property='botSILCAT';
%boxnum=1;
%sectnum=1;

units='';

% additional multiplicative factors
%  MultRho: 1 to multiply by in-situ density
if (strcmp(property,'volume'));
  MultRho=0; MultCp=0;
  MF=1/1e6; unitsprefix='1e6';
elseif (strcmp(property,'botSILCAT'));
  MultRho=1; MultCp=0;
  %MF=(28.0855+4*15.9994)/1e3/1e6; % kg/micromol SiO_4
  %MF=MF/1e3; unitsprefix='1e3(KG/UMOL SiO4)';
  MF=1e-6/1e3;	unitsprefix='KMOL/UMOL';
elseif (strcmp(property,'botOXYGEN'));
  MultRho=1; MultCp=0;
  MF=(2*15.9994)/1e3/1e6; % kg/micromol O_2
  MF=MF/1e3; unitsprefix='1e3(KG/UMOL O2)';
elseif (strcmp(property,'ctdsal'));
  MultRho=1; MultCp=0;
  MF=1/1e3/1e6; unitsprefix='1e6';
elseif (strcmp(property,'ctdtemp') | ...
	strcmp(property,'ctdptmp') | ...
	strcmp(property,'ctdpotmp'));
  MultRho=1; MultCp=1;
  MF=1/1e15; unitsprefix='(PW S/KG)';
else
  MultRho=0; MultCp=0;
  MF=1/1e6; unitsprefix='1e6';
end;

% load model layers
glev;
if (nlyr==0) nlyr=1:length(glayers); end;

load gaussout sectfiles;
sect=sectfiles(sectnum,:);
rawsect=sect;
for j=1:size(sect,1);
  for i=1:size(sect,2);
    if (strcmp(sect(j,i),'.'));
      sect2=sect(j,1:i-1);
    elseif (strcmp(sect(j,i),'/'));
      origsect=sect(j,i+1:length(sect));
    end;
  end;
  sect(j,1:length(sect2))=sect2;
  rawsect(j,1:length(sect2))=sect2;
  sect(j,length(sect2)+1:size(sect,2))=' ';
  rawsect(j,length(sect2)+1:size(sect,2))=' ';
  rawsect(j,length(sect2)+1:length(sect2)+4)='_raw';
  clear sect2;
end;

% load the directory of the original 
% (before prepctd) section
eval(['load ',rawsect,' directory']);
origsect=[directory,'/',origsect];

% load the locations of the casts and
% the property field
eval(['load ',origsect,' lon lat ctdpres ctdsal ctdtemp']);
if (strcmp(property,'ctdptmp') | ...
	 strcmp(property,'ctdpotmp'));
  ctdptmp=sw_ptmp(ctdsal,ctdtemp,ctdpres* ...
        ones(1,length(lon)),zeros(size(ctdsal)));
  property='ctdptmp';
elseif (strcmp(property,'volume'));
  property='ctdsal./ctdsal';
else
  eval(['load ',origsect,' ',property]);
end;
if (strcmp(property(1:3),'bot'))
  eval(['load ',origsect,' heads units']);
  for j=1:length(units)
    if strcmp(['bot',char(heads(j))],property)
      Units=char(units(j));
    end;
  end;
  units=Units;
end;
clear heads Units
eval(['load ',rawsect,' Ln']);
eval(['prop=',property,';']);

%% debugging code %%%%%%%%%%%%%%%%
%prop=ones(size(prop));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if (MultRho)
  rho=sw_dens(ctdsal,ctdtemp, ...
	ctdpres*ones(1,length(lon)));
  prop=prop.*rho;
  units=['(',units,')(KG/S)'];
else 
  units=['(',units,')(M^3/S)'];
end;
if (MultCp)
  Cp=sw_cp(ctdsal,ctdtemp, ...
        ctdpres*ones(1,length(lon)));
  prop=prop.*Cp;
end;
units=[unitsprefix,units];
prop=prop.*MF;

% calculate prop in layer coordinates
layprop=NaN*ones(length(glayers),length(lon));
for j=1:length(lon);
  for i=1:length(glayers);
    q=find(Ln(:,j)==i);
    if (length(q))
      layprop(i,j)=nanmean(prop(q,j));
    end;
  end;
end;

% interpolate to station pair locations
lon2=lon(1:length(lon)-1)+diff(lon)/2;
lat2=lat(1:length(lat)-1)+diff(lat)/2;
layprop2=NaN*ones(size(layprop,1),length(lon2));
for i=1:length(lon2);
  layprop2(:,i)=nanmean([layprop(:,i),layprop(:,i+1)]')';
end;
clear lon lat prop layprop;

% load necessary fields from gaussout
load gaussout lon lat D A Ax ind* Pxx sectlabel EkmanE

% identify relevant station pair indices
%stind=NaN*ones(length(lon2),1);
%for i=1:length(stind);
  %q=find(lon==lon2(i) & lat==lat2(i));
  %stind(i)=q;
%end;

layprop2=fillnans(layprop2,0);

% calculate transports
q=find(sectlabel==sectnum);
pfluxref=sum( ...
	Ax(indb(nlyr,1,boxnum),indv(q)).* ...
	layprop2(nlyr,:) ,2);
pfluxrel=-sum( ...
	D(indb(nlyr,1,boxnum),indv(q)).* ...
	layprop2(nlyr,:) ,2);
pfluxek=EkmanE(nlyr,1,boxnum,sectnum).* ...
	nanmean(layprop2(nlyr,:)')';

% calculate associated errors
h=A(indb(nlyr,1,boxnum), ...
	[indv(q);indE(unique(sectlabel(q)))])';
% multiply h by property concentration:
%   matrix layprop2, and an extra row containing the
%   layer mean values (for the Ekman transport)
h=h.*[layprop2(nlyr,:)';nanmean(layprop2(nlyr,:)')];
eref=sum(sum(h'*Pxx( ...
	[indv(q);indE(unique(sectlabel(q)))], ...
	[indv(q);indE(unique(sectlabel(q)))])*h));
eref=sqrt(eref);

pflux=NaN*ones(2,1);
pflux(1)=nansum(pfluxref+pfluxrel+pfluxek);
pflux(2)=eref;
fprintf('%s transport: %6.2f +- %6.2f', ...
	property,keepsigfigs(pflux(1),3), ...
	keepsigfigs(pflux(2),3));
fprintf('  in layers %d-%d, into box %d.\n', ...
	min(nlyr),max(nlyr),boxnum);
fprintf('  units: %s\n',units);

plot(pfluxref+pfluxrel+pfluxek,nlyr, ...
	pfluxref+pfluxrel+pfluxek,nlyr, ...
	'.k','markersize',15)
grid on;
set(gca,'ydir','reverse')
xlabel([property,' transport, ',units]);
ylabel('layer number');
title(['Net: ',num2str(keepsigfigs(pflux(1),3)), ...
	'\pm',num2str(keepsigfigs(pflux(2),3))]);


