% changeairsea.m
%
% Set the air/sea fluxes of heat and freshwater,
% and the resulting formation/transformation,
% equal to one of the climatologies.  
% allow the model to adjust these within 1%
% (basically fixed ... allow 10% for Ekman)
% 
% In boxes against Antarctica, and for the
% Arctic/GIN Seas box, increase
% the errors to 100% to allow for much larger
% adjustments.  Find the layer which has the
% maximum error, and assign this error to all
% denser layers as well.  This adjustment will 
% accomodate processes such as heat loss in
% polynyas, e.g. layers with zero fluxes in the
% coarsly-gridded climatologies.

clear all;
geo;
nboxes=size(geometry,1);
load gaussout Fcorr_multfact

climatnumber=5;  % climatology number. 
                % set to 0 for ensemble mean.
                % 1=UWM/COADS, 2=SOC unadj. 3=SOC adj. 
		        % 4=NCEP, 5=ERA-15

glev;
disp('Loading geometry file "geo".');
file_geom='geo'; eval(file_geom);
if (climatnumber==1)
    climname='UWM/COADS';
elseif (climatnumber==2)
    climname='SOC/COADS (unadjusted)';
elseif (climatnumber==3)
    climname='SOC/COADS (adjusted)';
elseif (climatnumber==4)
    climname='NCEP/NCAR Reanalysis V2';
elseif (climatnumber==5)
    climname='ECMWF Reanalysis 15yr';
else
    climname='unknown';
end;
fprintf('Switching air-sea fluxes to %s.\n',climname);

for boxnum=1:nboxes;
    loadairseaclims; % calculate t* vectors
    errF=0.01;  % only 1% adjustment - basically fixed.
    errF_ek=.1;
  
    if (climatnumber>0)
        
    Ffw=[tFfw(climatnumber,:);errF*abs(tFfw(climatnumber,:))];
    Fh=[tFh(climatnumber,:);errF*abs(tFh(climatnumber,:))];
    Fm=[tFm(climatnumber,:);errF*abs(tFm(climatnumber,:))];
    Mm=[tMm(climatnumber,:);errF*abs(tMm(climatnumber,:))];
    EkmanInM_range=errF_ek*abs(sum(tEkmanInM(:,:,climatnumber))');
    
    Mhek=[tMhek(climatnumber,:)];
    Mmek=[tMmek(climatnumber,:)];
    Msek=[tMsek(climatnumber,:)];
    EkmanInM=[tEkmanInM(:,:,climatnumber)];
    EkmanInH=[tEkmanInH(:,:,climatnumber)];
    EkmanInS=[tEkmanInS(:,:,climatnumber)];
    EkmanInSalt=[tEkmanInSalt(:,:,climatnumber)];
    SSArea=[tSSArea(climatnumber,:)];
    SSSbar=[tSSSbar(climatnumber,:)];
    SSTbar=[tSSTbar(climatnumber,:)];
    
    else % climatnumber==0
        
    Ffw=[mean(tFfw,1);errF*abs(mean(tFfw,1))];
    Fh=[mean(tFh,1);errF*abs(mean(tFh,1))];
    Fm=[mean(tFm,1);errF*abs(mean(tFm,1))];
    Mm=[mean(tMm,1);errF*abs(mean(tM,1))];
    EkmanInM_range=errF_ek*abs(sum(EkmanInM)');
    
    Mhek=[mean(tMhek,1)];
    Mmek=[mean(tMmek,1)];
    Msek=[mean(tMsek,1)];
    EkmanInM=[mean(tEkmanInM,3)];
    EkmanInH=[mean(tEkmanInH,3)];
    EkmanInS=[mean(tEkmanInS,3)];
    EkmanInSalt=[mean(tEkmanInSalt,3)];
    SSArea=[mean(tSSArea,1)];
    SSSbar=[mean(tSSSbar,1)];
    SSTbar=[mean(tSSTbar,1)];   
        
    end;
    
    eval(['save airsea',num2str(boxnum), ...
        ' Ekman* F* M* SS* si_flux' ...
        ' glevels glayers gamma2 climatnumber']);
end;

if (0)
%%% Outer Weddell
boxnum=getboxnum(0,-64,nboxes);
changeairsea_antbox;

%%% Inner Weddell, Atlantic sector
boxnum=getboxnum(-50,-72,nboxes);
changeairsea_antbox;

%%% Antarctic, Ross box
boxnum=getboxnum(-140,-70,nboxes);
changeairsea_antbox;

%%% Antarctic, Amery box
boxnum=getboxnum(110,-64,nboxes);
changeairsea_antbox;

%%% Arctic/GIN Seas box
boxnum=getboxnum(0,75,nboxes);
if (length(boxnum))
    changeairsea_antbox;
end;

end;
