
% i05p_con: southward fluxes (>0) across I05p (32S)
%	in the Indian Ocean.
%
%   Added 17 Nov 2003: Agulhas constraint from
%       Bryden and Beal (DSR 48(8), 2001)
%   Added 27 Feb 2004: Leeuwin Current/undercurrent
%	constraint from Feng et al (2003), JGR 108 (C11), 3355.
%   Modified deep/bottom water cul-de-sac constraints from 
%       Ganachaud (1999) after pers. comm. with Lisa Beal.  
%   Now: Moz Basin is a cul-de-sac 
%           (Gan. had 1+-2 Sv northward at gamma>28.11)
%       Madagascar Basin inflow feeds DWBC: 
%           1+-5 Sv northward here
%           (Gan. treated this as a cul-de-sac)

BoxNum=getboxnum(80,-40,nboxes); % SO, Ind sector
sectlon=lon(find(sectlabel==sectname2sectnum('i05p')));

% Indian Ocn -> SO (Indonesian throughflow)
%  minus net E-P-R (0.37Sv) in Indian Ocn N. of I05p
sectnum=sectname2sectnum('i05p');
statnum=[];
propnum=1;boxnum=BoxNum;
layernum=nlayers+1;
fluxvalue=ipt_Vflux-0.37e6;
fluxerror=sqrt(eipt_Vflux^2+masssecterror(sectnum)^2);
addcon;

% 0+-.5 Sv AABW into Natal Valley
layernum=find(glayers>28.11);
statnum=find(sectlon>30 & sectlon<34);
sectnum=sectname2sectnum('i05p');
propnum=1;boxnum=BoxNum;
fluxvalue=0;fluxerror=0.5e6;
addcon;

% 0+-1 Sv deep water into Mozambique basin
% Ganachaud: (-)1+-2 Sv  northward
layernum=find(glayers>28.11);
statnum=find(sectlon>35 & sectlon<46);
sectnum=sectname2sectnum('i05p');
propnum=1;boxnum=BoxNum;
fluxvalue=0;fluxerror=1e6;
addcon;

% Johnson, Musgrave, Warren, Ffield and Olson, 
% 1998: JGR 103(C13), 30973-30984:
% Northward DWBC in Mascarene Basin fed by
% 2.5-3.8 Sv deep water (pot.tmp<1.1degC,
% gamma>28.13) through Madagascar-Crozet
% Basin segment of the section
layernum=find(glayers>28.13);
statnum=find(sectlon>47 & sectlon<76.5);
sectnum=sectname2sectnum('i05p');
propnum=1;boxnum=BoxNum;
fluxvalue=-3.15e6;fluxerror=1e6;
addcon;

% 0+-1 Sv AABW into Central Basin
layernum=find(glayers>28.11);
statnum=find(sectlon>78 & sectlon<89);
sectnum=sectname2sectnum('i05p');
propnum=1;boxnum=BoxNum;
fluxvalue=0;fluxerror=1e6;
addcon;

% Bernadette Sloyan (presentation at Nice EGU 2004):
%  10 moorings, 9 recovered between Broken and
%  Naturaliste Plateaus (102-110 E), June 1995 to
%  September 1996.  Analysis shows deep northward flow:
%   0.6C < theta < 1.4C:  2.1 Sv.   
%     IO5p, station 89 (105.7E):  3080-4590dbar, 28.09<gamman<28.2
%   <0.6C: 1.6 Sv.
% BS estimated total deep Nward flow: 3.7+-0.4 Sv at theta<1.4C
layernum=find(glayers>=28.09);
statnum=find(sectlon>102 & sectlon<110);
sectnum=sectname2sectnum('i05p');
propnum=1;boxnum=BoxNum;
fluxvalue=-3.7e6;fluxerror=.4e6;
addcon;

% Bryden and Beal (DSR 48 (8), 1821-2845, 2001): 
% Net 63-70Sv southward in Agulhas Current
% (within 160km of Africa; pairs 1-10)
layernum=nlayers+1;
statnum=find(sectlon<31.5);
sectnum=sectname2sectnum('i05p');
propnum=1;boxnum=BoxNum;
fluxvalue=67e6;fluxerror=5e6;
addcon;

% Feng et al (JGR 108 (C11), 3355, 2003):
% Net 3.4Sv southward in Leeuwin Current region
layernum=nlayers+1;
statnum=find(sectlon>113.5);
sectnum=sectname2sectnum('i05p');
propnum=1;boxnum=BoxNum;
fluxvalue=3.4e6;fluxerror=1e6;
addcon;

clear BoxNum sectlon;
