function [F,sectlon]=cumlatflux(massnum,propnum,boxnum, ...
    sectnum,west2east,gfilename);

% function [F,lon]=cumlatflux(massnum,propnum,boxnum, ...
%   sectnum,west2east,gaussout_filename);
%
% Plot the cumulative transport across section "sectnum"
% in layer or layers defined by indices "nlyr", into
% box "boxnum" (negative is out of the box).  If
% "west2east"~=0 (default), the integration begins at
% the western boundary of the section

multfact=1;
smoothcurve=0;  % 3-pt smoother

if ~exist('west2east')
  west2east=1;
end;
if ~exist('gfilename');
    gfilename='gaussout';
end;

% load model layers
glev

waterdiv;
if (massnum<0 & length(massnum)==1)
  titl=['layer ',num2str(-massnum)];
  nlyr=-massnum;
elseif (massnum<0)
  titl=['layers ',num2str(-(max(massnum))), ...
        '-',num2str(-(min(massnum)))];
  nlyr=-massnum;
elseif (massnum==0)
  titl='net';
  nlyr=1:length(glayers);
elseif (massnum==1)
  titl=waterdivslab(massnum,:);
  nlyr=find(glayers<waterdivs(massnum));
elseif (massnum==length(waterdivs)+1)
  titl=waterdivslab(massnum,:);
  nlyr=find(glayers>=last(waterdivs));
elseif (massnum>1 & massnum<length(waterdivs)+1)
  titl=waterdivslab(massnum,:);
  nlyr=find(glayers>=waterdivs(massnum-1) & ...
        glayers<waterdivs(massnum));
end;

eval(['load ',gfilename,' sectfiles']);
sect=sectfiles(sectnum,:);
rawsect=sect;
for j=1:size(sect,1);
  for i=1:size(sect,2);
    if (strcmp(sect(j,i),'.'));
      sect2=sect(j,1:i-1);
    elseif (strcmp(sect(j,i),'/'));
      origsect=sect(j,i+1:length(sect));
    end;
  end;
  sect(j,1:length(sect2))=sect2;
  rawsect(j,1:length(sect2))=sect2;
  sect(j,length(sect2)+1:size(sect,2))=' ';
  rawsect(j,length(sect2)+1:size(sect,2))=' ';
  rawsect(j,length(sect2)+1:length(sect2)+4)='_raw';
  clear sect2;
end;

% load necessary fields from gaussout
eval(['load ',gfilename,' lon lat D A Ax ind* Pxx', ...
	' sectlabel EkmanE lon lat fluxdivfact']);

q=find(sectlabel==sectnum);
if (   ( last(lon(q))<lon(q(1)) & west2east) | ...
	(last(lon(q))>lon(q(1)) & ~west2east) )
  q=flipud(q);
end;
sectlon=lon(q);sectlat=lat(q);

pfluxref=NaN*ones(size(q));
pfluxrel=pfluxref;eref=pfluxref;
for i=1:length(q);
  pfluxref(i)=sum(sum(Ax(indb(nlyr,propnum,boxnum), ...
	indv(q(1:i)))));
  pfluxrel(i)=-sum(sum(D(indb(nlyr,propnum,boxnum), ...
	indv(q(1:i)))));
  h=A(indb(nlyr,propnum,boxnum),indv(q(1:i)))';
  eref(i)=sqrt(  sum(sum(h'*Pxx(indv(q(1:i)),indv(q(1:i)))*h))  );
end;

% EkIn: the total Ekman flux across that section
% (individual station pair information has not been saved).
EkIn=sum(EkmanE(nlyr,propnum,boxnum,sectnum),1);
if (EkIn)
  % distribute EkIn evenly among the station pairs
  % (cum. sum climbs steadily to total EkIn)
  EkIn=(EkIn/length(q):EkIn/length(q):EkIn)';
else
  EkIn=zeros(size(pfluxref));
end;

pfluxref=multfact*pfluxref/fluxdivfact(propnum);
eref=abs(multfact)*eref/fluxdivfact(propnum);
pfluxrel=multfact*pfluxrel/fluxdivfact(propnum);
EkIn=multfact*EkIn/fluxdivfact(propnum);

netflux=pfluxref+pfluxrel+EkIn;

tkspc=round(length(sectlon)/8);
if (max(diff(sectlon))>0 & min(diff(sectlon))<0)
  sectlab=num2str(round(10*sectlon(1:tkspc:length(sectlon)))/10);
  sectlon=(1:length(sectlon))';
  secttik=1:tkspc:length(sectlon);
end;

if (smoothcurve)
    netflux2=netflux;
    for i=2:length(netflux)-1;
        netflux(i)=.25*netflux(i-1)+.5*netflux(i) ...
            +.25*netflux(i+1);
    end;
end;

plot(sectlon,netflux,'k');
hold on;
line([min(sectlon) max(sectlon)],[0 0],'color',[.75 .75 .75]);
patch([sectlon;flipud(sectlon)], ...
	[netflux+eref;flipud(netflux-eref)], ...
	[.5 .5 .5],'edgecolor','none');
plot(sectlon,netflux,'k','linewidth',2);
hold off;
if (exist('sectlab'))
  set(gca,'xtick',secttik,'xticklabel',sectlab);
end;

% identify and print max abs value
q=find(abs(netflux)==max(abs(netflux)));
fprintf('Maximum value: %3.1f+-%3.1f\n',netflux(q), ...
    eref(q));
% identify max range from this value to inshore.
dnetflux=diff(netflux); flag=1;
for i=q-1:-1:2;
    if (sign(dnetflux(i))~=sign(dnetflux(i-1)) & flag)
        q2=i;
        flag=0;
    end;
end;
%fprintf('Range: %3.1f+-%3.1f\n',netflux(q)-netflux(q2), ...
%    eref(q));

if (west2east)
  titl=[titl,' west-to-east cumulative transport'];
else
  titl=[titl,' east-to-west cumulative transport'];
end;
title(titl,'fontsize',15);

F=[netflux eref];

