function Vmag=defVmag(section,reflevel,floorVmag,WBCwidth,WBCmag);

% function Vmag=defVmag(section,reflevel,floorVmag,WBCwidth,WBCmag);
%
% Define Vmag, the magnitude of the a priori std dev.
% of Vref.  This is the correction to the level-of-no-motion
% in the inversion.  Assume the correction can be +-250 dbar
% (bottom to bottom+250, if reflevel shoals;
% surface to 250dbar, if reflevel outcrops)
% Use "floorVmag" to define a minimum value for Vmag.
% REFERENCE: Ganachaud (dissertation, 1998, pg. 61).
%
% If WBCmag>0, find all station pairs within WBCwidth
% (km) of the western boundary and set Vmag=WBCmag for
% those pairs.

errorrange=250;	% error is +-errorrange (dbar)

eval(['load ',section, ...
	' binPair_vel bin_press surf_press lon lat bottom']);
f=2*7.2921e-05*sin(lat*2*pi/360);

% calculate Vbt=L^3 * grad(Hbar)
L=15e3;maxvel=.15;
dx=sw_dist(lat,lon,'km')*1e3;
% calculate H (smoothed bottom)
H=gausssmooth(bottom,[0 cumsum(dx)]',50e3)';
Hbar=H(1:length(H)-1)+diff(H)/2;
f=sw_f(lat);
Vbt=L.^3.*abs(diff(f./H))./dx;
q=find(Vbt>maxvel);Vbt(q)=maxvel;
% new method (29 July 2002): just grad(Hbar)
Vbt=10*abs(diff(H)./dx);
q=find(Vbt>maxvel);Vbt(q)=maxvel;

if strcmp(section(31:35),'ar19a' & 0)
  subplot(211);plot(-Hbar);
  subplot(212);plot(Vbt);keyboard;
end;
clear L maxvel dx H Hbar f

% convert lon, lat (stations) to lon, lat (station pairs)
lon=(lon(1:length(lon)-1)+diff(lon)/2)';
lat=(lat(1:length(lat)-1)+diff(lat)/2)';

Vmag=NaN*ones(1,size(binPair_vel,2));

if (1)	% calculate Vmag for +-errorrange adjustment
for stnp=1:length(Vmag);
  q=min(find(bin_press>=nanmean( ...
	surf_press(reflevel,stnp:stnp+1))));
  if (length(q));
    q=find(bin_press>=bin_press(q)-errorrange & ...
	bin_press<=bin_press(q)+errorrange);
  elseif (isfinite( max(surf_press(1:reflevel,stnp))  ))
	% ref level is "below" bottom, i.e. 
	% bottom ref level for this station pair
    q=max(find(isfinite(binPair_vel(:,stnp))));
    q=find(bin_press>=bin_press(q)-errorrange);
  else	% ref level outcrops, i.e. surf_press
	% is only defined for lighter gamma.
	%    (isfinite( max(surf_press( ...
	%    reflevel+1:nlayers-1,stnp))  )) == 1
    q=find(bin_press<=errorrange);
  end;
  q=binPair_vel(q,stnp);
  q=[min(q) max(q)];
  Vmag(stnp)=abs(diff(q));
end;
end;

if (1)	% assign larger of Vbt, Vmag
	% (do NOT set larger WBC values)
  fprintf('%s : using max(Vbt, Vmag).\n',section);
  q=find(Vmag<Vbt | isnan(Vmag));
  Vmag(q)=Vbt(q);
  q=find(Vmag<floorVmag);
  Vmag(q)=floorVmag;
else

% impose floor; use this smallest value to fill
% NaNs in Vmag (station pairs where there is no
% hydrography, i.e. joining points of two sections)
q=find(Vmag<floorVmag | isnan(Vmag));
Vmag(q)=floorVmag;

if (WBCmag>0);	% set a larger floor for the WBC
  fprintf('%s : magnifying Vref in WBC.\n',section);
  q=find(lon==min(lon));
  del=NaN*ones(size(lon));
  for i=1:length(del);
    del(i)=sw_dist([lat(i) lat(i)],[lon(i) lon(q)],'km');
  end;
  q=find(del<=WBCwidth);
  Vmag(q)=max([Vmag(q);WBCmag*ones(1,length(q))]);
end;

end;	% if-loop for Vbt or WBC magnification
