
function [lon_ncep,lat_ncep,lonvec,latvec,index, ...
        sst,longwave,shortwave,latent,sensible,...
        evap,precip,taux,tauy]=loadncepfluxes(year);

% function [lon_ncep,lat_ncep,lonvec,latvec,index, ...
%       sst, longwave,shortwave,latent,sensible,...
%       evap,precip,taux,tauy]=loadncepfluxes(year);
%
% load a year (>=1979) of monthly 
% observations from the NCEP/NCAR reanalysis 2 fields.
% Output is mean + anomaly.   evap, precip in m/s

directory='/phod008/lumpkin/ncep2';

eval(['lon_ncep=getnc(''',directory, ...
	'/lsmask.19294.nc'',''lon'');']);
% break data at dateline instead of prime meridian
q=find(lon_ncep>=180);
lon_ncep(q)=lon_ncep(q)-360;
[lon_ncep,ind_lon]=sort(lon_ncep);
eval(['lat_ncep=getnc(''',directory, ...
        '/lsmask.19294.nc'',''lat'');']);
eval(['landmask=getnc(''',directory, ...
        '/lsmask.19294.nc'',''lsmask'');']);
% redefine so landmask=1 over ocean, NaN over land
landmask=landmask+1;
landmask(find(~landmask))=NaN;

if (year<0)
  disp('Loading NCEP/NCAR Reanalysis 2 long-term monthly means');
  load /phod008/lumpkin/ncep2/ncep;
  return;
else
  if (year>45 & year<1900);
    year=year+1900;
  elseif (year>=0 & year<45);
    year=year+2000;
  end;
  fileext='.sfc.mon.mean.nc';
  fprintf('Loading NCEP/NCAR fields, year %d.\n',year);
  eval(['t=getnc(''',directory, ...
        '/lhtfl',fileext,''',''time'');']);

  % unit of time: hours since 1/1/1800
  t=t/24+julian([1800,1,15,0,0,0]);
  q=find(t>=julian([year,1,1,0,0,0]) & ...
	t<=julian([year,12,31,0,0,0]));
  corner=[q(1) -1 -1];
  endpt=[last(q) -1 -1];
  stride=[1 -1 -1];
end

% load, changing all heat flux signs to retain
% convention that POSITIVE = heat INTO ocean
eval(['latent=-getnc(''',directory, ...
	'/lhtfl',fileext,''',''lhtfl''', ...
	',corner,endpt,stride);']);
eval(['sensible=-getnc(''',directory, ...
        '/shtfl',fileext,''',''shtfl''', ...
        ',corner,endpt,stride);']);
eval(['dlongwave=getnc(''',directory, ...
        '/dlwrf',fileext,''',''dlwrf''', ...
        ',corner,endpt,stride);']);
eval(['ulongwave=getnc(''',directory, ...
        '/ulwrf',fileext,''',''ulwrf''', ...
        ',corner,endpt,stride);']);
longwave=dlongwave-ulongwave;
clear dlongwave ulongwave;
eval(['dshortwave=getnc(''',directory, ...
        '/dswrf',fileext,''',''dswrf''', ...
        ',corner,endpt,stride);']);
eval(['ushortwave=getnc(''',directory, ...
        '/uswrf',fileext,''',''uswrf''', ...
        ',corner,endpt,stride);']);
shortwave=dshortwave-ushortwave;
clear dshortwave ushortwave;
eval(['sst=getnc(''',directory, ...
        '/skt',fileext,''',''skt''', ...
        ',corner,endpt,stride);']);
% convert from K to degC
sst=sst-273;
eval(['taux=-getnc(''',directory, ...
        '/uflx',fileext,''',''uflx''', ...
        ',corner,endpt,stride);']);
eval(['tauy=-getnc(''',directory, ...
        '/vflx',fileext,''',''vflx''', ...
        ',corner,endpt,stride);']);
eval(['precip=getnc(''',directory, ...
        '/prate',fileext,''',''prate''', ...
        ',corner,endpt,stride);']);

% define netheat
%netheat=latent+sensible+longwave+shortwave;

%disp('netheat not really net!!!')
%netheat=shortwave;

% calculate evaporation from latent heat flux
Le=(2494-2.2*sst)*1000;		% lat.heat of evap. [J/kg]
evap=-latent./Le;		% evaporation [kg/m^2/s]

% calculate eminusp
%eminusp=evap-precip;
% convert evap, precip from kg/m^2/s to m/s
evap=evap/1000;
precip=precip/1000;

% re-order variables so longitude is -180:180
landmask=landmask(:,ind_lon);
latent=latent(:,:,ind_lon);
sensible=sensible(:,:,ind_lon);
longwave=longwave(:,:,ind_lon);
shortwave=shortwave(:,:,ind_lon);
sst=sst(:,:,ind_lon);
taux=taux(:,:,ind_lon);
tauy=tauy(:,:,ind_lon);
evap=evap(:,:,ind_lon);
precip=precip(:,:,ind_lon);
clear ind_lon;

% reshape data to have the same format as
% the COADS fields (time,index)
index=1:size(landmask,1)*size(landmask,2);
landmask=reshape(landmask, ...
	[1 size(landmask,1)*size(landmask,2)]);
lonvec=ones(length(lat_ncep),1)*lon_ncep';
latvec=lat_ncep*ones(1,length(lon_ncep));
lonvec=reshape(lonvec, ...
	[1 size(landmask,1)*size(landmask,2)]);
latvec=reshape(latvec, ...
        [1 size(landmask,1)*size(landmask,2)]);
latent=reshape(latent,[size(latent,1) ...
	size(latent,2)*size(latent,3)]);
sensible=reshape(sensible,[size(latent,1) ...
	size(latent,2)*size(latent,3)]);
longwave=reshape(longwave,[size(latent,1) ...
	size(latent,2)*size(latent,3)]);
shortwave=reshape(shortwave,[size(latent,1) ...
	size(latent,2)*size(latent,3)]);
sst=reshape(sst,[size(sst,1) ...
        size(sst,2)*size(sst,3)]);
taux=reshape(taux,[size(sst,1) ...
        size(sst,2)*size(sst,3)]);
tauy=reshape(tauy,[size(sst,1) ...
        size(sst,2)*size(sst,3)]);
evap=reshape(evap,[size(sst,1) ...
        size(sst,2)*size(sst,3)]);
precip=reshape(precip,[size(sst,1) ...
        size(sst,2)*size(sst,3)]);

% retain values over the ocean
q=find(isfinite(landmask));
index=index(q);
lonvec=lonvec(q);
latvec=latvec(q);
latent=latent(:,q);
sensible=sensible(:,q);
longwave=longwave(:,q);
shortwave=shortwave(:,q);
sst=sst(:,q);
taux=taux(:,q);
tauy=tauy(:,q);
evap=evap(:,q);
precip=precip(:,q);
clear landmask

%F=NaN*ones(length(lat_ncep),length(lon_ncep));
%F(index)=(1000*3600*24*365.24)*mean(eminusp,1);
%patchmap(lon_ncep,lat_ncep,F);
%colorbarvert

% load Levitus94 sea-surface salinity, interpolated
% onto NCEP grid via makesss.m (in NCEP directory)
eval(['load ',directory,'/sss sss;']);

% NaN-out values which contain ice temp in sst
% (allow a 1 psu increase in sss to account
% for possible monthly anomaly)
sstf=sw_fp(sss+1,zeros(size(sss)));
q=find(sst<sstf | isnan(sstf));
sst(q)=NaN;
evap(q)=NaN;
precip(q)=NaN;
latent(q)=NaN;
sensible(q)=NaN;
longwave(q)=NaN;
shortwave(q)=NaN;
taux(q)=NaN;
tauy(q)=NaN;


