function checkgeo(file_geom);

% checkgeo.m
%
% graphically check the geometry file for a box
% to make sure the sections and corresponding
% "geometry" values are correct.

clf;

if (exist('file_geom')) eval(file_geom); else geo; end;

Lon=[];Lat=[];
for i=1:size(geometry,2);
  eval(['load ',sectfiles(i,:),' lon lat']);
  Lon=[Lon;lon'];Lat=[Lat;lat'];
  q=find(Lon<-180);Lon(q)=Lon(q)+360;
  q=find(Lon>180);Lon(q)=Lon(q)-360;
end;

makemap([min(min(Lon)-10,-100) max(Lon)+10], ...
        [min(Lat)-10 max(Lat)+10],0,1);

colr=[[1 0 0];[0 0 1];[.14 .55 .14]; ...
	[.8 .8 0];[.8 0 .8];[.5 .5 .5]; ...
	[.87 .72 .53];[1 .5 .3]; ...
	[1 .4 .7];[1 .84 0]; ...
	[.94 .9 .55];[.13 .7 .67]; ...
	[0 0 .5];[.55 .27 .07]; ...
	[0 .5 .5];[1 .39 .28]];
[n,i]=sort(rand(size(colr,1),1));
colr=colr(i,:);
if (size(colr,1)<size(geometry,1))
  colr=[colr;rand( ...
	size(geometry,1)-size(colr,1),3)];
end;
colr=colr(1:size(geometry,1),:);

hold on;
for i=1:size(geometry,2);	% loop through sections
  eval(['load ',sectfiles(i,:),' lon lat']);
  if (0);	% wraparound
    q=find(lon<-180);
    lon2=lon(q)+360;lat2=lat(q);lon(q)=[];lat(q)=[];
    q=find(lon>180);
    lon3=lon(q)-360;lat3=lat(q);lon(q)=[];lat(q)=[];
  else lon2=[]; lon3=[];
  end;
  if length(lon) m_plot(lon,lat,'k'); end;
  if length(lon2) m_plot(lon2,lat2,'k'); end;
  if length(lon3) m_plot(lon3,lat3,'k'); end;
  [d,theta]=sw_dist([lat(1) last(lat)], ...
	[lon(1) last(lon)],'km');
  mlon=median(lon); mlat=median(lat);
  for j=1:size(geometry,1);	% loop through boxes
    if (geometry(j,i)~=0)
      theta2=theta*2*pi/360+geometry(j,i)*pi/2;
      theta2=theta2+.1*randn(1,1);
      P=m_quiver([mlon 0],[mlat 0], ...
	5*[cos(theta2) 0],5*[sin(theta2) 0],0);
      set(P,'color',colr(j,:));
    end;
  end;
  m_plot(mlon,mlat,'.w','markersize',15);
  m_text(mlon,mlat,num2str(i),'fontsize',8, ...
	'horizontalalignment','center');
end;
% Add box numbers in middle of each box.
for j=1:size(geometry,1);	% loop through boxes
  Lon=[];Lat=[];
  for i=1:size(geometry,2);	% accumulate lat, lon
    if (abs(geometry(j,i)));
      eval(['load ',sectfiles(i,:),' lon lat']);
      Lon=[Lon,lon];Lat=[Lat,lat];
    end;
  end;
  Lon=mean(Lon);Lat=mean(Lat);
  if (exist('file_geom'))
    eval(['load boxcoords',num2str(j)]);
    Lon=(max(lon)+min(lon))/2;
    Lat=(max(lat)+min(lat))/2;
    m_text(Lon,Lat,num2str(j),'fontsize',15, ...
	'horizontalalignment','center', ...
	'verticalalignment','middle', ...
	'color',colr(j,:));
  end;
end;
hold off;
disp('Arrows should point into boxes.');

titl=pwd;
title(['Geometry of ',titl],'fontsize',15);

clear Lat Lon P colr d i j lat lon mlat mlon
clear theta theta2 titl
