% makeairsea_onepoint.m
%
% Calculate the surface forcing for transformation
% of mass, heat and salt in a given region of the
% ocean.  Air-sea fluxes and winds from NCEP/NCAR
% reanalysis or from UWM/COADS and SOC COADS.
%
% Applied to a very small area (subgrid in
% NCEP fields): area is given, and the fluxes
% from the closest point of COADS/NCEP are used.

clear all;

Area=130e3 * 100e3

% input the years from the UWM/COADS flux fields
% to apply to the inverse model.
% e.g. year=[88 89] for Jan. 1988 - Dec. 1989
% year=[-99] for the climatology
year=input('Year(s) (-99 for monthly climatology)? ');
q=find(year>1900);
if (length(q)) year(q)=year(q)-1900; end;


% loop through the climatologies
for flag_clim=1:2;

flag_fw=1;	% set to zero for no net E-P-R
flag_h=1;	% set to zero for no net heat
error_multfact=.2;	% fractional error in air-sea fluxes

sacdir='/phod007/lumpkin/sac/';
riverdir='/phod007/lumpkin/runoff/catalog/';
levitusdir='/phod007/lumpkin/levitus94/';

disp('Loading geometry file "geo".');
file_geom='geo';
eval(file_geom);
nboxes=size(geometry,1);

error_corrdist=20;	% length scale (in grid points)
			% of errors in air-sea fields

%... Load neutral density surface of inverse model
load glevels;
glayers=[glevels(1)-.5*(glevels(2)-glevels(1)); ...
        glevels(1:length(glevels)-1)+diff(glevels)/2; ...
        last(glevels)+last(diff(glevels))/2];
%gamma2=[glevels(1)-diff(glevels(1:2)); ...
        %glevels;last(glevels)+last(diff(glevels))];

%%%%%%%%%%
% LOOP THROUGH BOXES
%%%%%%%%%%

for boxnumber=1:nboxes;
clf;
fprintf('\n     BOX %d\n\n',boxnumber);

%%%%%%%%%%%%%%%%%%%%%%%%%%
% LOAD AIR-SEA FLUX DATA %
%%%%%%%%%%%%%%%%%%%%%%%%%%

if (flag_clim==1)
  sss=NaN*ones(12*length(year),42164);
else
  sss=NaN*ones(12*length(year),12134);
end
sst=sss;netheat=sss;eminusp=sss;
taux=sss;tauy=sss;
netheat_soc=NaN*ones(12*length(year),13516);
for y=1:length(year);

  if (flag_clim==1)
    [lon_coads,lat_coads,lonvec,latvec, ...
        sss(12*(y-1)+1:12*y,:), index, ...
        sst(12*(y-1)+1:12*y,:), ...
        netheat(12*(y-1)+1:12*y,:), ...
        eminusp(12*(y-1)+1:12*y,:), ...
        taux(12*(y-1)+1:12*y,:), ...
        tauy(12*(y-1)+1:12*y,:)]= ...
        loadcoadsyear(year(y));

  else	% (flag_clim==2)
    [lon_coads,lat_coads,lonvec,latvec, ...
        sss(12*(y-1)+1:12*y,:), index, ...
        sst(12*(y-1)+1:12*y,:), ...
        netheat(12*(y-1)+1:12*y,:), ...
        eminusp(12*(y-1)+1:12*y,:), ...
        taux(12*(y-1)+1:12*y,:), ...
        tauy(12*(y-1)+1:12*y,:)]= ...
        loadncepyear(year(y));
  end;

  %[lon_soc,lat_soc,lonvec_soc,latvec_soc, ...
        %index_soc,netheat_soc(12*(y-1)+1:12*y,:)]= ...
        %loadsocyear(year(y));

end;
clear y;
eval(['load ',riverdir,'newrivers;']);

%%% extract closest points %%%
eval(['load boxcoords',num2str(boxnumber)]);
%q=find(lonvec>max(lon)+max(abs(diff(lon_coads))) | ...
	%lonvec<min(lon)-max(abs(diff(lon_coads))) | ...
	%latvec>max(lat)+max(abs(diff(lat_coads))) | ...
	%latvec<min(lat)-max(abs(diff(lat_coads))));
del=(lonvec-mean(lon)).^2+(latvec-mean(lat)).^2;
del2=sort(del);
q=find(del>del2(20));
truncatecoads;
del=(lonvec-mean(lon)).^2+(latvec-mean(lat)).^2;
closeptind=find(del==min(del));
taux_inbox=taux;tauy_inbox=tauy;

q=find(isinpoly(lon_river,lat_river,lon,lat)==0);
q=[q;find(isnan(lon_river))];
lon_river(q)=[];lat_river(q)=[];
river(q)=[];R(q)=[];si_flux(q)=[];

% calculate net silica input from rivers
si_flux=sum(si_flux);

% assign mean river fw flux to closest eminusp
orig_eminusp=eminusp;
disp('Adding river runoff.');
for riv=1:length(lon_river);
  del=(latvec-lat_river(riv)).^2+ ...
	(lonvec-lon_river(riv)).^2;
  del=find(del==min(del));
  eminusp(:,del)=eminusp(:,del)-R(riv)/Area;
  % R (m^3/s) divided by area (m^2) gives the
  % freshwater flux in units of m/s, same as eminusp.
end;
clear riv del

%%% replace heat flux with SOC heat flux
if (0)
  q=~isinpoly(lonvec_soc,latvec_soc,lon,lat);
  truncatesoc;
  clear q lon lat;
  disp('UWM -> SOC heat flux substitution.');
  index2=NaN*ones(size(index));
  for i=1:length(index2);
    q=find(index_soc==index(i));
    index2(i)=q;
  end;
  netheat=netheat_soc(:,index2);
else
  clear netheat_soc;
end;

if ~flag_fw eminusp=zeros(size(eminusp)); end;
if ~flag_h netheat=zeros(size(netheat)); end;

%%% load mixed layer depth %%%
if (flag_clim==1)
  eval(['load ',levitusdir,'ml_coadsgrid;']);
else	% flag_clim==2
  eval(['load ',levitusdir,'ml_ncepgrid;']);
end;
q1=find(lat_ml>=min(lat_coads) & lat_ml<=max(lat_coads));
q2=find(lon_ml>=min(lon_coads) & lon_ml<=max(lon_coads));
z_ml=ml(q1,q2,:);
clear lon_ml lat_ml ml q1 q2 ml_*grid

% calculate Ekman depth 
% (use a mean value of 1.3e-3 for the drag coefficient
%  in Tau=Rho_air * Cd * U_10^2; Rossby and Montgomery
%  (1935) value for Ekman depth z_ek=2.38 u_10/sin(lat).

z_ek=NaN*ones(size(z_ml));
for mon=1:size(z_ml,3);
  taux2=NaN*ones(length(lat_coads),length(lon_coads));
  tauy2=taux2;
  taux2(index)=taux(mon,:);
  tauy2(index)=tauy(mon,:);
  U10=sqrt(  sqrt(taux2.^2 + tauy2.^2) / 1.25 / 1.3e-3);
  z_ek(:,:,mon)= 2.38*U10./abs(sin(2*pi* ...
	lat_coads*ones(1,length(lon_coads))/360));
  clear taux2 tauy2 U10;
end;

% clear lon, lat (boxcoordsN vectors)
clear lon lat

% plot sea surface salinity field
sss2=NaN*ones(length(lat_coads),length(lon_coads));
sss2(index)=mean(sss,1);
plotsections;
hold on;
  m_plot(lonvec,latvec,'ok');
  m_plot(lon_river,lat_river,'*b');
hold off;
pause(.1);
%%%

% net heat std. error: error_multfact of net heat
% or 30 W/m^2 over error_corrdist^2
%netheaterr=30;
% E minus P error is maximum of:
% 1. error_multfact of net E-P on outcrop area, or
% 2. 1e-8 m/s E-P over error_corrdist^2

% calculate density, salt, heat fluxes 
calcflux;

% calculate matrix of area (m^2) for pixels
%area=sw_area(lon_coads,lat_coads);
%  ASSIGN Area to the closest point, 0 to the rest.
area=zeros(length(lat_coads),length(lon_coads));
area(find(lat_coads==latvec(closeptind)), ...
    find(lon_coads==lonvec(closeptind)))=Area;

% Calculate the net heat and freshwater
% fluxes, and the resulting density flux,
% as a function of gamma, on the glevels grid
disp('Integrating transformation over time, area.');
Fm=zeros(2,length(glevels));
Fh=Fm;Ffw=Fm;Ffw_norivers=Fm;
FmE=[];FhE=[];FfwE=[];LayE=[];
Mmek=zeros(1,length(glayers));
Epsilon=Mmek; numcells=Mmek;
Mhek=Mmek;Msek=Mmek;SSArea=Mmek;
SSTbar=Mmek; SSSbar=Mmek;
glayers_edge=glayers(1:length(glayers)-1);
glayers_edge(1)=-999;
glayers_edge=[glayers_edge;999];
gamma2_edge=[-999;glevels;999];

DaysInMonth=[31 28.25 31 30 31 30 31 31 30 31 30 31];
for month=1:size(sst,1);
  ssg2=NaN*ones(length(lat_coads), ...
	length(lon_coads));
  fm2=ssg2;fmerr2=ssg2;
  fh2=ssg2;fherr2=ssg2;
  ffw2=ssg2;ffwerr2=ssg2;
  ffw_norivers2=ssg2;
  sss2=ssg2;sst2=ssg2;
  ssg2(index)=ssg(month,:);
  fm2(index)=fm(month,:);
  fmerr2(index)=fmerr(month,:);
  fh2(index)=fh(month,:);
  fherr2(index)=fherr(month,:);
  ffw2(index)=ffw(month,:);
  ffw_norivers2(index)=ffw_norivers(month,:);
  ffwerr2(index)=ffwerr(month,:);
  sss2(index)=sss(month,:);
  sst2(index)=sst(month,:);
  Mek2=Mek(:,:,month);
  Sek2=Sek(:,:,month);
  Tek2=Tek(:,:,month);
  scalefact=DaysInMonth(month-12*floor((month-1)/12)) ./ ...
        mean(DaysInMonth);
  % loop through for terms defined on glevels grid
  for i=1:length(glevels);
    q=find(ssg2>=glayers_edge(i) & ssg2<glayers_edge(i+1));
    if (length(q))
      Fm(1,i)=Fm(1,i)+scalefact*nansum( ...
	fm2(q).*area(q)./ ...
	(glayers_edge(i+1)-glayers_edge(i)) );
      Fm(2,i)=Fm(2,i)+scalefact*nansum( ...
        fmerr2(q).*area(q)./ ...
	(glayers_edge(i+1)-glayers_edge(i)) );
      FmE=[FmE;scalefact*fmerr2(q).*area(q)./ ...
	(glayers_edge(i+1)-glayers_edge(i))];
      Fh(1,i)=Fh(1,i)+scalefact*nansum( ...
        fh2(q).*area(q));
      Fh(2,i)=Fh(2,i)+scalefact*nansum( ...
        fherr2(q).*area(q));
      FhE=[FhE;scalefact*fherr2(q).*area(q)];
      Ffw(1,i)=Ffw(1,i)+scalefact*nansum( ...
        ffw2(q).*area(q));
      Ffw(2,i)=Ffw(2,i)+scalefact*nansum( ...
        ffwerr2(q).*area(q));
      Ffw_norivers(1,i)=Ffw_norivers(1,i)+ ...
	scalefact*nansum(ffw_norivers2(q).*area(q));
      Ffw_norivers(2,i)=Ffw(2,i)+scalefact*nansum( ...
        ffwerr2(q).*area(q));
      FfwE=[FfwE;scalefact*ffwerr2(q).*area(q)];
      LayE=[LayE;i*ones(length(q),1)];
    end; % if length(q)
  end; % loop through layers
  % loop through for terms defined on glayers grid
  for i=1:length(glayers);
    q=find(ssg2>=gamma2_edge(i) & ...
	 ssg2<gamma2_edge(i+1));
    if (length(q))
      Mmek(i)=Mmek(i)+scalefact*nansum( ...
	[Mek2(q);0]);
      Msek(i)=Msek(i)+scalefact*nansum( ...
        [Sek2(q);0]);
      Mhek(i)=Mhek(i)+scalefact*nansum( ...
        [Tek2(q);0]);
      SSArea(i)=SSArea(i)+scalefact*nansum(area(q));
      numcells(i)=numcells(i)+scalefact*length(q);
      SSSbar(i)=SSSbar(i)+scalefact*nansum(sss2(q));
      SSTbar(i)=SSTbar(i)+scalefact*nansum(sst2(q));
    end;
  end;
end;

clear fm2 fmerr2 fh2 fherr2 ffw2* ffwerr2 
clear ssg2 Mek2 Sek2 Tek2
% All fields have been summed over each
% month.  Get average by dividing by the
% total number of months (size(sst,1)).
Fm=Fm/size(sst,1);
Fh=Fh/size(sst,1);
Ffw=Ffw/size(sst,1);
Ffw_norivers=Ffw_norivers/size(sst,1);
Mmek=Mmek/size(sst,1);
Msek=Msek/size(sst,1);
Mhek=Mhek/size(sst,1);
SSArea=SSArea/size(sst,1);
% calculate mean SSS and SST by diving
% nansum by number of cells/level
q=find(~numcells);numcells(q)=NaN;
SSSbar=SSSbar./numcells;
SSTbar=SSTbar./numcells;

if (0)
% allow the possible bias on Ffw, Fh, Fm
% to be correlated over length scale
% error_corrdist (grid points)
for i=1:max(LayE);
  q=find(LayE==i);
  if (length(q))
    multfact=error_corrdist/sqrt(length(q)/size(sst,1));
	% length(q) is divided by size(sst,1), # months,
	% to get a mean # of outcropping points.
    if (multfact>1) multfact=1; end;
    Fm(2,i)=multfact*sum(FmE(q)/size(sst,1));
    Fh(2,i)=multfact*sum(FhE(q)/size(sst,1));
    Ffw(2,i)=multfact*sum(FfwE(q)/size(sst,1));
    Ffw_norivers(2,i)=multfact*sum(FfwE(q)/size(sst,1));
  end;
end;
% NOTE: floor of error_multfact re-added to errors below.
end;

% now add zero endpoints to F* terms,
% so they match the gamma2 grid
Fm=[zeros(2,1),Fm,zeros(2,1)];
Ffw=[zeros(2,1),Ffw,zeros(2,1)];
Ffw_norivers=[zeros(2,1),Ffw_norivers,zeros(2,1)];
Fh=[zeros(2,1),Fh,zeros(2,1)];

% smooth the curves, keeping the values of the
% absolute maximum and absolute minimum
smoothit='F2(k)=(.5*F(j,k-1)+F(j,k)+.5*F(j,k+1))/2;';
for i=1:4;
  if (i==1) F=Fm;
  elseif (i==2) F=Ffw;
  elseif (i==3) F=Ffw_norivers;
  else F=Fh;
  end;
  q=[min(find(F(1,:)==min(F(1,:)))) ...
	min(find(F(1,:)==max(F(1,:))))];
  for j=1:2;
    F2=F(j,:);
    for k=2:min(q)-1;eval(smoothit);end;
    for k=min(q)+1:max(q)-1;eval(smoothit);end;
    for k=max(q)+1:length(gamma2)-1;eval(smoothit);end;
    F(j,:)=F2;
  end;
  if (i==1) Fm=F;
  elseif (i==2) Ffw=F;
  elseif (i==3) Ffw_norivers=F;
  else Fh=F;
  end;  
end;

% calculate formation rates from A/S forcing
Mm=NaN*ones(size(diff(Fm')'));
Mm(1,:)=-diff(Fm(1,:));
Mm(2,:)=sqrt(Fm(2,1:size(Fm,2)-1).^2+ ...
	Fm(2,2:size(Fm,2)).^2);
clear mm mma;

if (0)
  % create a floor for the error terms:
  % minimum error is always at least error_multfact
  % the magnitude of the forcing term.
  q=find(Mm(2,:)<error_multfact*abs(Mm(1,:)));
  Mm(2,q)=error_multfact*abs(Mm(1,q));
  q=find(Ffw(2,:)<error_multfact*abs(Ffw(1,:)));
  Ffw(2,q)=error_multfact*abs(Ffw(1,q));
  Ffw_norivers(2,q)=error_multfact*abs(Ffw_norivers(1,q));
  q=find(Fh(2,:)<error_multfact*abs(Fh(1,:)));
  Fh(2,q)=error_multfact*abs(Fh(1,q));
  q=find(Fm(2,:)<error_multfact*abs(Fm(1,:)));
  Fm(2,q)=error_multfact*abs(Fm(1,q));
end;

subplot(211);
plot(gamma2,Fm(1,:)/1e6,'k');
hold on;
plot(gamma2,(Fm(1,:)+Fm(2,:))/1e6);
plot(gamma2,(Fm(1,:)-Fm(2,:))/1e6);
line([min(gamma2) max(gamma2)],[0 0],'color','k');
set(gca,'xlim',[min(gamma2) max(gamma2)]);
hold off;
ylabel('Transformation (Sv)');

subplot(212);
plot(glayers,Mm(1,:)/1e6,'r',glayers,Mm(1,:)/1e6,'.r');
set(gca,'xlim',[min(gamma2) max(gamma2)]);
xlabel('\gamma');ylabel('Formation (Sv)');
line([20 29],[0 0]);

% interpolate Fh, Ffw to glayers
% (they are currently on the grid of gamma2, bracketing
% the glayers values).
Mfw(1,:)=interp1(gamma2',Ffw(1,:),glayers','linear');
Mfw(2,:)=interp1(gamma2',Ffw(2,:),glayers','linear');
MH(1,:)=interp1(gamma2',Fh(1,:),glayers','linear');
MH(2,:)=interp1(gamma2',Fh(2,:),glayers','linear');
Ffw=Mfw;clear Mfw; Fh=MH;clear MH;
Mfw(1,:)=interp1(gamma2',Ffw_norivers(1,:),glayers','linear');
Mfw(2,:)=interp1(gamma2',Ffw_norivers(2,:),glayers','linear');
Ffw_norivers=Mfw;clear Mfw;

% calculate net Ekman-driven salt flux (kg/s)
EkmanInSalt=1.027*(35*EkmanInM + 1000*EkmanInS);

filename='airsea';
if ~flag_fw filename=[filename,'_noFW']; end;
if ~flag_h filename=[filename,'_noH']; end;
filename=[filename,'_',num2str(flag_clim),'_'];
filename=[filename,num2str(boxnumber)];
disp(['Saving ',filename,'.mat']);
eval(['save ',filename,' glayers glevels gamma2', ...
	' Mm Fh Ffw* Mmek Mhek Msek flag* R', ...
	' EkmanInM EkmanInH EkmanInS EkmanInSalt', ...
	' SSSbar SSTbar SSArea Fm si_flux']);

clear netheat netheaterr ssd ssg sss sss2 sst taux tauy;
clear eminusp fh fherr fm fmerr;
clear ffw ffwerr index latvec lonvec landmask Sek Tek;
clear Mek Fh Mhek Mm Mmek Ffw Msek area q;
clear M Mek EkmanIn lat_river lon_river R

end;            % LOOP THROUGH BOXES

end;		% loop through climatologies (flag_clim)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% now assemble the transformation, formation and
% Ekman terms from the different climatologies
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all;
glev;
nclims=2;	% number of climatologies
disp('Loading geometry file "geo".');
file_geom='geo';
eval(file_geom);
nboxes=size(geometry,1);

for boxnum=1:nboxes;

  load airsea_1_1 EkmanInH
  tEkmanInH=NaN*ones([size(EkmanInH) nclims]);
  tEkmanInM=tEkmanInH;
  tEkmanInS=tEkmanInH;
  tEkmanInSalt=tEkmanInH;
  tFfw=NaN*ones([nclims length(glayers)]);
  tFh=tFfw;tFfw_norivers=tFfw;
  tFm=NaN*ones([nclims length(gamma2)]);
  tMhek=NaN*ones([nclims length(glayers)]);
  tMm=tMhek; tMmek=tMhek; tMsek=tMhek;
  tSSArea=tMhek; tSSSbar=tMhek; tSSTbar=tMhek;

  for climnum=1:nclims;
    eval(['load airsea_',num2str(climnum), ...
	'_',num2str(boxnum), ...
	' EkmanIn* F* M* SS* si_flux']);
    tEkmanInH(:,:,climnum)=EkmanInH;
    tEkmanInM(:,:,climnum)=EkmanInM;
    tEkmanInS(:,:,climnum)=EkmanInS;
    tEkmanInSalt(:,:,climnum)=EkmanInSalt;
    tFfw(climnum,:)=Ffw(1,:);
    tFfw_norivers(climnum,:)=Ffw_norivers(1,:);
    tFh(climnum,:)=Fh(1,:);
    tFm(climnum,:)=Fm(1,:);
    tMhek(climnum,:)=Mhek(1,:);
    tMm(climnum,:)=Mm(1,:);
    tMmek(climnum,:)=Mmek(1,:);
    tMsek(climnum,:)=Msek(1,:);
    tSSArea(climnum,:)=SSArea;
    tSSSbar(climnum,:)=SSSbar;
    tSSTbar(climnum,:)=SSTbar;
  end;
  EkmanInH=mean(tEkmanInH,3);
  EkmanInM=mean(tEkmanInM,3);
  EkmanInS=mean(tEkmanInS,3);
  EkmanInSalt=mean(tEkmanInSalt,3);
  EkmanInM_range=sum(tEkmanInM,1);
  EkmanInM_range=reshape(EkmanInM_range, ...
	[size(tEkmanInM,2) nclims]);
  EkmanInM_range=range(EkmanInM_range')';
  Ffw=[mean(tFfw);range(tFfw)/2];
  Ffw_norivers=[mean(tFfw_norivers); ...
	range(tFfw_norivers)/2];
  Fh=[mean(tFh);range(tFh)/2];
  Fm=[mean(tFm);range(tFm)/2];
  Mhek=mean(tMhek);
  Mm=[mean(tMm);range(tMm)/2];
  Mmek=mean(tMmek);
  Msek=mean(tMsek);
  SSArea=nanmean(tSSArea);
  SSSbar=nanmean(tSSSbar);
  SSTbar=nanmean(tSSTbar);
  eval(['save airsea',num2str(boxnum), ...
	' Ekman* F* M* tF* SS* si_flux' ...
	' glevels glayers gamma2']);
end;	% loop through boxes


