function makemap(lon,lat,plotbathy,plotcoast);

% function makemap(lon,lat,plotbathy,plotcoast);
%
% Make a map spanning coordinates lon, lat
% (ex: lon=[-90 0]; lat=[-90 60];)
% for subsequent geophysical data.
% Set plotbathy=1 for low-res bathymetry
% (included in m_map), =2 for Smith and Sandwell.
% Set plotcoast=0 for no coast, 1 for solid line
% (default), and 2 for filled polygons.

landcolor=[0 .5 0];	% color of land
landcolor=[.25 .75 .25];

if length(lon)==4
  lat=lon(3:4);lon=lon(1:2);
end;
if ~exist('lon') | ~length(lon) | ~length(lat)
  lon=[-180 180];
  lat=[-80 80];
end;
if ~exist('plotbathy')
  plotbathy=0;
end;
if ~exist('plotcoast');
  plotcoast=1;
end;

if (max(lat)<90 & min(lat)>-90);
% not a polar map
  polar=0;
  %m_proj('Mollweid','lat',lat,'lon',lon);
  m_proj('Mercator','lat',lat,'lon',lon);
else	% polar map
  polar=1;
  %if (max(lat)==90) mlat=90; end;
  %if (min(lat)==-90) mlat=-90; end;
  mlat=mean(lat);
  if (mlat>50) mlat=90; end;
  if (mlat<-50) mlat=-90; end;
  m_proj('Satellite','lon',mean(lon),'lat',mlat,'alt',4)
  %m_proj('stereographic','lon',mean(lon),'lat',mlat,'rad',30)
end;

if (plotbathy==1)
% bathymetry (1 deg.):
  m_elev('contourf',-7000:500:0,'edgecolor','none');
  caxis([-6500 0]);
elseif (plotbathy==2)
  [bathy,lonbath,latbath]=mygrid_sand([lon lat]);
  %m_contourf(lonbath,latbath,bathy,-7000:500:0);
  m_contourf(lonbath,latbath,bathy);
  shading flat;
elseif (plotcoast)
  if (plotcoast==2)
    m_coast('patch',landcolor,'edgecolor','none');
  elseif (plotcoast==1)
    m_coast('line','color',landcolor);
  end;
end;

if (polar)
  %m_grid('xlabeldir','middle');
  %m_grid('xticklabel',[],'yticklabel',[]);
  m_grid('xtick',[],'ytick',[]);
else
  %m_grid('xtick',[]);
  m_grid;
end;

