% uniquerefvels.m
%
% Define a set of inhomogeneous initial reference 
% velocities and a priori magnitudes of corrections for
% particular sections.

% load defined levels, layers
glev;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% a08 (11 deg. S).
%
% Initial reference levels from Speer, Holfort,
%	Reynaud and Siedler (1996).
sect='a08.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=28.101); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.4);
  RV=rv(i)*ones(length(Vmag),1)';
  % allow an eastern boundary current (Gabon-Congo Undercurrent)
  Vmag(length(Vmag)-1:length(Vmag))=.1;

  % shift ref level to 1100m west of 35.5W
  RV(3)=-.2886;

  % shift ref level to 3800m between 35.5W and 17.67W
  % (Brazil Basin)  (stations 4:6 stay bottom-referenced)
  RV(7:40)=[-93 -46 6 -29 -4 7 -4 7 16 2 -14 7 -2 -2 -4 0 -1 ...
	2 2 -5 4 0 -1 -3 -1 1 -3 6 4 -3 5 4 1 19]/1000;

  % shift ref level to 2400m between 17.67W and 10.17W (MAR)
  RV(41:57)=[-19 -7 -14 13 3 -26 24 13 3 4 2 -25 ...
	10 -16 39 -44 62]/1000;

  % shift ref level to 4000m east of 10.17W (Angola Basin)
  RV(58:96)=[0 0 -1 2 1 0 2 5 4 -4 1 -4 0 6 -4 2 0 -2 8 -1 ...
	-4 12 -2 1 2 1 0 1 0 -1 -1 3 0 -3 -4 1 4 -8 2]/1000;

  % uniformly shift ref vel to balance net mass and salt
  % (mass exactly, giving -13.88 psu Sv for net salt)
  RV=RV-1.348e-4;
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% a11 (45-30 deg. S).
%
% Primary reference Saunders and King, 1995
sect='a11.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=28.101); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.4);
  RV=rv(i)*ones(length(Vmag),1)';

  % 45 Sv WBC (pairs 1-5)
  RV(1:5)=.174;
  % -5 Sv EBC (pairs 86-90)
  RV(86:90)=-.043;
  % 6 Sv bottom water into Argentine Basin
  %  (potmp<2; layers 24-35; pairs 9-44)
  RV(15:17)=.0129;
  % 0 Sv bottom water into Cape Basin
  %  (pairs 61:82; blocked by Walvis Ridge)
  RV(61:82)=-.0005;
  % uniform s-ward flow across station pairs
  %   over MAR to get 0 net flow (-4.35 Sv to balance Ek)
  retflow=-.0303;RV(51:54)=retflow;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% a05fs (Florida Strait).
sect='a05fs.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=28.358); reflevel(i)=q(1); %bottom

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';
  RV(1:length(RV))=.307;  % 31 Sv through Florida Strait
  for bl=1:length(Vmag);
    Vmag(bl)=max([Vmag(bl) .05]);
  end;
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% a05int (24.5 deg. N).
%   Increase the magnitude of reference
%   velocities against the western slope
sect='a05int.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=27.77); reflevel(i)=q(1); % AAIW/NADW int.

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.4);
  RV=rv(i)*ones(length(Vmag),1)';
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% a06 (7.5 deg. N).
%   Increase the magnitude of reference
%   velocities against the western slope;
% 	balance net Ekman
sect='a06.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=27.77); reflevel(i)=q(1); % AAIW/NADW int.
  %q=find(glevels>=28.13);reflevel(i)=q(1);	% NADW/AABW int.

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.4);
  RV=rv(i)*ones(length(Vmag),1)';
  % balance net Ekman (9 Sv south)
  RV=RV+3.2e-3;
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ar07ed_ebc: Cape Farvel to Ireland, including
% 	an "EBC" tail closing the Porcupine Bank
%	to Ireland gap.
sect='ar07ed_ebc';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=27.879); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),60,.4);
  RV=rv(i)*ones(length(Vmag),1)';

  % East Greenland Current: Bersch (1995): 70-350m mean reaches
  % max speeds of 28 cm/s (Fig.7); total flux 32.2 Sv.
  % Bacon (1997): EGC width is 50-60km, total flux 15.0 Sv.
  RV(1)=-.1;RV(2)=-.2;RV(3)=-.3;
  RV(4)=-.06;
  RV(5:6)=-.14;RV(7)=-.13;RV(8)=-.12;
  for bl=1:8
    Vmag(bl)=max([Vmag(bl) .14]);
  end;

  % Current meters in ACM8: Irminger Current passes against
  % N.flank of Reykjanes Ridge with barotropic offset of 8 cm/s.
  RV(16:18)=.08;
  for bl=16:18;
    Vmag(bl)=max([Vmag(bl) .05]);
  end;
  
  % Bersch: net flow -9.1 Sv out of Irminger Basin
  RV(9:15)=.0194;
  
  % Bersch: NAC branch passes Eriador Seamount with surface
  % currents of 16-18 cm/s.
  RV(32:34)=.15;
  for bl=32:34;
    Vmag(bl)=max([Vmag(bl) .1]);
  end;
  
  % Bersch: net flow 5.7 Sv into Iceland Basin
  RV(19:31)=-.0223;
  
  % Bersch: 25-35 cm/s surface current against Porcupine Bank
  RV(50:51)=.15;
  for bl=50:51;
    Vmag(bl)=max([Vmag(bl) .15]);
  end;

  RV(35:49)=-.00592;      % close salt and mass balance (incl. Ek)

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%% Labrador Sea    %%%%%%%%%%%%%
% Lazier and Wright, 1993: the Lab. Current is 11.0 Sv,
% with a width of 100km.

sect='ar07w_a.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=27.949); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.4);
  RV=rv(i)*ones(length(Vmag),1)';
  % allow relatively strong EBC corrections
  for bl=1:6;
    Vmag(bl)=max([Vmag(bl) .1]);
  end;

  % Lazier and Wright, 1993: the Lab. Current is
  % 11.0 Sv, of which 7.2 Sv is BT and concentrated
  % in the main core of the Lab. Current
  % Add 14 cm/s to main core:
  RV(16:17)=.14;  % 11.0 Sv for pairs 16-23

  % Lazier and Wright: the total export in
  % the western Lab Sea, including the DWBC,
  % is 37~Sv.  This may be obtained by BC +
  % a BT component of 15 cm/s on the 2500m
  % isobath, decaying linearly to 0 over 140km.
  RV(15)=.1; RV(14)=.05; RV(13)=.01; 

  % this produces 11.9 Sv of gamma>28 in pairs 7-15
  % (export from Lab Sea).  The BC import in
  % the DBC is only 9.8 Sv.
  % Add a BT component to get -11.9 Sv.
  RV(4:6)=-.026;

  % finally, balance net in West Greenland Current
  RV(3)=-.229;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%% Denmark Strait  %%%%%%%%%%%%%
%
% Over the deepest part of this section,
% direct current measurements [Ross, 1975;
% Aagaard & Malmberg, 1978] give a mean
% southward speed of 50-60 cm/s.

sect='denstrait.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=27.879); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';

  % Increase the core speed of
  % the deep overflow water to 55 cm/s;
  % add a bit to next-deepest station pair to give
  % 2.7 Sv overflow
  RV(8)=.3; RV(9)=.06;
  Vmag(8:9)=.15;

  % EGC: 1.6 Sv (southward) polar water 
  RV(21)=.8;RV(20)=.4;RV(19)=.1;
  Vmag(21)=.4;Vmag(20)=.4;
  Vmag(19)=max(Vmag(19),.1);
  
  % Irminger Current: -0.9 Sv (northward) SPMW
  RV(1:7)=-.235;
  for bl=1:7;
    Vmag(bl)=max([Vmag(bl) .2]);
  end;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

%%%%%%%% Denmark Strait  %%%%%%%%%%%%%
%
% Over the deepest part of this section,
% direct current measurements [Ross, 1975;
% Aagaard & Malmberg, 1978] give a mean
% southward speed of 50-60 cm/s.
% 
% Probably the best estimate of absolute
% currents here is from Girton, Sanford and Kaese (2001)
% ( http://ohm.apl.washington.edu/%7Egirton/dso/figs2.html )
% 60 cm/s core of barotropic jet over sill

sect='ar18e1.mat';
i=sectname2sectnum(sect);
if (length(i))

  reflevel(i)=length(glevels);	% bottom ref level

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';

  % Irminger Current (pairs 1:5):
  %     -0.9 Sv (northward) SPMW (layers 1-15)
  RV(1:5)=-.06;

  % Barotropic jet west of channel.
  % 2.9Sv (this gives 3.0) at sig_theta>27.8, layers 21-35;
  % .9 Sv in layers 21-28, 2.0 Sv in layers 29-35.
  % [Girton et al. 2001].  This gives 1.12, 1.90 respectively.
  RV(10)=.2;RV(9)=.3; RV(8)=.04;
  for bl=7:10;
    Vmag(bl)=max([Vmag(bl) .3]);
  end;

  % EGC: 1.6 Sv (southward) polar water (layers 1-11 west
  % of the Irminger Current, stn. pairs 7-21).
  RV(19:20)=-.04;
  for bl=19:20;
    Vmag(bl)=max([Vmag(bl) .2]);
  end;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;


%%%%%%%%%% Iceland-Scotland Ridge %%%%%%%%%%%%%%
sect='fbc.mat';
i=sectname2sectnum(sect);
if (length(i))
  q=find(glevels>=27.879); reflevel(i)=q(1);
  RV(3)=.7;
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

sect='ice2scot.mat';
i=sectname2sectnum(sect);

if (length(i))

  q=find(glevels>=27.879); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),-99,-99);
  RV=rv(i)*ones(length(Vmag),1)';

  % add BT velocity in FBC to get 1.4 Sv overflow at
  % sig_thet>27.975 (gamma>28.145) [Mauritzen, 1996;
  %  Osterhus et al., 1999; Price et al., 2001]
  RV(15)=.7;
  Vmag(15)=max([Vmag(15) .35]);

  % -4 Sv (northward) SPMW (layers 1-15) across
  % Iceland-Faroe Rise (pairs 19-32) [Hansen et al 1999]
  RV(19:29)=-.05;
  
  % simultaneously, .7 to 1 Sv denser (including
  % N. Iceland Winter Water) passing S over Rise
  RV(31:32)=.15;	% this gives .8 Sv, 
			%   layers 16-35 pairs 19:32
  for bl=31:32;
    Vmag(bl)=max([Vmag(bl) .15]);
  end;

  % -3 Sv SPMW between Faroes and Scotland
  % [Hansen et al 1999]
  RV(1:3)=-.06;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% a02_94: 48N
sect='a02_94.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=27.879); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.4);
  RV=rv(i)*ones(length(Vmag),1)';
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% a02_97: 48N
sect='a02_97.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=27.879); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.4);
  RV=rv(i)*ones(length(Vmag),1)';
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% ar19a: 48N
sect='ar19a.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=27.879); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.4);
  RV=rv(i)*ones(length(Vmag),1)';

  RV(10)=.12;     % NAC core speed (Clarke, Hendry & Yashayaer 199?)
  RV(8:9)=-.06;   % 25 Sv DWBC (pairs 5-13, CH&Y)
  RV(11:length(RV))=-8.5e-4; % balance Ekman 2.52Sv southward

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% ar19c: 48N
sect='ar19c.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=27.879); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.4);
  RV=rv(i)*ones(length(Vmag),1)';
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% ar19d: 48N
sect='ar19d.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=27.879); reflevel(i)=q(1);
  
  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.4);
  RV=rv(i)*ones(length(Vmag),1)';
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% i05p: 32S
sect='i05p.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=27.917); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.4);
  RV=rv(i)*ones(length(Vmag),1)';

  RV(11:12)=-.013;              % Natal Valley AABW cul-de-sac
  RV(22:23)=.009;               % 1 Sv AABW into Mozambique Basin
  RV(31:40)=-.002;              % Madagascar Basin AABW cul-de-sac
  RV(58:67)=0;                  % Central Basin AABW cul-de-sac
  RV=RV+6e-4;                   % balance net to get PIT-Ek (1.6Sv)

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% p06: 32S
sect='p06.mat';
i=sectname2sectnum(sect);
if (length(i))

  q=find(glevels>=28.1); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),100,.4);
  RV=rv(i)*ones(length(Vmag),1)';
  RV(28:34)=-.0015;     % S. New Cal. Trough layers 16-35 cul-de-sac
  % Witworth, Warren et al, 1999: PCM9 observations of DWBC
  % against Kermadec Ridge
  RV(57:62)=0.025;      % 16 Sv (layers 16-35) N against Kermadec Ridge
                        %   as seen by PCM9 (179-168W; pairs 57-83)
  RV=RV-3.2e-4;         % Balance net to get PIT - Ek (1.7 Sv)=8.3
  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

% wedsea
sect='wedsea.mat';
i=sectname2sectnum(sect);
if (length(i))

  % reference level: 0 deg C. CDW/WSDW interface
  q=find(glevels>=28.292); reflevel(i)=q(1);

  Vmag=defVmag(sectfiles(i,:),reflevel(i),vmag(i),50,.4);
  RV=rv(i)*ones(length(Vmag),1)';
  % add WBC to balance -.1 Sv southward.
  RV(6:10)=.0005;

  rvfilename=['refvel_',sect];
  eval(['save ',rvfilename,' RV Vmag']);
end;

