
% plotairsea
%
% plot the corrected air-sea fluxes of buoyancy,
% heat and freshwater for all boxes
%   DASHED: COADS  DOTTED: NCEP

gamlim=[min(gamma2) 28.2];
if nboxes==4
  boxlabels=['Equatorial box '; ...
             'Subtropical box'; ...
             ' Subpolar box  '; ...
             ' Overflow box  '];
else
  for i=1:nboxes;
    boxlabels(i,:)=['box ',num2str(i)];
  end;
end;
colorplot=0;		% set to 0 for b&w, 1 for color

clf;

% calculate the mean conversion factor as a function
% of layer
FluxDivFact=NaN*ones(nlayers-1,nboxes);
for boxnum=1:nboxes;
  S=meanprop(:,2,boxnum)*1000+35;
  Th=meanprop(:,3,boxnum);
  eval(['load mprop_atl',num2str(boxnum), ...
        ' mpres_atl',num2str(boxnum)]);
  eval(['P=mpres_atl',num2str(boxnum),';']);
  T=sw_temp(S,Th,P,zeros(size(P)));
  Rho=sw_dens(S,T,P);
  Cp=sw_cp(S,T,P);
  FluxDivFact(:,boxnum)=1e15./Rho./Cp;
end;
fluxdivfact=fillnans(mean(FluxDivFact,2),0);
fluxdivfact_lay=fillnans(interp1(glevels, ...
        mean(FluxDivFact,2),glayers),0);

for boxnum=1:nboxes;

  eval(['load airsea',num2str(boxnum),' t*']);
  fdens=(Fdens(2:nlayers,boxnum)+ ...
	Fdenscorr(2:nlayers,boxnum))/1e6;
  efdens=eFdenscorr(2:nlayers,boxnum)/1e6;

  ffw=x(indF(:,2,boxnum));
  effw=erx(indF(:,2,boxnum));
  ffw=ffw/1e3; effw=effw/1e3;

  fh=x(indF(:,1,boxnum));   % indF: 1 is heat, 2 is FW
  efh=erx(indF(:,1,boxnum));
  fh=fh./fluxdivfact;efh=efh./fluxdivfact;

  % by construction in gauss.m, each layer gets 1/2 of the
  % flux from the lighter level and 1/2 from the heavier level.
  ffw=[0;ffw;0];ffw=ffw(1:length(ffw)-1)+diff(ffw)/2;
  fh=[0;fh;0];fh=fh(1:length(fh)-1)+diff(fh)/2;
  effw_lay=NaN*ones(size(glayers));efh_lay=effw_lay;
  effw_lay(1)=effw(1)/2;effw_lay(length(glayers))=last(effw)/2;
  efh_lay(1)=efh(1)/2;efh_lay(length(glayers))=last(efh)/2;
  for i=2:length(glayers)-1;
    effw_lay(i)=sqrt( effw(i-1)^2 + effw(i)^2)/sqrt(2);
    efh_lay(i)=sqrt( efh(i-1)^2 + efh(i)^2)/sqrt(2);
  end;
  efh=efh_lay;effw=effw_lay;

  % add a priori air-sea fluxes
  ffw=ffw+AirSea(:,1,boxnum)/1e3;
  fh=fh+AirSea(:,3,boxnum)./fluxdivfact_lay;

  subplot(3,nboxes,boxnum);
  set(gca,'fontsize',12);
  plot(glevels,fdens,'k');
  hold on;
  line([min(gamma2) max(gamma2)],[0 0],'color',[.5 .5 .5]);
  patch([glevels;flipud(glevels)], ...
        [fdens+efdens ; flipud(fdens-efdens)], ...
        [.7 .7 .7],'edgecolor','none');
  plot(glevels,fdens,'color',[.2 .2 .2]);
  plot(gamma2,tFm(1,:)/1e6,'--k','linewidth',1);
  plot(gamma2,tFm(2,:)/1e6,':k','linewidth',2);
  hold off;
  set(gca,'xlim',[min(gamlim) max(gamlim)]);

  subplot(3,nboxes,nboxes+boxnum);
  set(gca,'fontsize',12);
  plot(glayers,ffw);
  hold on;
  line([min(gamma2) max(gamma2)],[0 0],'color',[.5 .5 .5]);
  if (colorplot)
    patch([glayers;flipud(glayers)], ...
	[ffw+effw ; flipud(ffw-effw)], ...
        [.5 1 .5],'edgecolor','none');
    plot(glayers,ffw,'color',[0 .5 0]);
    plot(glayers,tFfw(1,:)/1e3,'--', ...
	'linewidth',1,'color',[0 .5 0]);
    plot(glayers,tFfw(2,:)/1e3,':', ...
	'linewidth',2,'color',[0 .5 0]);
  else
    patch([glayers;flipud(glayers)], ...
        [ffw+effw ; flipud(ffw-effw)], ...
        [.7 .7 .7],'edgecolor','none');
    plot(glayers,ffw,'color',[.2 .2 .2]);
    plot(glayers,tFfw(1,:)/1e3,'--k','linewidth',1);
    plot(glayers,tFfw(2,:)/1e3,':k','linewidth',2);
  end;

  hold off;
  set(gca,'xlim',[min(gamlim) max(gamlim)]);
  %title('F_{fw} (green: a priori, black: corrected)');

  subplot(3,nboxes,2*nboxes+boxnum);
  set(gca,'fontsize',12);
  plot(glayers,fh,'r');
  hold on;
  line([min(gamma2) max(gamma2)],[0 0],'color',[.5 .5 .5]);
  if (colorplot)
    patch([glayers;flipud(glayers)], ...
	[fh+efh; flipud(fh-efh)], ...
        [1 .7 .7],'edgecolor','none');
    plot(glayers,fh,'r');
    plot(glayers,tFh(1,:)./fluxdivfact_lay', ...
	'--r','linewidth',1);
    plot(glayers,tFh(2,:)./fluxdivfact_lay', ...
	':r','linewidth',2);
  else
    patch([glayers;flipud(glayers)], ...
        [fh+efh ; flipud(fh-efh)], ...
        [.7 .7 .7],'edgecolor','none');
    plot(glayers,fh,'color',[.2 .2 .2]);
    plot(glayers,tFh(1,:)./fluxdivfact_lay', ...
	'--k','linewidth',1);
    plot(glayers,tFh(2,:)./fluxdivfact_lay', ...
	':k','linewidth',2);
  end;
  hold off;
  set(gca,'xlim',[min(gamlim) max(gamlim)]);

end;	% loop over boxes

subplot(3,nboxes,1);
ylabel('F_\rho (Sv)','fontsize',15);
subplot(3,nboxes,nboxes+1);
ylabel('F_{fw} (10^3 m^3/s)','fontsize',15);
subplot(3,nboxes,2*nboxes+1);
ylabel('F_h (PW)','fontsize',15);

for boxnum=1:nboxes;
  subplot(3,nboxes,boxnum);
  title(boxlabels(boxnum,:),'fontsize',15);
end;
for j=3*nboxes-nboxes+1:3*nboxes;
  subplot(3,nboxes,j);
  xlabel('\gamma^n','fontsize',15);
end;

orient landscape
%print airsea -depsc
load gaussout fluxdivfact

