
% plotairsea2
%
% plot the corrected air-sea fluxes of buoyancy,
% heat and freshwater for all boxes
% 
% same as plotairsea, but fluxes are plotted
% vertically using layerplot

plot(1,1);
orient landscape;
wysiwyg;
clf;

gamlim=[min(gamma2) 28.2];
if nboxes==4
  boxlabels=['Equatorial box '; ...
             'Subtropical box'; ...
             ' Subpolar box  '; ...
             ' Overflow box  '];
else
  for i=1:nboxes;
    boxlabels(i,:)=['box ',num2str(i)];
  end;
end;

clf;

% calculate the mean conversion factor as a function
% of layer
FluxDivFact=NaN*ones(nlayers-1,nboxes);
for boxnum=1:nboxes;
  S=meanprop(:,2,boxnum)*1000+35;
  Th=meanprop(:,3,boxnum);
  eval(['load mprop_atl',num2str(boxnum), ...
        ' mpres_atl',num2str(boxnum)]);
  eval(['P=mpres_atl',num2str(boxnum),';']);
  T=sw_temp(S,Th,P,zeros(size(P)));
  Rho=sw_dens(S,T,P);
  Cp=sw_cp(S,T,P);
  FluxDivFact(:,boxnum)=1e15./Rho./Cp;
end;
fluxdivfact=fillnans(mean(FluxDivFact,2),0);
fluxdivfact_lay=fillnans(interp1(glevels, ...
        mean(FluxDivFact,2),glayers),0);

for boxnum=1:nboxes;

  eval(['load airsea',num2str(boxnum),' t*']);
  fdens=(Fdens(2:nlayers,boxnum)+ ...
	Fdenscorr(2:nlayers,boxnum))/1e6;
  efdens=eFdenscorr(2:nlayers,boxnum)/1e6;

  ffw=x(indF(:,2,boxnum));
  effw=erx(indF(:,2,boxnum));
  ffw=ffw/1e3; effw=effw/1e3;

  fh=x(indF(:,1,boxnum));
  efh=erx(indF(:,1,boxnum));
  fh=fh./fluxdivfact;efh=efh./fluxdivfact;

  % by construction in gauss.m, each layer gets 1/2 of the
  % flux from the lighter level and 1/2 from the heavier level.
  ffw=[0;ffw;0];ffw=ffw(1:length(ffw)-1)+diff(ffw)/2;
  fh=[0;fh;0];fh=fh(1:length(fh)-1)+diff(fh)/2;
  effw_lay=NaN*ones(size(glayers));efh_lay=effw_lay;
  effw_lay(1)=effw(1)/2;effw_lay(length(glayers))=last(effw)/2;
  efh_lay(1)=efh(1)/2;efh_lay(length(glayers))=last(efh)/2;
  for i=2:length(glayers)-1;
    effw_lay(i)=sqrt( effw(i-1)^2 + effw(i)^2)/sqrt(2);
    efh_lay(i)=sqrt( efh(i-1)^2 + efh(i)^2)/sqrt(2);
  end;
  efh=efh_lay;effw=effw_lay;

  % add a priori air-sea fluxes
  ffw=ffw+AirSea(:,1,boxnum)/1e3;
  fh=fh+AirSea(:,3,boxnum)./fluxdivfact_lay;

  subplot(3,nboxes,boxnum);
  set(gca,'fontsize',12);
  layerplot(fdens,'k');
  hold on;
  line([0 0],[0 -length(gamma2)],'color',[.5 .5 .5]);
  vert=(1:length(glevels))';
  patch([fdens+efdens ; flipud(fdens-efdens)], ...
	-[vert;flipud(vert)], ...
        [.7 .7 .7],'edgecolor','none');
  plot(fdens,-vert,'color',[.2 .2 .2]);
  vert=(0:length(gamma2)-1)';
  plot(tFm(1,:)/1e6,-vert,'--k','linewidth',1);
  plot(tFm(2,:)/1e6,-vert,':k','linewidth',2);
  hold off;
  if (boxnum>1) set(gca,'yticklabel',' '); end;

  subplot(3,nboxes,nboxes+boxnum);
  set(gca,'fontsize',12);
  vert=(.5:length(glayers)-.5)';
  layerplot(ffw,'k');
  hold on;
  line([0 0],[0 -length(gamma2)],'color',[.5 .5 .5]);
  patch([ffw+effw ; flipud(ffw-effw)], ...
	-[vert;flipud(vert)], ...
        [.7 .7 .7],'edgecolor','none');
  plot(ffw,-vert,'color',[.2 .2 .2]);
  plot(tFfw(1,:)/1e3,-vert,'--k','linewidth',1);
  plot(tFfw(2,:)/1e3,-vert,':k','linewidth',2);
  hold off;
  if (boxnum>1) set(gca,'yticklabel',' '); end;

  subplot(3,nboxes,2*nboxes+boxnum);
  set(gca,'fontsize',12);
  layerplot(fh,'k');
  hold on;
  line([0 0],[0 -length(gamma2)],'color',[.5 .5 .5]);
  patch([fh+efh ; flipud(fh-efh)], ...
        -[vert;flipud(vert)], ...
        [.7 .7 .7],'edgecolor','none');
  plot(fh,-vert,'color',[.2 .2 .2]);
  plot(tFh(1,:)./fluxdivfact_lay', ...
	-vert,'--k','linewidth',1);
  plot(tFh(2,:)./fluxdivfact_lay', ...
	-vert,':k','linewidth',2);

  hold off;
  if (boxnum>1) set(gca,'yticklabel',' '); end;

end;	% loop over boxes

for bn=1:nboxes;
  subplot(3,nboxes,bn);
  xlabel('F_\rho (Sv)','fontsize',12);
  subplot(3,nboxes,nboxes+bn);
  xlabel('F_{fw} (10^3 m^3/s)','fontsize',12);
  subplot(3,nboxes,2*nboxes+bn);
  xlabel('F_h (PW)','fontsize',12);
end;

for boxnum=1:nboxes;
  subplot(3,nboxes,boxnum);
  title(boxlabels(boxnum,:),'fontsize',15);
end;
%for j=3*nboxes-nboxes+1:3*nboxes;
  %subplot(3,nboxes,j);
  %xlabel('\gamma^n');
%end;

print airsea2 -depsc
load gaussout fluxdivfact

