% plotdiafluxes.m
%
% loop through boxes and properties,
% using the routine "plotdiaflux"
% to plot the diffusion and interior
% mixing-driven diapycnal advection.
% 
% a flag in plotdiaflux controls what
% is plotted for heat, salt.

Boxes=1:nboxes;		% boxes to plot 
nBoxes=length(Boxes);

plot(1,1);
orient landscape;
wysiwyg;
clf;

boxlabels='';
if (nBoxes==4)
  boxlabels=['Equatorial box '; ...
	     'Subtropical box'; ...
	     ' Subpolar box  '; ...
	     ' Overflow box  '];
else 
  for i=1:nBoxes;
    boxlabels(i,:)=['Box ',num2str(Boxes(i))];
  end;
end;

for propnum=1:nproperties;

for bxn=1:nBoxes;
boxnum=Boxes(bxn);

subplot(nproperties,nBoxes, ...
	(bxn-1)+nBoxes*(propnum-1)+1);
if (boxnum==Boxes(1)) plotblocks=1;
else plotblocks=0;
end;
plotdiaflux;
if (boxnum>Boxes(1))
  set(gca,'yticklabel',[]);
end;

if (propnum==1) title(boxlabels(bxn,:));
else title(' ');
end;

if (nboxes>1)
  if (propnum==1 & boxnum==Boxes(1))
    P=get(gca,'pos');
    x1=P(1);
    dx=P(3);
  elseif (propnum==1 & boxnum==Boxes(2))
    P=get(gca,'pos');
    x2=P(1);
    dxp=.5*(x2-x1-dx)-.001;
  end;
else	% only 1 box
  dxp=0;
end;

end;	% loop over boxnum
end;	% loop over propnum

% re-loop, resizing the width of the plots
for propnum=1:nproperties;
for bxn=1:nBoxes;
boxnum=Boxes(bxn);

subplot(nproperties,nBoxes, ...
        (bxn-1)+nBoxes*(propnum-1)+1);
P=get(gca,'pos');
set(gca,'pos',[P(1)-dxp,P(2),dx+2*dxp,P(4)]);

end;end;

clear Boxes nBoxes;

print diafluxes -depsc
