
% plotlatflux: visualize output from gauss.m
%
% Plot the lateral (isopycnic) property fluxes across the
% sections for water mass "massnum", including the Ekman flux.
% In each box, state the air-sea and mixing generation
% rates of the water mass.
% Water mass "massnum" is defined in waterdiv.m.
% If "massnum" is negative, plot the flux in glayers(massnum)

holdstatus=ishold;

for propnum=1:3;

latisekman=0;		% set to 1 for Ekman flux only
latisvref=0;		% set to 1 for reference flux only
latisvrel=0;		% set to 1 for relative flux only
latisapriori=0;		% set to 1 for rel+Ek only

plotanom=0;		% set to 1 for salt anomaly (propnum=2)
			% set to 0 for salt (incl. Sbar flux)
labelflux=0;		% set to 1 for labels (eg. 1.0+-0.6)
barwidth=5;

colorplot=0;		% set to 1 for color plot (using propcolor),
			% 	 0 for black & white plot

if ~exist('propcolr')
  load gaussout;
end;
if (colorplot)
  tpropcolr=propcolr;
else
  tpropcolr=[[0 0 0];[.5 .5 .5];[0 0 0]];
end;

tempsectlabel=sectlabel;
tempgeometry=geometry;
if (nboxes==4);
  q=find(tempsectlabel==2);tempsectlabel(q)=3;
  q=find(tempsectlabel==8);tempsectlabel(q)=9;
elseif (nboxes==5)
  q=find(tempsectlabel==3);tempsectlabel(q)=4;
  q=find(tempsectlabel==9);tempsectlabel(q)=10;
elseif (nboxes==6)
  q=find(tempsectlabel==4);tempsectlabel(q)=5;
  q=find(tempsectlabel==10);tempsectlabel(q)=11;
end;
tempnsections=size(tempgeometry,2);

if (~exist('massnum')) massnum=0; end;

if (propnum==1)
  multfact=8; legendflux=1; numstr='%2.1f'; lq2=1;
elseif (propnum==2)
  multfact=.3; legendflux=30; numstr='%2.1f'; lq2=3;
else
  multfact=15; legendflux=.5; numstr='%2.2f'; lq2=2;
end;

waterdiv;		% define the layers.

if (massnum>0)
  titl=waterdivslab(massnum,:);
elseif (massnum<0)
  titl=['layer ',num2str(-massnum)];
end;
if (massnum==0)
  nlyr=1:length(glayers);
  titl='vertically-integrated transports';
elseif (massnum==1)
  nlyr=find(glayers<waterdivs(massnum));
elseif (massnum==length(waterdivs)+1)
  nlyr=find(glayers>=last(waterdivs));
elseif (massnum>1 & massnum<length(waterdivs)+1)
  nlyr=find(glayers>=waterdivs(massnum-1) & ...
	glayers<waterdivs(massnum));
else
  nlyr=-massnum;
end;

% calculate the mean conversion factor as a function
% of layer
FluxDivFact=NaN*ones(nlayers,nboxes);
for boxnum=1:nboxes;
  S=meanprop(:,2,boxnum)*1000+35;
  Th=meanprop(:,3,boxnum);
  eval(['load mprop_atl',num2str(boxnum), ...
        ' mpres_atl',num2str(boxnum)]);
  eval(['P=mpres_atl',num2str(boxnum),';']);
  T=sw_temp(S,Th,P,zeros(size(P)));
  Rho=sw_dens(S,T,P);
  if (propnum==1) fluxdivfact=1e6*ones(size(glevels));
  elseif (propnum==2)
    fluxdivfact=1e6./Rho;
  elseif (propnum==3)
    Cp=sw_cp(S,T,P);
    fluxdivfact=1e15./Rho./Cp;
  end;
  FluxDivFact(:,boxnum)=fillnans(interp1(glevels, ...
      fluxdivfact,glayers),0);
end;
fluxdivfact=mean(FluxDivFact,2);

%%%%%%%%%%%%%%%%%%%
%disp('WARNING: changed fluxdivfact for debugging')
%fluxdivfact=1e6*ones(size(fluxdivfact));
%%%%%%%%%%%%%%%%%%%

% Calculate the lateral flux latflux(boxnum,sectnum,1)
% across each section in layer "massnum".
% This flux is composed of the total geostrophic
% flow (relative + reference) and the Ekman flow.
% latflux(boxnum,sectnum,2) contains the std errors.
latflux=zeros(nboxes,tempnsections,2);
for boxnum=1:nboxes;
  for sectnum=1:tempnsections;

    q=find(tempsectlabel==sectnum);
    if (length(q))
    pfluxref=sum(Ax(indb(nlyr,propnum,boxnum),indv(q)),2);

    if (exist('indE') )
      h=A(indb(nlyr,propnum,boxnum), ...
	[indv(q);indE(unique(sectlabel(q)))])';
      h=h./(ones(size(h,1),1)*fluxdivfact(nlyr)');
      eref=sum(sum(h'*Pxx( ...
	  [indv(q);indE(unique(sectlabel(q)))], ...
	  [indv(q);indE(unique(sectlabel(q)))])*h));
    else	% no correction to Ekman
      h=A(indb(nlyr,propnum,boxnum),indv(q))';
      h=h./(ones(size(h,1),1)*fluxdivfact(nlyr)');
      eref=sum(sum(h'*Pxx(indv(q),indv(q))*h));
    end;
    eref=sqrt(eref);

    pfluxrel=-sum(D(indb(nlyr,propnum,boxnum),indv(q)),2);
    EkIn=EkmanE(nlyr,propnum,boxnum,sectnum);

    if (propnum==2 & ~plotanom)
      pfluxref=pfluxref+35/1e3* ...
	sum(Ax(indb(nlyr,1,boxnum),indv(q)),2);
      h=35/1000*A(indb(nlyr,1,boxnum),indv(q))';
      h=h./(ones(size(h,1),1)*fluxdivfact(nlyr)');
      eref2=sum(sum(h'*Pxx(indv(q),indv(q))*h));
      eref2=sqrt(eref2);
      eref=sqrt(eref^2+eref2^2);
      pfluxrel=pfluxrel-35/1e3* ...
	sum(D(indb(nlyr,1,boxnum),indv(q)),2);
      EkIn=EkIn+35/1e3*EkmanE(nlyr,1,boxnum,sectnum);
    end;

    pfluxref=pfluxref./fluxdivfact(nlyr);
    pfluxrel=pfluxrel./fluxdivfact(nlyr);
    EkIn=EkIn./fluxdivfact(nlyr);

    latflux(boxnum,sectnum,1)=sum(pfluxref+pfluxrel+EkIn);
    latflux(boxnum,sectnum,2)=eref;
    if (latisekman)
      disp('Plotting Ekman flux only')
      latflux(boxnum,sectnum,1)=sum(EkIn);
      latflux(boxnum,sectnum,2)=0;
    elseif (latisvref)
      disp('Plotting reference flux only')
      latflux(boxnum,sectnum,1)=sum(pfluxref);
    elseif (latisvrel)
      disp('Plotting relative flux only')
      latflux(boxnum,sectnum,1)=sum(pfluxrel);
      latflux(boxnum,sectnum,2)=0;
    elseif (latisapriori)
      disp('Plotting a priori only')
      latflux(boxnum,sectnum,1)=sum(pfluxrel+EkIn);
      latflux(boxnum,sectnum,2)=0;
    end;

    end;	% if length(q)
  end;
end;

% calculate the diapycnal advection driven by
% the air-sea buoyancy flux and subsurface mixing of density
vertflux=NaN*ones(nboxes,2);
for boxnum=1:nboxes;
   vflux=diff(W(:,boxnum) ...
	.*[0;level_area_nonans(:,boxnum);0] ...
	.*[0;meanprop_nonans(:,propnum,boxnum);0]) ...
	./fluxdivfact;
   vertflux(boxnum,1)=sum(vflux(nlyr));
   h=A(indb(nlyr,propnum,boxnum), ...
	[indF(:,:,boxnum),indw(:,propnum,boxnum)])';
   h=h./(ones(size(h,1),1)*fluxdivfact(nlyr)');
   eref=sum(sum(h'*Pxx( ...
	[indF(:,:,boxnum),indw(:,propnum,boxnum)], ...
	[indF(:,:,boxnum),indw(:,propnum,boxnum)])*h));
   vertflux(boxnum,2)=sqrt(eref);
end;

% calculate airsea(boxnumber,1), a vector containing
% the direct air-sea input of the property, and
% the input from diapycnal advection driven by
% the air-sea buoyancy flux.
% airsea(boxnumber,2) are the std errors.
airsea=zeros(nboxes,2);
for boxnum=1:nboxes;

  fdens=(Fdens(2:nlayers,boxnum)+ ...
        Fdenscorr(2:nlayers,boxnum));
  ffw=x(indF(:,2,boxnum));
  fh=x(indF(:,1,boxnum));
  % interpolate ffh, fh to glayers grid
  ffw=[0;ffw;0];ffw=ffw(1:length(ffw)-1)+diff(ffw)/2;
  fh=[0;fh;0];fh=fh(1:length(fh)-1)+diff(fh)/2;

  % direct input
  airsea(boxnum,1)=sum(AirSea(nlyr,propnum,boxnum) ...
	./fluxdivfact(nlyr));
  % include adjustments
  if (propnum==1)	% fw adjustment
    airsea(boxnum,1)=airsea(boxnum,1)+ ...
	sum(ffw(nlyr)./fluxdivfact(nlyr));
  elseif (propnum==3)	% heat adjustment
    airsea(boxnum,1)=airsea(boxnum,1)+ ...
	sum(fh(nlyr)./fluxdivfact(nlyr));
  end;

  % air-sea driven diapycnal advective convergence
  w_as=-fdens.*meanprop_nonans(:,propnum,boxnum);
  w_as=[0;w_as;0];
  w_as_conv=diff(w_as);
  airsea(boxnum,1)=airsea(boxnum,1)+ ...
	sum(w_as_conv(nlyr)./fluxdivfact(nlyr));

  ffact2=fluxdivfact(1:length(fluxdivfact)-1)+ ...
	diff(fluxdivfact)/2;
  h=A(indb(nlyr,propnum,boxnum),indF(:,:,boxnum))' ...
	./([ffact2;ffact2]*ones(1,length(nlyr)));
  eref=sum(sum(h'*Pxx(indF(:,:,boxnum), ...
        indF(:,:,boxnum))*h));
  eref=sqrt(eref);
  airsea(boxnum,2)=eref;
  
end;	% loop through boxes

% define mixing(boxnum,1), a matrix
% containing the diapycnic flux convergence
% (advective and mixing; same units as
% isopycnal flux).
% mixing(boxnum,2) contains the std error.
mixing=NaN*ones(nboxes,2);
ermixing=mixing;
for boxnum=1:nboxes;

  % by including all property indices in indw,
  % this should include both diffusive w* terms and
  % diapycnal advection terms
  mixing(boxnum,1)=sum(sum(Ax(indb(nlyr,propnum,boxnum), ...
        indw(:,:,boxnum)),2) ./fluxdivfact(nlyr));

  % include a priori mixing
  w_mix_conv=diff(drD_ap(:,propnum,boxnum));
  mixing(boxnum,1)=mixing(boxnum,1)+ ...
        sum(w_mix_conv(nlyr)./fluxdivfact(nlyr));

  h=A(indb(nlyr,propnum,boxnum),indw(:,:,boxnum))' ...
	./([ffact2;ffact2;ffact2]*ones(1,length(nlyr)));
  eref=sum(sum(h'*Pxx(indw(:,:,boxnum), ...
	indw(:,:,boxnum))*h));
  eref=sqrt(eref);
  mixing(boxnum,2)=eref;
end;

if (~ishold)	% first-time through loops: make map
  %clf;
  minlon=min([min(lon)-10 -100]);
  maxlon=max([max(lon)+10 0]);
  %makemap_merc([minlon maxlon], ...
	%[min(lat)-10 max(lat)+5],0,1);
  %hold on;
  plot(lon(1),lat(1),'.k','markersize',1);
  hold on; 
  overlay;
  axis([minlon maxlon min(lat)-10 max(lat)+5]);
end;

lonF=NaN*ones(tempnsections,1);
latF=lonF;
for boxnum=1:nboxes;
  for sectnum=1:tempnsections;
    if (tempgeometry(boxnum,sectnum));
      q=find(tempsectlabel==sectnum);
      lq=floor(length(q)/3);
      qq=q( (lq2-1)*lq+1:lq2*lq);
      if (length(q))
      plot(lon(q),lat(q),'.', ...
	'markersize',4,'color',[.5 .5 .5]);
      lonF(sectnum)=lon(round(median(qq)));
      latF(sectnum)=lat(round(median(qq)));
      thetaF=median(theta(q));
      Fx=-[latflux(boxnum,sectnum,1)*sin(thetaF) ...
	*tempgeometry(boxnum,sectnum) 0];
      Fy=[latflux(boxnum,sectnum,1)*cos(thetaF) ...
	*tempgeometry(boxnum,sectnum) 0];
      eFx=-[latflux(boxnum,sectnum,2)*sin(thetaF) ...
        *tempgeometry(boxnum,sectnum) 0];
      eFy=[latflux(boxnum,sectnum,2)*cos(thetaF) ...
        *tempgeometry(boxnum,sectnum) 0];

      P=quiver([lonF(sectnum) 0], ...
	[latF(sectnum) 0], ...
	multfact*Fx,multfact*Fy,0,'.');
        set(P,'color',tpropcolr(propnum,:), ...
		'linewidth',barwidth);

      % superimpose very light grey bar for heat flux;
      % make it shorter and a bit offset, so it's bordered
      % by black.
      if (propnum==3 & ~colorplot)
	spc=.025;
        P=quiver([lonF(sectnum) 0]+spc*multfact*Fx, ...
        [latF(sectnum) 0]+spc*multfact*Fy, ...
        (1-2*spc)*multfact*Fx,(1-2*spc)*multfact*Fy,0,'.');
        set(P,'color',[.9 .9 .9], ...
                'linewidth',.7*barwidth);
      end;
        
      if (labelflux)
        labl=[num2str(abs(latflux(boxnum,sectnum,1)),numstr), ...
	'\pm',num2str(latflux(boxnum,sectnum,2),numstr)];
        text(lonF(sectnum)+multfact*Fx(1)+2, ...
	  latF(sectnum)+.9*multfact*Fy(1),labl,'fontsize',8);
      end;
      end;
    end;
  end;
end;
title(titl,'fontsize',15);

% add legend
if (propnum==1)
  legend=[-65,-15];        % center of legend
elseif (propnum==2);
  legend=[-65,-5];        % center of legend
else
  legend=[-65,5];
end;

dx=15; dy=7;            % width, height (degrees)
%patch([legend(1)-dx/2 legend(1)-dx/2 ...
        %legend(1)+dx/2 legend(1)+dx/2], ...
        %[legend(2)-dy/2 legend(2)+dy/2 ...
        %legend(2)+dy/2 legend(2)-dy/2],'w');
H=fill([legend(1)-dx/2 legend(1)-dx/2 ...
        legend(1)+dx/2 legend(1)+dx/2], ...
        [legend(2)-dy/2 legend(2)+dy/2 ...
        legend(2)+dy/2 legend(2)-dy/2],'w');
P=quiver([legend(1)-multfact*legendflux/2 0], ...
	[legend(2)+dy/5 0],multfact*[legendflux 0],[0 0],0,'.');
set(P,'color',tpropcolr(propnum,:),'linewidth',barwidth);
if (propnum==3 & ~colorplot)
  spc=.025;
  P=quiver([legend(1)-multfact*legendflux/2 0]+ ...
        spc*multfact,[legend(2)+dy/5 0], ...
	(1-3*spc)*multfact*[legendflux 0],[0 0],0,'.');
  set(P,'color',[.9 .9 .9],'linewidth',.7*barwidth);
end;

if (propnum==2)
  text(legend(1),legend(2)-dy/4, ...
        [num2str(legendflux),'x10^6 kg/s'], ...
        'horizontalalignment','center','fontsize',8);
else
  text(legend(1),legend(2)-dy/4, ...
	[num2str(legendflux),fluxunits(propnum,:)], ...
        'horizontalalignment','center','fontsize',8);
end;

for boxnum=1:nboxes;
  
  q=find(tempgeometry(boxnum,:)~=0);
  %%%%%%%%%%%%%lonB=nanmean(lonF(q));
  %%%%%%%%%%%%%latB=nanmean(latF(q));
  %%%% box-specific tweaks
  %if (boxnum==3) lonB=lonB+10;end;
  %if (boxnum==4) lonB=lonB+12;latB=latB+3;end;
  %%%%
  lonB=(max(lonF(q))+min(lonF(q)))/2;
  latB=(max(latF(q))+min(latF(q)))/2;

  % label how much of the property is removed from
  % the layers by diapycnal flux divergence in each box
  str=['Mixing: '];
  if (mixing(boxnum,1)>0.05) str=[str,'+'];
  end;
  str=[str,num2str(mixing(boxnum,1),numstr)];
  str=[str,' \pm ',num2str(mixing(boxnum,2),numstr)];
  str=[str,fluxunits(propnum,:)];
  if (massnum & labelflux)
    H=text(lonB,latB+2,str,'fontsize',6, ...
	'horizontalalignment','center');
    set(H,'fontangle','italic');
  end;

  % label how much of the property is removed by
  % air-sea fluxes.
  str=['Air-sea: '];
  if (airsea(boxnum,1)>0.05) str=[str,'+']; end;
  str=[str,num2str(airsea(boxnum,1),numstr)];
  str=[str,' \pm ',num2str(airsea(boxnum,2),numstr)];
  str=[str,fluxunits(propnum,:)];
  %if (labelflux)
  if (propnum==3)
    H=text(lonB,latB-2,str,'fontsize',6, ...
	'horizontalalignment','center');
    set(H,'fontangle','italic');
  end;
end;

% display values of lateral fluxes
fprintf(['Lateral fluxes (',fluxunits(propnum,:),'):\n']);
fprintf('  Sect:\t');
for l=1:tempnsections;
  fprintf(['     ',num2str(l),'\t\t']);
end;
fprintf('\n');
for boxnum=1:nboxes;
  fprintf('Box %d: \t',boxnum);
  for l=1:tempnsections;
    fprintf('%3.1f +- %3.1f\t', ...
        latflux(boxnum,l,1),latflux(boxnum,l,2));
  end;
  fprintf('\n');
end;

end;	% loop through propnum

if (holdstatus);
  hold on;
else
  hold off;
end;

if (latisvref);
  load gaussout AirSea;
end;

load gaussout fluxdivfact;
