
% plotrefvel;
%
% plot the reference velocities from the inverse
% model solution, at station pair positions lon, lat
% with separation angle theta (theta=0 for a station
% pair pointing towards the east).
% "ufact" is used to scale the arrows.

uarr=x(indv).*cos(theta+pi/2); 
varr=x(indv).*sin(theta+pi/2);
ufact=.25*mean(diag(Rxx(indv,indv)))^.5;
ufact=.01;

plot(0,0,'.k','markersize',1);
hold on;
overlay
quiver(lon,lat,uarr/ufact,varr/ufact,0);
if (min(lat)>17 & max(lon)<0) remap(3);
elseif (min(lat)>-8 & max(lon)<0) remap(3.5);
elseif (min(lat)>-16 & max(lon)<0) remap(4);
elseif (min(lat)>-25) remap(4.5);
else axis([-180 180 -80 80]);
end;
% add legend to quiver plot of reference velocities
legend=[-80,65];	% center of legend
dxleg=10; dyleg=5;	% width, height (degrees)
patch([legend(1)-dxleg/2 legend(1)-dxleg/2 ...
	legend(1)+dxleg/2 legend(1)+dxleg/2], ...
	[legend(2)-dyleg/2 legend(2)+dyleg/2 ...
	legend(2)+dyleg/2 legend(2)-dyleg/2],'w');
quiver([legend(1)-1 0],[legend(2)+dyleg/5 0],[2 0],[0 0],0);
text(legend(1),legend(2)-dyleg/4,[num2str(200*ufact),' cm/s'], ...
	'horizontalalignment','center','fontsize',6);
q=find(abs(x(indv))./vmag >1);
plot(lon(q),lat(q),'or');
q=find(abs(x(indv))./erx(indv) > 1);
plot(lon(q),lat(q),'.r');
hold off;
title('v_{ref}');

clear uarr varr ufact legend dxleg dyleg;
