function Psi=sidelatflux(propnum,boxnum,sectnum, ...
    multfact,streamfunction,include_labels,gaussout_filename);

% function Psi=sidelatflux(propnum,boxnum,sectnum, ...
%   multfact,streamfunction,include_labels,gaussout_filename);

% plot a side view of the lateral fluxes across a 
% section or sections.  If streamfunction==1 (default),
% the transports are given for cumulative bottom-to-top.
% If streamfuction==0, they are layer-by-layer.
% Default "gaussout_filename" is "gaussout" (.mat)

addstorage=0;

if (~exist('streamfunction'))
  streamfunction=1;	% cumulative bottom-to-top;
end;
if (streamfunction) avg=1;
else avg=1;
end;
if ~exist('include_labels')
    include_labels=0;
end;
if ~exist('gaussout_filename')
    gaussout_filename='gaussout';
end;

eval(['load ',gaussout_filename, ...
    ' A Ax D EkmanE sectlabel nlayers ', ...
	'glayers indb indv indE Pxx fluxdivfact;']);

if (length(sectnum)>1)
  for i=2:length(sectnum)
    q=find(sectlabel==sectnum(i));
    sectlabel(q)=sectnum(1);
  end;
end;

qsect=find(sectlabel==sectnum(1));

EkIn=sum(EkmanE(:,propnum,boxnum,sectnum),4);
pfluxref=NaN*ones(nlayers,1);
pfluxrel=pfluxref;eref=pfluxref;
ekflux=pfluxref;
glayers_avg=pfluxref;

i=1:avg:nlayers-avg+1;

for i=1:avg:nlayers-avg+1;

  if (streamfunction)
    j=i:nlayers;
  else
    j=i:i+avg-1;
  end;

  glayers_avg(i)=mean(glayers(j));
  pfluxref(i)=sum(sum(Ax( ...
      indb(j,propnum,boxnum),indv(qsect))));
  pfluxrel(i)=-sum(sum(D( ...
      indb(j,propnum,boxnum),indv(qsect))));
  h=A(indb(j,propnum,boxnum), ...
        [indv(qsect);indE(unique(sectlabel(qsect)))])';
  eref(i)=sqrt(  sum(sum(h'*Pxx( ...
      [indv(qsect);indE(unique(sectlabel(qsect)))], ...
      [indv(qsect);indE(unique(sectlabel(qsect)))])*h))  );
  if (length(boxnum)==1)
      ekflux(i)=nansum(EkIn(j));
  else
      ekflux(i)=sum(nansum(EkIn(j,:,:)));
  end;
end;
q=find(isnan(pfluxref+pfluxrel));
pfluxref(q)=[]; pfluxrel(q)=[];
eref(q)=[]; glayers_avg(q)=[];
ekflux(q)=[];

netflux=multfact*(pfluxref+pfluxrel+ekflux);

prop=netflux/fluxdivfact(propnum);
eprop=eref/fluxdivfact(propnum);
if (~streamfunction)
  glayers=glayers_avg;
end;

if (include_labels)
  layerpatch(prop,eprop,'k',[.5 .5 .5],1);
else 
  %layerpatch(prop,eprop,'k',[.5 .5 .5],0);
  plot(prop,glayers);
end;
set(gca,'ylim',[-length(glayers)+.5 -.5]);

layers=(1:length(glayers))';
Psi(:,1)=prop;
Psi(:,2)=eprop;

% add cumulate storage
if (addstorage & streamfunction);
  disp('Adding storage');
  load gaussout n;
  n=n(indb(1:length(glayers),propnum,boxnum));
  Psi(:,1)=Psi(:,1)+flipud(cumsum(flipud(n))) ...
	/fluxdivfact(propnum);
end;

if (propnum==1 & streamfunction)
    % added 26 March 2004: max overturning at densities>25.5
    % (i.e. not the PIT number for Indian Ocean overturning)
  q1=find(glayers>25.5);
  q2=find(abs(Psi(q1,1))==max(abs(Psi(q1,1))));
  q2=max(q2);
  fprintf('overturning strength: %2.1f +- %2.1f Sv\n', ...
	abs(Psi(q1(q2),1)),Psi(q1(q2),2));
end;

pause(.1);
